Class: Conekta::ApiKeyCreateResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::ApiKeyCreateResponse
- Defined in:
- lib/conekta/models/api_key_create_response.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Indicates if the api key is active.
-
#authentication_token ⇒ Object
It is occupied as a user when authenticated with basic authentication, with a blank password.
-
#created_at ⇒ Object
Unix timestamp in seconds of when the api key was created.
-
#deactivated_at ⇒ Object
Unix timestamp in seconds of when the api key was deleted.
-
#description ⇒ Object
A name or brief explanation of what this api key is used for.
-
#id ⇒ Object
Unique identifier of the api key.
-
#last_used_at ⇒ Object
Unix timestamp in seconds with the api key was used.
-
#livemode ⇒ Object
Indicates if the api key is in production.
-
#object ⇒ Object
Object name, value is 'api_key'.
-
#prefix ⇒ Object
The first few characters of the authentication_token.
-
#role ⇒ Object
Indicates if the api key is private or public.
-
#updated_at ⇒ Object
Unix timestamp in seconds of when the api key was last updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiKeyCreateResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiKeyCreateResponse
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/conekta/models/api_key_create_response.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ApiKeyCreateResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ApiKeyCreateResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'authentication_token') self.authentication_token = attributes[:'authentication_token'] end if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'deactivated_at') self.deactivated_at = attributes[:'deactivated_at'] end if attributes.key?(:'last_used_at') self.last_used_at = attributes[:'last_used_at'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'prefix') self.prefix = attributes[:'prefix'] end if attributes.key?(:'role') self.role = attributes[:'role'] end end |
Instance Attribute Details
#active ⇒ Object
Indicates if the api key is active
22 23 24 |
# File 'lib/conekta/models/api_key_create_response.rb', line 22 def active @active end |
#authentication_token ⇒ Object
It is occupied as a user when authenticated with basic authentication, with a blank password. This value will only appear once, in the request to create a new key. Copy and save it in a safe place.
19 20 21 |
# File 'lib/conekta/models/api_key_create_response.rb', line 19 def authentication_token @authentication_token end |
#created_at ⇒ Object
Unix timestamp in seconds of when the api key was created
25 26 27 |
# File 'lib/conekta/models/api_key_create_response.rb', line 25 def created_at @created_at end |
#deactivated_at ⇒ Object
Unix timestamp in seconds of when the api key was deleted
31 32 33 |
# File 'lib/conekta/models/api_key_create_response.rb', line 31 def deactivated_at @deactivated_at end |
#description ⇒ Object
A name or brief explanation of what this api key is used for
37 38 39 |
# File 'lib/conekta/models/api_key_create_response.rb', line 37 def description @description end |
#id ⇒ Object
Unique identifier of the api key
40 41 42 |
# File 'lib/conekta/models/api_key_create_response.rb', line 40 def id @id end |
#last_used_at ⇒ Object
Unix timestamp in seconds with the api key was used
34 35 36 |
# File 'lib/conekta/models/api_key_create_response.rb', line 34 def last_used_at @last_used_at end |
#livemode ⇒ Object
Indicates if the api key is in production
43 44 45 |
# File 'lib/conekta/models/api_key_create_response.rb', line 43 def livemode @livemode end |
#object ⇒ Object
Object name, value is 'api_key'
46 47 48 |
# File 'lib/conekta/models/api_key_create_response.rb', line 46 def object @object end |
#prefix ⇒ Object
The first few characters of the authentication_token
49 50 51 |
# File 'lib/conekta/models/api_key_create_response.rb', line 49 def prefix @prefix end |
#role ⇒ Object
Indicates if the api key is private or public
52 53 54 |
# File 'lib/conekta/models/api_key_create_response.rb', line 52 def role @role end |
#updated_at ⇒ Object
Unix timestamp in seconds of when the api key was last updated
28 29 30 |
# File 'lib/conekta/models/api_key_create_response.rb', line 28 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/conekta/models/api_key_create_response.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/conekta/models/api_key_create_response.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/conekta/models/api_key_create_response.rb', line 55 def self.attribute_map { :'authentication_token' => :'authentication_token', :'active' => :'active', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'deactivated_at' => :'deactivated_at', :'last_used_at' => :'last_used_at', :'description' => :'description', :'id' => :'id', :'livemode' => :'livemode', :'object' => :'object', :'prefix' => :'prefix', :'role' => :'role' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/conekta/models/api_key_create_response.rb', line 220 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/conekta/models/api_key_create_response.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/conekta/models/api_key_create_response.rb', line 83 def self.openapi_types { :'authentication_token' => :'String', :'active' => :'Boolean', :'created_at' => :'Integer', :'updated_at' => :'Integer', :'deactivated_at' => :'Integer', :'last_used_at' => :'Integer', :'description' => :'String', :'id' => :'String', :'livemode' => :'Boolean', :'object' => :'String', :'prefix' => :'String', :'role' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/conekta/models/api_key_create_response.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && authentication_token == o.authentication_token && active == o.active && created_at == o.created_at && updated_at == o.updated_at && deactivated_at == o.deactivated_at && last_used_at == o.last_used_at && description == o.description && id == o.id && livemode == o.livemode && object == o.object && prefix == o.prefix && role == o.role end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/conekta/models/api_key_create_response.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/conekta/models/api_key_create_response.rb', line 213 def hash [authentication_token, active, created_at, updated_at, deactivated_at, last_used_at, description, id, livemode, object, prefix, role].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 |
# File 'lib/conekta/models/api_key_create_response.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/conekta/models/api_key_create_response.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 |
# File 'lib/conekta/models/api_key_create_response.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |