Class: Conekta::BalanceResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/balance_response.rb

Overview

balance model

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BalanceResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/conekta/models/balance_response.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::BalanceResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::BalanceResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'available')
    if (value = attributes[:'available']).is_a?(Array)
      self.available = value
    end
  end

  if attributes.key?(:'cashout_retention_amount')
    if (value = attributes[:'cashout_retention_amount']).is_a?(Array)
      self.cashout_retention_amount = value
    end
  end

  if attributes.key?(:'conekta_retention')
    if (value = attributes[:'conekta_retention']).is_a?(Array)
      self.conekta_retention = value
    end
  end

  if attributes.key?(:'gateway')
    if (value = attributes[:'gateway']).is_a?(Array)
      self.gateway = value
    end
  end

  if attributes.key?(:'pending')
    if (value = attributes[:'pending']).is_a?(Array)
      self.pending = value
    end
  end

  if attributes.key?(:'retained')
    if (value = attributes[:'retained']).is_a?(Array)
      self.retained = value
    end
  end

  if attributes.key?(:'retention_amount')
    if (value = attributes[:'retention_amount']).is_a?(Array)
      self.retention_amount = value
    end
  end

  if attributes.key?(:'target_collateral_amount')
    self.target_collateral_amount = attributes[:'target_collateral_amount']
  end

  if attributes.key?(:'target_retention_amount')
    if (value = attributes[:'target_retention_amount']).is_a?(Array)
      self.target_retention_amount = value
    end
  end

  if attributes.key?(:'temporarily_retained')
    if (value = attributes[:'temporarily_retained']).is_a?(Array)
      self.temporarily_retained = value
    end
  end
end

Instance Attribute Details

#availableObject

The balance's available



20
21
22
# File 'lib/conekta/models/balance_response.rb', line 20

def available
  @available
end

#cashout_retention_amountObject

The balance's cashout retention amount



23
24
25
# File 'lib/conekta/models/balance_response.rb', line 23

def cashout_retention_amount
  @cashout_retention_amount
end

#conekta_retentionObject

The balance's conekta retention



26
27
28
# File 'lib/conekta/models/balance_response.rb', line 26

def conekta_retention
  @conekta_retention
end

#gatewayObject

The balance's gateway



29
30
31
# File 'lib/conekta/models/balance_response.rb', line 29

def gateway
  @gateway
end

#pendingObject

The balance's pending



32
33
34
# File 'lib/conekta/models/balance_response.rb', line 32

def pending
  @pending
end

#retainedObject

The balance's retained



35
36
37
# File 'lib/conekta/models/balance_response.rb', line 35

def retained
  @retained
end

#retention_amountObject

The balance's retention amount



38
39
40
# File 'lib/conekta/models/balance_response.rb', line 38

def retention_amount
  @retention_amount
end

#target_collateral_amountObject

The balance's target collateral amount



41
42
43
# File 'lib/conekta/models/balance_response.rb', line 41

def target_collateral_amount
  @target_collateral_amount
end

#target_retention_amountObject

The balance's target retention amount



44
45
46
# File 'lib/conekta/models/balance_response.rb', line 44

def target_retention_amount
  @target_retention_amount
end

#temporarily_retainedObject

The balance's temporarily retained



47
48
49
# File 'lib/conekta/models/balance_response.rb', line 47

def temporarily_retained
  @temporarily_retained
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/conekta/models/balance_response.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/conekta/models/balance_response.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/conekta/models/balance_response.rb', line 50

def self.attribute_map
  {
    :'available' => :'available',
    :'cashout_retention_amount' => :'cashout_retention_amount',
    :'conekta_retention' => :'conekta_retention',
    :'gateway' => :'gateway',
    :'pending' => :'pending',
    :'retained' => :'retained',
    :'retention_amount' => :'retention_amount',
    :'target_collateral_amount' => :'target_collateral_amount',
    :'target_retention_amount' => :'target_retention_amount',
    :'temporarily_retained' => :'temporarily_retained'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/conekta/models/balance_response.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/conekta/models/balance_response.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/conekta/models/balance_response.rb', line 76

def self.openapi_types
  {
    :'available' => :'Array<BalanceCommonFielsResponse>',
    :'cashout_retention_amount' => :'Array<BalanceCommonFielsResponse>',
    :'conekta_retention' => :'Array<BalanceCommonFielsResponse>',
    :'gateway' => :'Array<BalanceCommonFielsResponse>',
    :'pending' => :'Array<BalanceCommonFielsResponse>',
    :'retained' => :'Array<BalanceCommonFielsResponse>',
    :'retention_amount' => :'Array<BalanceCommonFielsResponse>',
    :'target_collateral_amount' => :'Object',
    :'target_retention_amount' => :'Array<BalanceCommonFielsResponse>',
    :'temporarily_retained' => :'Array<BalanceCommonFielsResponse>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/conekta/models/balance_response.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      available == o.available &&
      cashout_retention_amount == o.cashout_retention_amount &&
      conekta_retention == o.conekta_retention &&
      gateway == o.gateway &&
      pending == o.pending &&
      retained == o.retained &&
      retention_amount == o.retention_amount &&
      target_collateral_amount == o.target_collateral_amount &&
      target_retention_amount == o.target_retention_amount &&
      temporarily_retained == o.temporarily_retained
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/conekta/models/balance_response.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/conekta/models/balance_response.rb', line 212

def hash
  [available, cashout_retention_amount, conekta_retention, gateway, pending, retained, retention_amount, target_collateral_amount, target_retention_amount, temporarily_retained].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
# File 'lib/conekta/models/balance_response.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/conekta/models/balance_response.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
# File 'lib/conekta/models/balance_response.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end