Class: Conekta::ChargeResponseRefundsData

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/charge_response_refunds_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ChargeResponseRefundsData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ChargeResponseRefundsData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ChargeResponseRefundsData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'auth_code')
    self.auth_code = attributes[:'auth_code']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



18
19
20
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 18

def amount
  @amount
end

#auth_codeObject

Returns the value of attribute auth_code.



20
21
22
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 20

def auth_code
  @auth_code
end

#created_atObject

Returns the value of attribute created_at.



22
23
24
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 22

def created_at
  @created_at
end

#expires_atObject

refund expiration date



25
26
27
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 25

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



27
28
29
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 27

def id
  @id
end

#objectObject

Returns the value of attribute object.



29
30
31
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 29

def object
  @object
end

#statusObject

refund status



32
33
34
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 32

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 35

def self.attribute_map
  {
    :'amount' => :'amount',
    :'auth_code' => :'auth_code',
    :'created_at' => :'created_at',
    :'expires_at' => :'expires_at',
    :'id' => :'id',
    :'object' => :'object',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 233

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 58

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'auth_code' => :'String',
    :'created_at' => :'Integer',
    :'expires_at' => :'Integer',
    :'id' => :'String',
    :'object' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
216
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      auth_code == o.auth_code &&
      created_at == o.created_at &&
      expires_at == o.expires_at &&
      id == o.id &&
      object == o.object &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 220

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



226
227
228
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 226

def hash
  [amount, auth_code, created_at, expires_at, id, object, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 255

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
162
# File 'lib/conekta/models/charge_response_refunds_data.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @object.nil?
  true
end