Class: Conekta::ChargebackResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/chargeback_response.rb

Overview

Chargeback object

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ChargebackResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/conekta/models/chargeback_response.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ChargebackResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ChargebackResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'followup_status')
    self.followup_status = attributes[:'followup_status']
  end

  if attributes.key?(:'response_from_client')
    self.response_from_client = attributes[:'response_from_client']
  end

  if attributes.key?(:'files')
    if (value = attributes[:'files']).is_a?(Array)
      self.files = value
    end
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'charge_id')
    self.charge_id = attributes[:'charge_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'evidence_due_by')
    self.evidence_due_by = attributes[:'evidence_due_by']
  end
end

Instance Attribute Details

#charge_idObject

Returns the value of attribute charge_id.



35
36
37
# File 'lib/conekta/models/chargeback_response.rb', line 35

def charge_id
  @charge_id
end

#created_atObject

Returns the value of attribute created_at.



37
38
39
# File 'lib/conekta/models/chargeback_response.rb', line 37

def created_at
  @created_at
end

#evidence_due_byObject

Returns the value of attribute evidence_due_by.



39
40
41
# File 'lib/conekta/models/chargeback_response.rb', line 39

def evidence_due_by
  @evidence_due_by
end

#filesObject

Returns the value of attribute files.



31
32
33
# File 'lib/conekta/models/chargeback_response.rb', line 31

def files
  @files
end

#followup_statusObject

Returns the value of attribute followup_status.



27
28
29
# File 'lib/conekta/models/chargeback_response.rb', line 27

def followup_status
  @followup_status
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/conekta/models/chargeback_response.rb', line 19

def id
  @id
end

#noteObject

Returns the value of attribute note.



25
26
27
# File 'lib/conekta/models/chargeback_response.rb', line 25

def note
  @note
end

#objectObject

Returns the value of attribute object.



33
34
35
# File 'lib/conekta/models/chargeback_response.rb', line 33

def object
  @object
end

#reasonObject

Returns the value of attribute reason.



23
24
25
# File 'lib/conekta/models/chargeback_response.rb', line 23

def reason
  @reason
end

#response_from_clientObject

Returns the value of attribute response_from_client.



29
30
31
# File 'lib/conekta/models/chargeback_response.rb', line 29

def response_from_client
  @response_from_client
end

#statusObject

Returns the value of attribute status.



21
22
23
# File 'lib/conekta/models/chargeback_response.rb', line 21

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/conekta/models/chargeback_response.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/conekta/models/chargeback_response.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/conekta/models/chargeback_response.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'reason' => :'reason',
    :'note' => :'note',
    :'followup_status' => :'followup_status',
    :'response_from_client' => :'response_from_client',
    :'files' => :'files',
    :'object' => :'object',
    :'charge_id' => :'charge_id',
    :'created_at' => :'created_at',
    :'evidence_due_by' => :'evidence_due_by'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/conekta/models/chargeback_response.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/conekta/models/chargeback_response.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/conekta/models/chargeback_response.rb', line 91

def self.openapi_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'reason' => :'String',
    :'note' => :'String',
    :'followup_status' => :'String',
    :'response_from_client' => :'String',
    :'files' => :'Array<ChargebackFileResponse>',
    :'object' => :'String',
    :'charge_id' => :'String',
    :'created_at' => :'Integer',
    :'evidence_due_by' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/conekta/models/chargeback_response.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      reason == o.reason &&
      note == o.note &&
      followup_status == o.followup_status &&
      response_from_client == o.response_from_client &&
      files == o.files &&
      object == o.object &&
      charge_id == o.charge_id &&
      created_at == o.created_at &&
      evidence_due_by == o.evidence_due_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/conekta/models/chargeback_response.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/conekta/models/chargeback_response.rb', line 253

def hash
  [id, status, reason, note, followup_status, response_from_client, files, object, charge_id, created_at, evidence_due_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
# File 'lib/conekta/models/chargeback_response.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/conekta/models/chargeback_response.rb', line 282

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
190
191
192
193
194
195
# File 'lib/conekta/models/chargeback_response.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["won", "lost", "action_required", "pending_review", "under_review", "covered", "rt", "rt_sent", "represented"])
  return false unless status_validator.valid?(@status)
  reason_validator = EnumAttributeValidator.new('String', ["unrecognized", "unauthorized", "unauthorized_by_client", "unrecognized_like_fraud", "insufficient_evidence", "illegible_evidence", "general", "late_evidence", "incorrect_exchange", "fraudulent_business", "billing", "twice_transaction", "transaction_not_refunded", "bank_doc_request", "unrecognized_purchase", "subscription_canceled", "copy_of_purchase", "differents_amounts", "subscription_not_requested", "damaged_products", "show_documents", "duplicate", "fraudulent", "service_canceled", "product_unacceptable", "product_not_received", "incorrect_amount", "chip_liabiliaty_shift", "credit_not_processed"])
  return false unless reason_validator.valid?(@reason)
  followup_status_validator = EnumAttributeValidator.new('String', ["customer_uncontacted", "customer_contacted", "customer_unreachable"])
  return false unless followup_status_validator.valid?(@followup_status)
  true
end