Class: Conekta::CheckoutOrderTemplate

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/checkout_order_template.rb

Overview

It maintains the attributes with which the order will be created when receiving a new payment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CheckoutOrderTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/conekta/models/checkout_order_template.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CheckoutOrderTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CheckoutOrderTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'customer_info')
    self.customer_info = attributes[:'customer_info']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  else
    self.line_items = nil
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'tax_lines')
    if (value = attributes[:'tax_lines']).is_a?(Array)
      self.tax_lines = value
    end
  end

  if attributes.key?(:'discount_lines')
    if (value = attributes[:'discount_lines']).is_a?(Array)
      self.discount_lines = value
    end
  end
end

Instance Attribute Details

#currencyObject

It is the currency in which the order will be created. It must be a valid ISO 4217 currency code.



20
21
22
# File 'lib/conekta/models/checkout_order_template.rb', line 20

def currency
  @currency
end

#customer_infoObject

Returns the value of attribute customer_info.



22
23
24
# File 'lib/conekta/models/checkout_order_template.rb', line 22

def customer_info
  @customer_info
end

#discount_linesObject

List of discounts that are applied to the order.



34
35
36
# File 'lib/conekta/models/checkout_order_template.rb', line 34

def discount_lines
  @discount_lines
end

#line_itemsObject

They are the products to buy. Each contains the "unit price" and "quantity" parameters that are used to calculate the total amount of the order.



25
26
27
# File 'lib/conekta/models/checkout_order_template.rb', line 25

def line_items
  @line_items
end

#metadataObject

It is a set of key-value pairs that you can attach to the order. It can be used to store additional information about the order in a structured format.



28
29
30
# File 'lib/conekta/models/checkout_order_template.rb', line 28

def 
  @metadata
end

#tax_linesObject

List of taxes that are applied to the order.



31
32
33
# File 'lib/conekta/models/checkout_order_template.rb', line 31

def tax_lines
  @tax_lines
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/conekta/models/checkout_order_template.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/conekta/models/checkout_order_template.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/conekta/models/checkout_order_template.rb', line 37

def self.attribute_map
  {
    :'currency' => :'currency',
    :'customer_info' => :'customer_info',
    :'line_items' => :'line_items',
    :'metadata' => :'metadata',
    :'tax_lines' => :'tax_lines',
    :'discount_lines' => :'discount_lines'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/conekta/models/checkout_order_template.rb', line 230

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/conekta/models/checkout_order_template.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/conekta/models/checkout_order_template.rb', line 59

def self.openapi_types
  {
    :'currency' => :'String',
    :'customer_info' => :'CheckoutOrderTemplateCustomerInfo',
    :'line_items' => :'Array<Product>',
    :'metadata' => :'Hash<String, Object>',
    :'tax_lines' => :'Array<OrderTaxRequest>',
    :'discount_lines' => :'Array<OrderDiscountLinesRequest>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
# File 'lib/conekta/models/checkout_order_template.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      currency == o.currency &&
      customer_info == o.customer_info &&
      line_items == o.line_items &&
       == o. &&
      tax_lines == o.tax_lines &&
      discount_lines == o.discount_lines
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


217
218
219
# File 'lib/conekta/models/checkout_order_template.rb', line 217

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



223
224
225
# File 'lib/conekta/models/checkout_order_template.rb', line 223

def hash
  [currency, customer_info, line_items, , tax_lines, discount_lines].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/conekta/models/checkout_order_template.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if @line_items.nil?
    invalid_properties.push('invalid value for "line_items", line_items cannot be nil.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/conekta/models/checkout_order_template.rb', line 252

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
162
# File 'lib/conekta/models/checkout_order_template.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @currency.nil?
  return false if @currency.to_s.length > 3
  return false if @line_items.nil?
  return false if !@metadata.nil? && @metadata.length > 100
  true
end