Class: Conekta::CompaniesApi
- Inherits:
-
Object
- Object
- Conekta::CompaniesApi
- Defined in:
- lib/conekta/api/companies_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_company(create_company_request, opts = {}) ⇒ CompanyResponse
Create Company Create a new company.
-
#create_company_with_http_info(create_company_request, opts = {}) ⇒ Array<(CompanyResponse, Integer, Hash)>
Create Company Create a new company.
-
#get_companies(opts = {}) ⇒ GetCompaniesResponse
Get List of Companies Consume the list of child companies.
-
#get_companies_with_http_info(opts = {}) ⇒ Array<(GetCompaniesResponse, Integer, Hash)>
Get List of Companies Consume the list of child companies.
-
#get_company(id, opts = {}) ⇒ CompanyResponse
Get Company.
-
#get_company_documents(company_id, opts = {}) ⇒ Array<CompanyDocumentResponse>
Get Company Documents Retrieve a list of documents associated with a specific company.
-
#get_company_documents_with_http_info(company_id, opts = {}) ⇒ Array<(Array<CompanyDocumentResponse>, Integer, Hash)>
Get Company Documents Retrieve a list of documents associated with a specific company.
-
#get_company_with_http_info(id, opts = {}) ⇒ Array<(CompanyResponse, Integer, Hash)>
Get Company.
-
#get_current_company(opts = {}) ⇒ CompanyResponse
Get Current Company Retrieves information about the currently authenticated company.
-
#get_current_company_with_http_info(opts = {}) ⇒ Array<(CompanyResponse, Integer, Hash)>
Get Current Company Retrieves information about the currently authenticated company.
-
#initialize(api_client = ApiClient.default) ⇒ CompaniesApi
constructor
A new instance of CompaniesApi.
-
#update_company_document(company_id, company_document_request, opts = {}) ⇒ CompanyDocumentResponse
Update Company Document Updates an existing document associated with a specific company.
-
#update_company_document_with_http_info(company_id, company_document_request, opts = {}) ⇒ Array<(CompanyDocumentResponse, Integer, Hash)>
Update Company Document Updates an existing document associated with a specific company.
-
#upload_company_document(company_id, company_document_request, opts = {}) ⇒ CompanyDocumentResponse
Upload Company Document Uploads a document associated with a specific company.
-
#upload_company_document_with_http_info(company_id, company_document_request, opts = {}) ⇒ Array<(CompanyDocumentResponse, Integer, Hash)>
Upload Company Document Uploads a document associated with a specific company.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CompaniesApi
Returns a new instance of CompaniesApi.
19 20 21 |
# File 'lib/conekta/api/companies_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/conekta/api/companies_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_company(create_company_request, opts = {}) ⇒ CompanyResponse
Create Company Create a new company.
27 28 29 30 |
# File 'lib/conekta/api/companies_api.rb', line 27 def create_company(create_company_request, opts = {}) data, _status_code, _headers = create_company_with_http_info(create_company_request, opts) data end |
#create_company_with_http_info(create_company_request, opts = {}) ⇒ Array<(CompanyResponse, Integer, Hash)>
Create Company Create a new company.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/conekta/api/companies_api.rb', line 37 def create_company_with_http_info(create_company_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.create_company ...' end # verify the required parameter 'create_company_request' is set if @api_client.config.client_side_validation && create_company_request.nil? fail ArgumentError, "Missing the required parameter 'create_company_request' when calling CompaniesApi.create_company" end # resource path local_var_path = '/companies' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_company_request) # return_type return_type = opts[:debug_return_type] || 'CompanyResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CompaniesApi.create_company", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#create_company\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_companies(opts = {}) ⇒ GetCompaniesResponse
Get List of Companies Consume the list of child companies. This is used for holding companies with several child entities.
99 100 101 102 |
# File 'lib/conekta/api/companies_api.rb', line 99 def get_companies(opts = {}) data, _status_code, _headers = get_companies_with_http_info(opts) data end |
#get_companies_with_http_info(opts = {}) ⇒ Array<(GetCompaniesResponse, Integer, Hash)>
Get List of Companies Consume the list of child companies. This is used for holding companies with several child entities.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/conekta/api/companies_api.rb', line 113 def get_companies_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.get_companies ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 250 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.get_companies, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.get_companies, must be greater than or equal to 1.' end # resource path local_var_path = '/companies' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCompaniesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CompaniesApi.get_companies", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#get_companies\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_company(id, opts = {}) ⇒ CompanyResponse
Get Company
179 180 181 182 |
# File 'lib/conekta/api/companies_api.rb', line 179 def get_company(id, opts = {}) data, _status_code, _headers = get_company_with_http_info(id, opts) data end |
#get_company_documents(company_id, opts = {}) ⇒ Array<CompanyDocumentResponse>
Get Company Documents Retrieve a list of documents associated with a specific company.
248 249 250 251 |
# File 'lib/conekta/api/companies_api.rb', line 248 def get_company_documents(company_id, opts = {}) data, _status_code, _headers = get_company_documents_with_http_info(company_id, opts) data end |
#get_company_documents_with_http_info(company_id, opts = {}) ⇒ Array<(Array<CompanyDocumentResponse>, Integer, Hash)>
Get Company Documents Retrieve a list of documents associated with a specific company.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/conekta/api/companies_api.rb', line 259 def get_company_documents_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.get_company_documents ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.get_company_documents" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/companies/{company_id}/documents'.sub('{company_id}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CompanyDocumentResponse>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CompaniesApi.get_company_documents", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#get_company_documents\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_company_with_http_info(id, opts = {}) ⇒ Array<(CompanyResponse, Integer, Hash)>
Get Company
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/conekta/api/companies_api.rb', line 189 def get_company_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.get_company ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CompaniesApi.get_company" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/companies/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CompanyResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CompaniesApi.get_company", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#get_company\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_current_company(opts = {}) ⇒ CompanyResponse
Get Current Company Retrieves information about the currently authenticated company. This endpoint returns the same data as the standard company endpoint but automatically uses the current company's context.
317 318 319 320 |
# File 'lib/conekta/api/companies_api.rb', line 317 def get_current_company(opts = {}) data, _status_code, _headers = get_current_company_with_http_info(opts) data end |
#get_current_company_with_http_info(opts = {}) ⇒ Array<(CompanyResponse, Integer, Hash)>
Get Current Company Retrieves information about the currently authenticated company. This endpoint returns the same data as the standard company endpoint but automatically uses the current company's context.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/conekta/api/companies_api.rb', line 327 def get_current_company_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.get_current_company ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/companies/current' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CompanyResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CompaniesApi.get_current_company", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#get_current_company\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_company_document(company_id, company_document_request, opts = {}) ⇒ CompanyDocumentResponse
Update Company Document Updates an existing document associated with a specific company.
383 384 385 386 |
# File 'lib/conekta/api/companies_api.rb', line 383 def update_company_document(company_id, company_document_request, opts = {}) data, _status_code, _headers = update_company_document_with_http_info(company_id, company_document_request, opts) data end |
#update_company_document_with_http_info(company_id, company_document_request, opts = {}) ⇒ Array<(CompanyDocumentResponse, Integer, Hash)>
Update Company Document Updates an existing document associated with a specific company.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/conekta/api/companies_api.rb', line 395 def update_company_document_with_http_info(company_id, company_document_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.update_company_document ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.update_company_document" end # verify the required parameter 'company_document_request' is set if @api_client.config.client_side_validation && company_document_request.nil? fail ArgumentError, "Missing the required parameter 'company_document_request' when calling CompaniesApi.update_company_document" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/companies/{company_id}/document'.sub('{company_id}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(company_document_request) # return_type return_type = opts[:debug_return_type] || 'CompanyDocumentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CompaniesApi.update_company_document", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#update_company_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#upload_company_document(company_id, company_document_request, opts = {}) ⇒ CompanyDocumentResponse
Upload Company Document Uploads a document associated with a specific company.
464 465 466 467 |
# File 'lib/conekta/api/companies_api.rb', line 464 def upload_company_document(company_id, company_document_request, opts = {}) data, _status_code, _headers = upload_company_document_with_http_info(company_id, company_document_request, opts) data end |
#upload_company_document_with_http_info(company_id, company_document_request, opts = {}) ⇒ Array<(CompanyDocumentResponse, Integer, Hash)>
Upload Company Document Uploads a document associated with a specific company.
476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/conekta/api/companies_api.rb', line 476 def upload_company_document_with_http_info(company_id, company_document_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.upload_company_document ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.upload_company_document" end # verify the required parameter 'company_document_request' is set if @api_client.config.client_side_validation && company_document_request.nil? fail ArgumentError, "Missing the required parameter 'company_document_request' when calling CompaniesApi.upload_company_document" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/companies/{company_id}/document'.sub('{company_id}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(company_document_request) # return_type return_type = opts[:debug_return_type] || 'CompanyDocumentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CompaniesApi.upload_company_document", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#upload_company_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |