Class: Conekta::CompanyDocumentRequest

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/company_document_request.rb

Overview

Request body for uploading a company document.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CompanyDocumentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/conekta/models/company_document_request.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CompanyDocumentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CompanyDocumentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'file_classification')
    self.file_classification = attributes[:'file_classification']
  else
    self.file_classification = nil
  end

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  else
    self.content_type = nil
  end

  if attributes.key?(:'international')
    self.international = attributes[:'international']
  end

  if attributes.key?(:'file_name')
    self.file_name = attributes[:'file_name']
  else
    self.file_name = nil
  end

  if attributes.key?(:'file_data')
    self.file_data = attributes[:'file_data']
  else
    self.file_data = nil
  end
end

Instance Attribute Details

#content_typeObject

MIME type of the file. Allowed values depend on the file_classification. - image/jpeg - image/png - application/pdf



23
24
25
# File 'lib/conekta/models/company_document_request.rb', line 23

def content_type
  @content_type
end

#file_classificationObject

Classification of the document. | Tipo de archivo | Descripción | | :--------------------------- | :-------------------------------------------------------- | | id_legal_representative | identificación oficial frente | | id_legal_representative_back | identificación oficial atrás | | cfdi | Prueba de situación fiscal | | constitutive_act_basic | Acta constitutiva | | proof_of_address | Comprobante de domicilio del negocio | | power_of_attonery | Poderes de representación | | deposit_account_cover | Carátula de la cuenta de depósito | | permit_casino | Permiso ante SEGOB | | license_sanitation | Licencia sanitaria de COFEPRIS | | registration_tourism | Inscripción ante el Registro Nacional de Turismo (SECTUR) |



20
21
22
# File 'lib/conekta/models/company_document_request.rb', line 20

def file_classification
  @file_classification
end

#file_dataObject

Base64 encoded content of the file.



32
33
34
# File 'lib/conekta/models/company_document_request.rb', line 32

def file_data
  @file_data
end

#file_nameObject

Name of the file being uploaded.



29
30
31
# File 'lib/conekta/models/company_document_request.rb', line 29

def file_name
  @file_name
end

#internationalObject

Indicates if the document is international. Defaults to false.



26
27
28
# File 'lib/conekta/models/company_document_request.rb', line 26

def international
  @international
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/conekta/models/company_document_request.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/conekta/models/company_document_request.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/conekta/models/company_document_request.rb', line 57

def self.attribute_map
  {
    :'file_classification' => :'file_classification',
    :'content_type' => :'content_type',
    :'international' => :'international',
    :'file_name' => :'file_name',
    :'file_data' => :'file_data'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/conekta/models/company_document_request.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/conekta/models/company_document_request.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/conekta/models/company_document_request.rb', line 78

def self.openapi_types
  {
    :'file_classification' => :'String',
    :'content_type' => :'String',
    :'international' => :'Boolean',
    :'file_name' => :'String',
    :'file_data' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
# File 'lib/conekta/models/company_document_request.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      file_classification == o.file_classification &&
      content_type == o.content_type &&
      international == o.international &&
      file_name == o.file_name &&
      file_data == o.file_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/conekta/models/company_document_request.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/conekta/models/company_document_request.rb', line 236

def hash
  [file_classification, content_type, international, file_name, file_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/conekta/models/company_document_request.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @file_classification.nil?
    invalid_properties.push('invalid value for "file_classification", file_classification cannot be nil.')
  end

  if @content_type.nil?
    invalid_properties.push('invalid value for "content_type", content_type cannot be nil.')
  end

  if @file_name.nil?
    invalid_properties.push('invalid value for "file_name", file_name cannot be nil.')
  end

  if @file_data.nil?
    invalid_properties.push('invalid value for "file_data", file_data cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/conekta/models/company_document_request.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
172
173
174
# File 'lib/conekta/models/company_document_request.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @file_classification.nil?
  file_classification_validator = EnumAttributeValidator.new('String', ["id_legal_representative", "id_legal_representative_back", "cfdi", "constitutive_act_basic", "proof_of_address", "power_of_attonery", "deposit_account_cover", "permit_casino", "license_sanitation", "registration_tourism"])
  return false unless file_classification_validator.valid?(@file_classification)
  return false if @content_type.nil?
  return false if @file_name.nil?
  return false if @file_data.nil?
  true
end