Class: Conekta::Configuration
- Inherits:
-
Object
- Object
- Conekta::Configuration
- Defined in:
- lib/conekta/configuration.rb
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
-
#access_token_getter ⇒ Proc
Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2.
-
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
-
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
-
#base_path ⇒ Object
Defines url base path.
-
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation.
-
#debugging ⇒ true, false
Set this to enable/disable debugging.
-
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
-
#host ⇒ Object
Defines url host.
-
#inject_format ⇒ Object
Returns the value of attribute inject_format.
-
#logger ⇒ #debug
Defines the logger used for debugging.
-
#params_encoder ⇒ Object
Set this to customize parameters encoder of array parameter.
-
#password ⇒ String
Defines the password used with HTTP basic authentication.
-
#proxy ⇒ Object
Proxy setting HTTP Proxy settings.
-
#return_binary_data ⇒ Object
Set this to return data as binary instead of downloading a temp file.
-
#scheme ⇒ Object
Defines url scheme.
-
#server_index ⇒ Object
Define server configuration index.
-
#server_operation_index ⇒ Object
Define server operation configuration index.
-
#server_operation_variables ⇒ Object
Default server operation variables.
-
#server_variables ⇒ Object
Default server variables.
-
#ssl_ca_file ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
-
#ssl_client_cert ⇒ Object
TLS/SSL setting Client certificate file (for client certificate).
-
#ssl_client_key ⇒ Object
TLS/SSL setting Client private key file (for client certificate).
-
#ssl_verify ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server.
-
#ssl_verify_mode ⇒ Object
TLS/SSL setting Any
OpenSSL::SSL::constant (see https://ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html). -
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response).
-
#timeout ⇒ Object
The time limit for HTTP request in seconds.
-
#username ⇒ String
Defines the username used with HTTP basic authentication.
Class Method Summary collapse
-
.default ⇒ Object
The default Configuration object.
Instance Method Summary collapse
-
#access_token_with_refresh ⇒ Object
Gets access_token using access_token_getter or uses the static access_token.
-
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
-
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
-
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings.
-
#basic_auth_token ⇒ Object
Gets Basic Auth token string.
- #configure {|_self| ... } ⇒ Object
- #configure_connection(conn) ⇒ Object
-
#configure_faraday_connection(&block) ⇒ Object
Configure Faraday connection directly.
-
#configure_middleware(connection) ⇒ Object
Set up middleware on the connection.
-
#initialize {|_self| ... } ⇒ Configuration
constructor
A new instance of Configuration.
- #operation_server_settings ⇒ Object
-
#request(*middleware) ⇒ Object
Adds request middleware to the stack.
-
#response(*middleware) ⇒ Object
Adds response middleware to the stack.
-
#server_settings ⇒ Object
Returns an array of Server setting.
-
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings.
-
#set_faraday_middleware(operation, key, *args, &block) ⇒ Object
Adds Faraday middleware setting information to the stack.
-
#use(*middleware) ⇒ Object
Adds middleware to the stack.
Constructor Details
#initialize {|_self| ... } ⇒ Configuration
Returns a new instance of Configuration.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/conekta/configuration.rb', line 148 def initialize @scheme = 'https' @host = 'api.conekta.io' @base_path = '' @server_index = nil @server_operation_index = {} @server_variables = {} @server_operation_variables = {} @api_key = {} @api_key_prefix = {} @client_side_validation = true @ssl_verify = true @ssl_verify_mode = nil @ssl_ca_file = File.dirname(__FILE__) + '/../ssl_data/ca_bundle.crt' @ssl_client_cert = nil @ssl_client_key = nil @middlewares = Hash.new { |h, k| h[k] = [] } @configure_connection_blocks = [] @timeout = 60 # return data as binary instead of file @return_binary_data = false @params_encoder = nil @debugging = false @inject_format = false @force_ending_format = false @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT) yield(self) if block_given? end |
Instance Attribute Details
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
62 63 64 |
# File 'lib/conekta/configuration.rb', line 62 def access_token @access_token end |
#access_token_getter ⇒ Proc
Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2. Overrides the access_token if set
67 68 69 |
# File 'lib/conekta/configuration.rb', line 67 def access_token_getter @access_token_getter end |
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
41 42 43 |
# File 'lib/conekta/configuration.rb', line 41 def api_key @api_key end |
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
49 50 51 |
# File 'lib/conekta/configuration.rb', line 49 def api_key_prefix @api_key_prefix end |
#base_path ⇒ Object
Defines url base path
21 22 23 |
# File 'lib/conekta/configuration.rb', line 21 def base_path @base_path end |
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation. Default to true.
101 102 103 |
# File 'lib/conekta/configuration.rb', line 101 def client_side_validation @client_side_validation end |
#debugging ⇒ true, false
Set this to enable/disable debugging. When enabled (set to true), HTTP request/response
details will be logged with logger.debug (see the logger attribute).
Default to false.
79 80 81 |
# File 'lib/conekta/configuration.rb', line 79 def debugging @debugging end |
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
146 147 148 |
# File 'lib/conekta/configuration.rb', line 146 def force_ending_format @force_ending_format end |
#host ⇒ Object
Defines url host
18 19 20 |
# File 'lib/conekta/configuration.rb', line 18 def host @host end |
#inject_format ⇒ Object
Returns the value of attribute inject_format.
144 145 146 |
# File 'lib/conekta/configuration.rb', line 144 def inject_format @inject_format end |
#logger ⇒ #debug
Defines the logger used for debugging.
Default to Rails.logger (when in Rails) or logging to STDOUT.
85 86 87 |
# File 'lib/conekta/configuration.rb', line 85 def logger @logger end |
#params_encoder ⇒ Object
Set this to customize parameters encoder of array parameter. Default to nil. Faraday uses NestedParamsEncoder when nil.
https://github.com/lostisland/faraday/tree/main/lib/faraday/encoders
142 143 144 |
# File 'lib/conekta/configuration.rb', line 142 def params_encoder @params_encoder end |
#password ⇒ String
Defines the password used with HTTP basic authentication.
59 60 61 |
# File 'lib/conekta/configuration.rb', line 59 def password @password end |
#proxy ⇒ Object
Proxy setting HTTP Proxy settings
135 136 137 |
# File 'lib/conekta/configuration.rb', line 135 def proxy @proxy end |
#return_binary_data ⇒ Object
Set this to return data as binary instead of downloading a temp file. When enabled (set to true)
HTTP responses with return type File will be returned as a stream of binary data.
Default to false.
72 73 74 |
# File 'lib/conekta/configuration.rb', line 72 def return_binary_data @return_binary_data end |
#scheme ⇒ Object
Defines url scheme
15 16 17 |
# File 'lib/conekta/configuration.rb', line 15 def scheme @scheme end |
#server_index ⇒ Object
Define server configuration index
24 25 26 |
# File 'lib/conekta/configuration.rb', line 24 def server_index @server_index end |
#server_operation_index ⇒ Object
Define server operation configuration index
27 28 29 |
# File 'lib/conekta/configuration.rb', line 27 def server_operation_index @server_operation_index end |
#server_operation_variables ⇒ Object
Default server operation variables
33 34 35 |
# File 'lib/conekta/configuration.rb', line 33 def server_operation_variables @server_operation_variables end |
#server_variables ⇒ Object
Default server variables
30 31 32 |
# File 'lib/conekta/configuration.rb', line 30 def server_variables @server_variables end |
#ssl_ca_file ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
123 124 125 |
# File 'lib/conekta/configuration.rb', line 123 def ssl_ca_file @ssl_ca_file end |
#ssl_client_cert ⇒ Object
TLS/SSL setting Client certificate file (for client certificate)
127 128 129 |
# File 'lib/conekta/configuration.rb', line 127 def ssl_client_cert @ssl_client_cert end |
#ssl_client_key ⇒ Object
TLS/SSL setting Client private key file (for client certificate)
131 132 133 |
# File 'lib/conekta/configuration.rb', line 131 def ssl_client_key @ssl_client_key end |
#ssl_verify ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.
110 111 112 |
# File 'lib/conekta/configuration.rb', line 110 def ssl_verify @ssl_verify end |
#ssl_verify_mode ⇒ Object
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting
Any OpenSSL::SSL:: constant (see https://ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)
117 118 119 |
# File 'lib/conekta/configuration.rb', line 117 def ssl_verify_mode @ssl_verify_mode end |
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files
(for API endpoints that have file response).
Default to use Tempfile.
92 93 94 |
# File 'lib/conekta/configuration.rb', line 92 def temp_folder_path @temp_folder_path end |
#timeout ⇒ Object
The time limit for HTTP request in seconds. Default to 0 (never times out).
96 97 98 |
# File 'lib/conekta/configuration.rb', line 96 def timeout @timeout end |
#username ⇒ String
Defines the username used with HTTP basic authentication.
54 55 56 |
# File 'lib/conekta/configuration.rb', line 54 def username @username end |
Class Method Details
.default ⇒ Object
The default Configuration object.
179 180 181 |
# File 'lib/conekta/configuration.rb', line 179 def self.default @@default ||= Configuration.new end |
Instance Method Details
#access_token_with_refresh ⇒ Object
Gets access_token using access_token_getter or uses the static access_token
226 227 228 229 |
# File 'lib/conekta/configuration.rb', line 226 def access_token_with_refresh return access_token if access_token_getter.nil? access_token_getter.call end |
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
215 216 217 218 219 220 221 222 223 |
# File 'lib/conekta/configuration.rb', line 215 def api_key_with_prefix(param_name, param_alias = nil) key = @api_key[param_name] key = @api_key.fetch(param_alias, key) unless param_alias.nil? if @api_key_prefix[param_name] "#{@api_key_prefix[param_name]} #{key}" else key end end |
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/conekta/configuration.rb', line 237 def auth_settings { 'bearerAuth' => { type: 'bearer', in: 'header', key: 'Authorization', value: "Bearer #{access_token_with_refresh}" }, } end |
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings
204 205 206 207 208 209 210 211 |
# File 'lib/conekta/configuration.rb', line 204 def base_url(operation = nil) if operation_server_settings.key?(operation) then index = server_operation_index.fetch(operation, server_index) server_url(index.nil? ? 0 : index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation]) else server_index.nil? ? "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') : server_url(server_index, server_variables, nil) end end |
#basic_auth_token ⇒ Object
Gets Basic Auth token string
232 233 234 |
# File 'lib/conekta/configuration.rb', line 232 def basic_auth_token 'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n") end |
#configure {|_self| ... } ⇒ Object
183 184 185 |
# File 'lib/conekta/configuration.rb', line 183 def configure yield(self) if block_given? end |
#configure_connection(conn) ⇒ Object
318 319 320 321 322 |
# File 'lib/conekta/configuration.rb', line 318 def configure_connection(conn) @configure_connection_blocks.each do |block| block.call(conn) end end |
#configure_faraday_connection(&block) ⇒ Object
Configure Faraday connection directly.
c.configure_faraday_connection do |conn|
conn.use Faraday::HttpCache, shared_cache: false, logger: logger
conn.response :logger, nil, headers: true, bodies: true, log_level: :debug do |logger|
logger.filter(/(Authorization: )(.*)/, '\1[REDACTED]')
end
end
c.configure_faraday_connection do |conn|
conn.adapter :typhoeus
end
314 315 316 |
# File 'lib/conekta/configuration.rb', line 314 def configure_faraday_connection(&block) @configure_connection_blocks << block end |
#configure_middleware(connection) ⇒ Object
Set up middleware on the connection
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/conekta/configuration.rb', line 361 def configure_middleware(connection) return if @middlewares.empty? [:request, :response, :use, :insert, :insert_before, :insert_after, :swap].each do |operation| next unless @middlewares.key?(operation) @middlewares[operation].each do |key, args, block| connection.builder.send(operation, key, *args, &block) end end if @middlewares.key?(:delete) @middlewares[:delete].each do |key, _args, _block| connection.builder.delete(key) end end end |
#operation_server_settings ⇒ Object
259 260 261 262 |
# File 'lib/conekta/configuration.rb', line 259 def operation_server_settings { } end |
#request(*middleware) ⇒ Object
Adds request middleware to the stack
330 331 332 |
# File 'lib/conekta/configuration.rb', line 330 def request(*middleware) set_faraday_middleware(:request, *middleware) end |
#response(*middleware) ⇒ Object
Adds response middleware to the stack
335 336 337 |
# File 'lib/conekta/configuration.rb', line 335 def response(*middleware) set_faraday_middleware(:response, *middleware) end |
#server_settings ⇒ Object
Returns an array of Server setting
250 251 252 253 254 255 256 257 |
# File 'lib/conekta/configuration.rb', line 250 def server_settings [ { url: "https://api.conekta.io", description: "Conekta main server", } ] end |
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/conekta/configuration.rb', line 268 def server_url(index, variables = {}, servers = nil) servers = server_settings if servers == nil # check array index out of bound if (index.nil? || index < 0 || index >= servers.size) fail ArgumentError, "Invalid index #{index} when selecting the server. Must not be nil and must be less than #{servers.size}" end server = servers[index] url = server[:url] return url unless server.key? :variables # go through variable and assign a value server[:variables].each do |name, variable| if variables.key?(name) if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name])) url.gsub! "{" + name.to_s + "}", variables[name] else fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}." end else # use default value url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value] end end url end |
#set_faraday_middleware(operation, key, *args, &block) ⇒ Object
Adds Faraday middleware setting information to the stack
350 351 352 353 354 355 356 357 |
# File 'lib/conekta/configuration.rb', line 350 def set_faraday_middleware(operation, key, *args, &block) unless [:request, :response, :use, :insert, :insert_before, :insert_after, :swap, :delete].include?(operation) fail ArgumentError, "Invalid faraday middleware operation #{operation}. Must be" \ " :request, :response, :use, :insert, :insert_before, :insert_after, :swap or :delete." end @middlewares[operation] << [key, args, block] end |
#use(*middleware) ⇒ Object
Adds middleware to the stack
325 326 327 |
# File 'lib/conekta/configuration.rb', line 325 def use(*middleware) set_faraday_middleware(:use, *middleware) end |