Class: Conekta::CreateCustomerFiscalEntitiesResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/conekta/models/create_customer_fiscal_entities_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateCustomerFiscalEntitiesResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CreateCustomerFiscalEntitiesResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CreateCustomerFiscalEntitiesResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'metadata')
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



18
19
20
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 18

def address
  @address
end

#company_nameObject

Returns the value of attribute company_name.



28
29
30
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 28

def company_name
  @company_name
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 34

def created_at
  @created_at
end

#defaultObject

Returns the value of attribute default.



38
39
40
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 38

def default
  @default
end

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 22

def email
  @email
end

#idObject

Returns the value of attribute id.



30
31
32
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 30

def id
  @id
end

#metadataObject

Returns the value of attribute metadata.



26
27
28
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 26

def 
  @metadata
end

#objectObject

Returns the value of attribute object.



32
33
34
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 32

def object
  @object
end

#parent_idObject

Returns the value of attribute parent_id.



36
37
38
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 36

def parent_id
  @parent_id
end

#phoneObject

Returns the value of attribute phone.



24
25
26
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 24

def phone
  @phone
end

#tax_idObject

Returns the value of attribute tax_id.



20
21
22
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 20

def tax_id
  @tax_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 41

def self.attribute_map
  {
    :'address' => :'address',
    :'tax_id' => :'tax_id',
    :'email' => :'email',
    :'phone' => :'phone',
    :'metadata' => :'metadata',
    :'company_name' => :'company_name',
    :'id' => :'id',
    :'object' => :'object',
    :'created_at' => :'created_at',
    :'parent_id' => :'parent_id',
    :'default' => :'default'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 267

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 85

def self.openapi_nullable
  Set.new([
    :'metadata',
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 68

def self.openapi_types
  {
    :'address' => :'FiscalEntityRequestAddress',
    :'tax_id' => :'String',
    :'email' => :'String',
    :'phone' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'company_name' => :'String',
    :'id' => :'String',
    :'object' => :'String',
    :'created_at' => :'Integer',
    :'parent_id' => :'String',
    :'default' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 236

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address == o.address &&
      tax_id == o.tax_id &&
      email == o.email &&
      phone == o.phone &&
       == o. &&
      company_name == o.company_name &&
      id == o.id &&
      object == o.object &&
      created_at == o.created_at &&
      parent_id == o.parent_id &&
      default == o.default
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 254

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



260
261
262
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 260

def hash
  [address, tax_id, email, phone, , company_name, id, object, created_at, parent_id, default].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
190
191
192
# File 'lib/conekta/models/create_customer_fiscal_entities_response.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @address.nil?
  return false if @id.nil?
  return false if @object.nil?
  return false if @created_at.nil?
  true
end