Class: Conekta::CustomerPortalResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/customer_portal_response.rb

Overview

Customer portal model

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerPortalResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/conekta/models/customer_portal_response.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CustomerPortalResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CustomerPortalResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'subscription_id')
    self.subscription_id = attributes[:'subscription_id']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  end

  if attributes.key?(:'subscription')
    self.subscription = attributes[:'subscription']
  end

  if attributes.key?(:'customer')
    self.customer = attributes[:'customer']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'portal_url')
    self.portal_url = attributes[:'portal_url']
  end
end

Instance Attribute Details

#company_idObject

Associated company ID



39
40
41
# File 'lib/conekta/models/customer_portal_response.rb', line 39

def company_id
  @company_id
end

#created_atObject

Unix timestamp of creation



44
45
46
# File 'lib/conekta/models/customer_portal_response.rb', line 44

def created_at
  @created_at
end

#customerObject

Returns the value of attribute customer.



33
34
35
# File 'lib/conekta/models/customer_portal_response.rb', line 33

def customer
  @customer
end

#customer_idObject

Associated customer ID



26
27
28
# File 'lib/conekta/models/customer_portal_response.rb', line 26

def customer_id
  @customer_id
end

#idObject

Customer portal ID



36
37
38
# File 'lib/conekta/models/customer_portal_response.rb', line 36

def id
  @id
end

#livemodeObject

Whether this is a live or test mode portal



29
30
31
# File 'lib/conekta/models/customer_portal_response.rb', line 29

def livemode
  @livemode
end

#objectObject

Returns the value of attribute object.



41
42
43
# File 'lib/conekta/models/customer_portal_response.rb', line 41

def object
  @object
end

#portal_urlObject

URL to access the customer portal



50
51
52
# File 'lib/conekta/models/customer_portal_response.rb', line 50

def portal_url
  @portal_url
end

#slugObject

Unique slug identifier for the portal



20
21
22
# File 'lib/conekta/models/customer_portal_response.rb', line 20

def slug
  @slug
end

#subscriptionObject

Returns the value of attribute subscription.



31
32
33
# File 'lib/conekta/models/customer_portal_response.rb', line 31

def subscription
  @subscription
end

#subscription_idObject

Associated subscription ID



23
24
25
# File 'lib/conekta/models/customer_portal_response.rb', line 23

def subscription_id
  @subscription_id
end

#updated_atObject

Unix timestamp of last update



47
48
49
# File 'lib/conekta/models/customer_portal_response.rb', line 47

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/conekta/models/customer_portal_response.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/conekta/models/customer_portal_response.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/conekta/models/customer_portal_response.rb', line 53

def self.attribute_map
  {
    :'slug' => :'slug',
    :'subscription_id' => :'subscription_id',
    :'customer_id' => :'customer_id',
    :'livemode' => :'livemode',
    :'subscription' => :'subscription',
    :'customer' => :'customer',
    :'id' => :'id',
    :'company_id' => :'company_id',
    :'object' => :'object',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'portal_url' => :'portal_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/conekta/models/customer_portal_response.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/conekta/models/customer_portal_response.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/conekta/models/customer_portal_response.rb', line 81

def self.openapi_types
  {
    :'slug' => :'String',
    :'subscription_id' => :'String',
    :'customer_id' => :'String',
    :'livemode' => :'Boolean',
    :'subscription' => :'SubscriptionDetails',
    :'customer' => :'CustomerDetails',
    :'id' => :'String',
    :'company_id' => :'String',
    :'object' => :'String',
    :'created_at' => :'Integer',
    :'updated_at' => :'Integer',
    :'portal_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/conekta/models/customer_portal_response.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      slug == o.slug &&
      subscription_id == o.subscription_id &&
      customer_id == o.customer_id &&
      livemode == o.livemode &&
      subscription == o.subscription &&
      customer == o.customer &&
      id == o.id &&
      company_id == o.company_id &&
      object == o.object &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      portal_url == o.portal_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/conekta/models/customer_portal_response.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/conekta/models/customer_portal_response.rb', line 211

def hash
  [slug, subscription_id, customer_id, livemode, subscription, customer, id, company_id, object, created_at, updated_at, portal_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
# File 'lib/conekta/models/customer_portal_response.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/conekta/models/customer_portal_response.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
# File 'lib/conekta/models/customer_portal_response.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end