Class: Conekta::CustomerResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/customer_response.rb

Overview

customer response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/conekta/models/customer_response.rb', line 138

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CustomerResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CustomerResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'antifraud_info')
    self.antifraud_info = attributes[:'antifraud_info']
  end

  if attributes.key?(:'corporate')
    self.corporate = attributes[:'corporate']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'custom_reference')
    self.custom_reference = attributes[:'custom_reference']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'default_fiscal_entity_id')
    self.default_fiscal_entity_id = attributes[:'default_fiscal_entity_id']
  end

  if attributes.key?(:'default_shipping_contact_id')
    self.default_shipping_contact_id = attributes[:'default_shipping_contact_id']
  end

  if attributes.key?(:'default_payment_source_id')
    self.default_payment_source_id = attributes[:'default_payment_source_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'fiscal_entities')
    self.fiscal_entities = attributes[:'fiscal_entities']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  else
    self.livemode = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'national_id')
    self.national_id = attributes[:'national_id']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'payment_sources')
    self.payment_sources = attributes[:'payment_sources']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'shipping_contacts')
    self.shipping_contacts = attributes[:'shipping_contacts']
  end

  if attributes.key?(:'subscription')
    self.subscription = attributes[:'subscription']
  end
end

Instance Attribute Details

#antifraud_infoObject

Returns the value of attribute antifraud_info.



19
20
21
# File 'lib/conekta/models/customer_response.rb', line 19

def antifraud_info
  @antifraud_info
end

#corporateObject

true if the customer is a company



22
23
24
# File 'lib/conekta/models/customer_response.rb', line 22

def corporate
  @corporate
end

#created_atObject

Creation date of the object



25
26
27
# File 'lib/conekta/models/customer_response.rb', line 25

def created_at
  @created_at
end

#custom_referenceObject

Custom reference



28
29
30
# File 'lib/conekta/models/customer_response.rb', line 28

def custom_reference
  @custom_reference
end

#date_of_birthObject

It is a parameter that allows to identify the date of birth of the client.



31
32
33
# File 'lib/conekta/models/customer_response.rb', line 31

def date_of_birth
  @date_of_birth
end

#default_fiscal_entity_idObject

Returns the value of attribute default_fiscal_entity_id.



33
34
35
# File 'lib/conekta/models/customer_response.rb', line 33

def default_fiscal_entity_id
  @default_fiscal_entity_id
end

#default_payment_source_idObject

Returns the value of attribute default_payment_source_id.



37
38
39
# File 'lib/conekta/models/customer_response.rb', line 37

def default_payment_source_id
  @default_payment_source_id
end

#default_shipping_contact_idObject

Returns the value of attribute default_shipping_contact_id.



35
36
37
# File 'lib/conekta/models/customer_response.rb', line 35

def default_shipping_contact_id
  @default_shipping_contact_id
end

#emailObject

Returns the value of attribute email.



39
40
41
# File 'lib/conekta/models/customer_response.rb', line 39

def email
  @email
end

#fiscal_entitiesObject

Returns the value of attribute fiscal_entities.



41
42
43
# File 'lib/conekta/models/customer_response.rb', line 41

def fiscal_entities
  @fiscal_entities
end

#idObject

Customer's ID



44
45
46
# File 'lib/conekta/models/customer_response.rb', line 44

def id
  @id
end

#livemodeObject

true if the object exists in live mode or the value false if the object exists in test mode



47
48
49
# File 'lib/conekta/models/customer_response.rb', line 47

def livemode
  @livemode
end

#metadataObject

Returns the value of attribute metadata.



55
56
57
# File 'lib/conekta/models/customer_response.rb', line 55

def 
  @metadata
end

#nameObject

Customer's name



50
51
52
# File 'lib/conekta/models/customer_response.rb', line 50

def name
  @name
end

#national_idObject

It is a parameter that allows to identify the national identification number of the client.



53
54
55
# File 'lib/conekta/models/customer_response.rb', line 53

def national_id
  @national_id
end

#objectObject

Returns the value of attribute object.



57
58
59
# File 'lib/conekta/models/customer_response.rb', line 57

def object
  @object
end

#payment_sourcesObject

Returns the value of attribute payment_sources.



59
60
61
# File 'lib/conekta/models/customer_response.rb', line 59

def payment_sources
  @payment_sources
end

#phoneObject

Customer's phone number



62
63
64
# File 'lib/conekta/models/customer_response.rb', line 62

def phone
  @phone
end

#shipping_contactsObject

Returns the value of attribute shipping_contacts.



64
65
66
# File 'lib/conekta/models/customer_response.rb', line 64

def shipping_contacts
  @shipping_contacts
end

#subscriptionObject

Returns the value of attribute subscription.



66
67
68
# File 'lib/conekta/models/customer_response.rb', line 66

def subscription
  @subscription
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/conekta/models/customer_response.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/conekta/models/customer_response.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/conekta/models/customer_response.rb', line 69

def self.attribute_map
  {
    :'antifraud_info' => :'antifraud_info',
    :'corporate' => :'corporate',
    :'created_at' => :'created_at',
    :'custom_reference' => :'custom_reference',
    :'date_of_birth' => :'date_of_birth',
    :'default_fiscal_entity_id' => :'default_fiscal_entity_id',
    :'default_shipping_contact_id' => :'default_shipping_contact_id',
    :'default_payment_source_id' => :'default_payment_source_id',
    :'email' => :'email',
    :'fiscal_entities' => :'fiscal_entities',
    :'id' => :'id',
    :'livemode' => :'livemode',
    :'name' => :'name',
    :'national_id' => :'national_id',
    :'metadata' => :'metadata',
    :'object' => :'object',
    :'payment_sources' => :'payment_sources',
    :'phone' => :'phone',
    :'shipping_contacts' => :'shipping_contacts',
    :'subscription' => :'subscription'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/conekta/models/customer_response.rb', line 396

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



131
132
133
134
# File 'lib/conekta/models/customer_response.rb', line 131

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/conekta/models/customer_response.rb', line 105

def self.openapi_types
  {
    :'antifraud_info' => :'CustomerAntifraudInfoResponse',
    :'corporate' => :'Boolean',
    :'created_at' => :'Integer',
    :'custom_reference' => :'String',
    :'date_of_birth' => :'String',
    :'default_fiscal_entity_id' => :'String',
    :'default_shipping_contact_id' => :'String',
    :'default_payment_source_id' => :'String',
    :'email' => :'String',
    :'fiscal_entities' => :'CustomerFiscalEntitiesResponse',
    :'id' => :'String',
    :'livemode' => :'Boolean',
    :'name' => :'String',
    :'national_id' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'object' => :'String',
    :'payment_sources' => :'CustomerPaymentMethodsResponse',
    :'phone' => :'String',
    :'shipping_contacts' => :'CustomerResponseShippingContacts',
    :'subscription' => :'SubscriptionResponse'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/conekta/models/customer_response.rb', line 356

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      antifraud_info == o.antifraud_info &&
      corporate == o.corporate &&
      created_at == o.created_at &&
      custom_reference == o.custom_reference &&
      date_of_birth == o.date_of_birth &&
      default_fiscal_entity_id == o.default_fiscal_entity_id &&
      default_shipping_contact_id == o.default_shipping_contact_id &&
      default_payment_source_id == o.default_payment_source_id &&
      email == o.email &&
      fiscal_entities == o.fiscal_entities &&
      id == o.id &&
      livemode == o.livemode &&
      name == o.name &&
      national_id == o.national_id &&
       == o. &&
      object == o.object &&
      payment_sources == o.payment_sources &&
      phone == o.phone &&
      shipping_contacts == o.shipping_contacts &&
      subscription == o.subscription
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


383
384
385
# File 'lib/conekta/models/customer_response.rb', line 383

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



389
390
391
# File 'lib/conekta/models/customer_response.rb', line 389

def hash
  [antifraud_info, corporate, created_at, custom_reference, date_of_birth, default_fiscal_entity_id, default_shipping_contact_id, default_payment_source_id, email, fiscal_entities, id, livemode, name, national_id, , object, payment_sources, phone, shipping_contacts, subscription].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/conekta/models/customer_response.rb', line 247

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @livemode.nil?
    invalid_properties.push('invalid value for "livemode", livemode cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/conekta/models/customer_response.rb', line 418

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



279
280
281
282
283
284
285
286
287
288
# File 'lib/conekta/models/customer_response.rb', line 279

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @livemode.nil?
  return false if @name.nil?
  return false if !@metadata.nil? && @metadata.length > 100
  return false if @object.nil?
  true
end