Class: Conekta::CustomerShippingContactsDataResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/conekta/models/customer_shipping_contacts_data_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerShippingContactsDataResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CustomerShippingContactsDataResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CustomerShippingContactsDataResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'receiver')
    self.receiver = attributes[:'receiver']
  end

  if attributes.key?(:'between_streets')
    self.between_streets = attributes[:'between_streets']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



27
28
29
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 27

def address
  @address
end

#between_streetsObject

The street names between which the order will be delivered.



25
26
27
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 25

def between_streets
  @between_streets
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 42

def created_at
  @created_at
end

#defaultObject

Returns the value of attribute default.



31
32
33
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 31

def default
  @default
end

#deletedObject

Returns the value of attribute deleted.



33
34
35
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 33

def deleted
  @deleted
end

#idObject

Returns the value of attribute id.



38
39
40
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 38

def id
  @id
end

#metadataObject

Metadata associated with the shipping contact



36
37
38
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 36

def 
  @metadata
end

#objectObject

Returns the value of attribute object.



40
41
42
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 40

def object
  @object
end

#parent_idObject

Returns the value of attribute parent_id.



29
30
31
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 29

def parent_id
  @parent_id
end

#phoneObject

Phone contact



19
20
21
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 19

def phone
  @phone
end

#receiverObject

Name of the person who will receive the order



22
23
24
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 22

def receiver
  @receiver
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 45

def self.attribute_map
  {
    :'phone' => :'phone',
    :'receiver' => :'receiver',
    :'between_streets' => :'between_streets',
    :'address' => :'address',
    :'parent_id' => :'parent_id',
    :'default' => :'default',
    :'deleted' => :'deleted',
    :'metadata' => :'metadata',
    :'id' => :'id',
    :'object' => :'object',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 292

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 72

def self.openapi_types
  {
    :'phone' => :'String',
    :'receiver' => :'String',
    :'between_streets' => :'String',
    :'address' => :'CustomerShippingContactsRequestAddress',
    :'parent_id' => :'String',
    :'default' => :'Boolean',
    :'deleted' => :'Boolean',
    :'metadata' => :'Hash<String, Object>',
    :'id' => :'String',
    :'object' => :'String',
    :'created_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      phone == o.phone &&
      receiver == o.receiver &&
      between_streets == o.between_streets &&
      address == o.address &&
      parent_id == o.parent_id &&
      default == o.default &&
      deleted == o.deleted &&
       == o. &&
      id == o.id &&
      object == o.object &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


279
280
281
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 279

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



285
286
287
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 285

def hash
  [phone, receiver, between_streets, address, parent_id, default, deleted, , id, object, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
199
200
201
202
203
# File 'lib/conekta/models/customer_shipping_contacts_data_response.rb', line 195

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @address.nil?
  return false if !@metadata.nil? && @metadata.length > 100
  return false if @id.nil?
  return false if @object.nil?
  return false if @created_at.nil?
  true
end