Class: Conekta::CustomerShippingContactsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/conekta/models/customer_shipping_contacts_request.rb

Overview

Shipping details, required in case of sending a shipping. If we do not receive a shipping_contact on the order, the default shipping_contact of the customer will be used.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerShippingContactsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CustomerShippingContactsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CustomerShippingContactsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'receiver')
    self.receiver = attributes[:'receiver']
  end

  if attributes.key?(:'between_streets')
    self.between_streets = attributes[:'between_streets']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



28
29
30
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 28

def address
  @address
end

#between_streetsObject

The street names between which the order will be delivered.



26
27
28
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 26

def between_streets
  @between_streets
end

#defaultObject

Returns the value of attribute default.



32
33
34
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 32

def default
  @default
end

#deletedObject

Returns the value of attribute deleted.



34
35
36
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 34

def deleted
  @deleted
end

#metadataObject

Metadata associated with the shipping contact



37
38
39
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 37

def 
  @metadata
end

#parent_idObject

Returns the value of attribute parent_id.



30
31
32
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 30

def parent_id
  @parent_id
end

#phoneObject

Phone contact



20
21
22
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 20

def phone
  @phone
end

#receiverObject

Name of the person who will receive the order



23
24
25
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 23

def receiver
  @receiver
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 40

def self.attribute_map
  {
    :'phone' => :'phone',
    :'receiver' => :'receiver',
    :'between_streets' => :'between_streets',
    :'address' => :'address',
    :'parent_id' => :'parent_id',
    :'default' => :'default',
    :'deleted' => :'deleted',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 64

def self.openapi_types
  {
    :'phone' => :'String',
    :'receiver' => :'String',
    :'between_streets' => :'String',
    :'address' => :'CustomerShippingContactsRequestAddress',
    :'parent_id' => :'String',
    :'default' => :'Boolean',
    :'deleted' => :'Boolean',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      phone == o.phone &&
      receiver == o.receiver &&
      between_streets == o.between_streets &&
      address == o.address &&
      parent_id == o.parent_id &&
      default == o.default &&
      deleted == o.deleted &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 208

def hash
  [phone, receiver, between_streets, address, parent_id, default, deleted, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
# File 'lib/conekta/models/customer_shipping_contacts_request.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @address.nil?
  return false if !@metadata.nil? && @metadata.length > 100
  true
end