Class: Conekta::CustomerShippingContactsRequestAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::CustomerShippingContactsRequestAddress
- Defined in:
- lib/conekta/models/customer_shipping_contacts_request_address.rb
Overview
Address of the person who will receive the order
Instance Attribute Summary collapse
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
this field follows the ISO 3166-1 alpha-2 standard.
-
#postal_code ⇒ Object
Returns the value of attribute postal_code.
-
#residential ⇒ Object
Returns the value of attribute residential.
-
#state ⇒ Object
Returns the value of attribute state.
-
#street1 ⇒ Object
Returns the value of attribute street1.
-
#street2 ⇒ Object
Returns the value of attribute street2.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerShippingContactsRequestAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerShippingContactsRequestAddress
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CustomerShippingContactsRequestAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CustomerShippingContactsRequestAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'street1') self.street1 = attributes[:'street1'] end if attributes.key?(:'street2') self.street2 = attributes[:'street2'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'residential') self.residential = attributes[:'residential'] end end |
Instance Attribute Details
#city ⇒ Object
Returns the value of attribute city.
25 26 27 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 25 def city @city end |
#country ⇒ Object
this field follows the ISO 3166-1 alpha-2 standard
30 31 32 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 30 def country @country end |
#postal_code ⇒ Object
Returns the value of attribute postal_code.
23 24 25 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 23 def postal_code @postal_code end |
#residential ⇒ Object
Returns the value of attribute residential.
32 33 34 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 32 def residential @residential end |
#state ⇒ Object
Returns the value of attribute state.
27 28 29 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 27 def state @state end |
#street1 ⇒ Object
Returns the value of attribute street1.
19 20 21 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 19 def street1 @street1 end |
#street2 ⇒ Object
Returns the value of attribute street2.
21 22 23 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 21 def street2 @street2 end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 35 def self.attribute_map { :'street1' => :'street1', :'street2' => :'street2', :'postal_code' => :'postal_code', :'city' => :'city', :'state' => :'state', :'country' => :'country', :'residential' => :'residential' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 165 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 58 def self.openapi_types { :'street1' => :'String', :'street2' => :'String', :'postal_code' => :'String', :'city' => :'String', :'state' => :'String', :'country' => :'String', :'residential' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && street1 == o.street1 && street2 == o.street2 && postal_code == o.postal_code && city == o.city && state == o.state && country == o.country && residential == o.residential end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 158 def hash [street1, street2, postal_code, city, state, country, residential].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 |
# File 'lib/conekta/models/customer_shipping_contacts_request_address.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |