Class: Conekta::CustomerUpdateShippingContactsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::CustomerUpdateShippingContactsRequest
- Defined in:
- lib/conekta/models/customer_update_shipping_contacts_request.rb
Overview
Shipping details, required in case of sending a shipping. If we do not receive a shipping_contact on the order, the default shipping_contact of the customer will be used.
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#between_streets ⇒ Object
The street names between which the order will be delivered.
-
#default ⇒ Object
Returns the value of attribute default.
-
#deleted ⇒ Object
Returns the value of attribute deleted.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
-
#phone ⇒ Object
Phone contact.
-
#receiver ⇒ Object
Name of the person who will receive the order.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerUpdateShippingContactsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomerUpdateShippingContactsRequest
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CustomerUpdateShippingContactsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CustomerUpdateShippingContactsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'receiver') self.receiver = attributes[:'receiver'] end if attributes.key?(:'between_streets') self.between_streets = attributes[:'between_streets'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'default') self.default = attributes[:'default'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
28 29 30 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 28 def address @address end |
#between_streets ⇒ Object
The street names between which the order will be delivered.
26 27 28 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 26 def between_streets @between_streets end |
#default ⇒ Object
Returns the value of attribute default.
32 33 34 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 32 def default @default end |
#deleted ⇒ Object
Returns the value of attribute deleted.
34 35 36 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 34 def deleted @deleted end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
30 31 32 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 30 def parent_id @parent_id end |
#phone ⇒ Object
Phone contact
20 21 22 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 20 def phone @phone end |
#receiver ⇒ Object
Name of the person who will receive the order
23 24 25 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 23 def receiver @receiver end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 37 def self.attribute_map { :'phone' => :'phone', :'receiver' => :'receiver', :'between_streets' => :'between_streets', :'address' => :'address', :'parent_id' => :'parent_id', :'default' => :'default', :'deleted' => :'deleted' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 60 def self.openapi_types { :'phone' => :'String', :'receiver' => :'String', :'between_streets' => :'String', :'address' => :'CustomerShippingContactsRequestAddress', :'parent_id' => :'String', :'default' => :'Boolean', :'deleted' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && phone == o.phone && receiver == o.receiver && between_streets == o.between_streets && address == o.address && parent_id == o.parent_id && default == o.default && deleted == o.deleted end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 160 def hash [phone, receiver, between_streets, address, parent_id, default, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 |
# File 'lib/conekta/models/customer_update_shipping_contacts_request.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |