Class: Conekta::DiscountLinesDataResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/discount_lines_data_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DiscountLinesDataResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/conekta/models/discount_lines_data_response.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::DiscountLinesDataResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::DiscountLinesDataResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  else
    self.parent_id = nil
  end
end

Instance Attribute Details

#amountObject

The amount to be deducted from the total sum of all payments, in cents.



19
20
21
# File 'lib/conekta/models/discount_lines_data_response.rb', line 19

def amount
  @amount
end

#codeObject

Discount code.



22
23
24
# File 'lib/conekta/models/discount_lines_data_response.rb', line 22

def code
  @code
end

#idObject

The discount line id



28
29
30
# File 'lib/conekta/models/discount_lines_data_response.rb', line 28

def id
  @id
end

#objectObject

The object name



31
32
33
# File 'lib/conekta/models/discount_lines_data_response.rb', line 31

def object
  @object
end

#parent_idObject

The order id



34
35
36
# File 'lib/conekta/models/discount_lines_data_response.rb', line 34

def parent_id
  @parent_id
end

#typeObject

It can be 'loyalty', 'campaign', 'coupon' o 'sign'



25
26
27
# File 'lib/conekta/models/discount_lines_data_response.rb', line 25

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/conekta/models/discount_lines_data_response.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/conekta/models/discount_lines_data_response.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/conekta/models/discount_lines_data_response.rb', line 37

def self.attribute_map
  {
    :'amount' => :'amount',
    :'code' => :'code',
    :'type' => :'type',
    :'id' => :'id',
    :'object' => :'object',
    :'parent_id' => :'parent_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/conekta/models/discount_lines_data_response.rb', line 271

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/conekta/models/discount_lines_data_response.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/conekta/models/discount_lines_data_response.rb', line 59

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'code' => :'String',
    :'type' => :'String',
    :'id' => :'String',
    :'object' => :'String',
    :'parent_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
# File 'lib/conekta/models/discount_lines_data_response.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      code == o.code &&
      type == o.type &&
      id == o.id &&
      object == o.object &&
      parent_id == o.parent_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


258
259
260
# File 'lib/conekta/models/discount_lines_data_response.rb', line 258

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



264
265
266
# File 'lib/conekta/models/discount_lines_data_response.rb', line 264

def hash
  [amount, code, type, id, object, parent_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/conekta/models/discount_lines_data_response.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @parent_id.nil?
    invalid_properties.push('invalid value for "parent_id", parent_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/conekta/models/discount_lines_data_response.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
175
176
177
# File 'lib/conekta/models/discount_lines_data_response.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 0
  return false if @code.nil?
  return false if @type.nil?
  return false if @id.nil?
  return false if @object.nil?
  return false if @parent_id.nil?
  true
end