Class: Conekta::EventResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/event_response.rb

Overview

event model

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EventResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/conekta/models/event_response.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::EventResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::EventResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Hash)
      self.data = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'webhook_logs')
    if (value = attributes[:'webhook_logs']).is_a?(Array)
      self.webhook_logs = value
    end
  end

  if attributes.key?(:'webhook_status')
    self.webhook_status = attributes[:'webhook_status']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



19
20
21
# File 'lib/conekta/models/event_response.rb', line 19

def created_at
  @created_at
end

#dataObject

Returns the value of attribute data.



21
22
23
# File 'lib/conekta/models/event_response.rb', line 21

def data
  @data
end

#idObject

Returns the value of attribute id.



23
24
25
# File 'lib/conekta/models/event_response.rb', line 23

def id
  @id
end

#livemodeObject

Returns the value of attribute livemode.



25
26
27
# File 'lib/conekta/models/event_response.rb', line 25

def livemode
  @livemode
end

#objectObject

Returns the value of attribute object.



27
28
29
# File 'lib/conekta/models/event_response.rb', line 27

def object
  @object
end

#typeObject

Returns the value of attribute type.



29
30
31
# File 'lib/conekta/models/event_response.rb', line 29

def type
  @type
end

#webhook_logsObject

Returns the value of attribute webhook_logs.



31
32
33
# File 'lib/conekta/models/event_response.rb', line 31

def webhook_logs
  @webhook_logs
end

#webhook_statusObject

Returns the value of attribute webhook_status.



33
34
35
# File 'lib/conekta/models/event_response.rb', line 33

def webhook_status
  @webhook_status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/conekta/models/event_response.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/conekta/models/event_response.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/conekta/models/event_response.rb', line 36

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'data' => :'data',
    :'id' => :'id',
    :'livemode' => :'livemode',
    :'object' => :'object',
    :'type' => :'type',
    :'webhook_logs' => :'webhook_logs',
    :'webhook_status' => :'webhook_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/conekta/models/event_response.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/conekta/models/event_response.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/conekta/models/event_response.rb', line 60

def self.openapi_types
  {
    :'created_at' => :'Integer',
    :'data' => :'Hash<String, Object>',
    :'id' => :'String',
    :'livemode' => :'Boolean',
    :'object' => :'String',
    :'type' => :'String',
    :'webhook_logs' => :'Array<WebhookLog>',
    :'webhook_status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/conekta/models/event_response.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      data == o.data &&
      id == o.id &&
      livemode == o.livemode &&
      object == o.object &&
      type == o.type &&
      webhook_logs == o.webhook_logs &&
      webhook_status == o.webhook_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/conekta/models/event_response.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/conekta/models/event_response.rb', line 189

def hash
  [created_at, data, id, livemode, object, type, webhook_logs, webhook_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
# File 'lib/conekta/models/event_response.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@data.nil? && @data.length > 100
    invalid_properties.push('invalid value for "data", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/conekta/models/event_response.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
# File 'lib/conekta/models/event_response.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@data.nil? && @data.length > 100
  true
end