Class: Conekta::EventsResendResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::EventsResendResponse
- Defined in:
- lib/conekta/models/events_resend_response.rb
Overview
event model
Instance Attribute Summary collapse
-
#failed_attempts ⇒ Object
Returns the value of attribute failed_attempts.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_attempted_at ⇒ Object
Returns the value of attribute last_attempted_at.
-
#last_http_response_status ⇒ Object
Returns the value of attribute last_http_response_status.
-
#response_data ⇒ Object
Returns the value of attribute response_data.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventsResendResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EventsResendResponse
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/conekta/models/events_resend_response.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::EventsResendResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::EventsResendResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'failed_attempts') self.failed_attempts = attributes[:'failed_attempts'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'last_attempted_at') self.last_attempted_at = attributes[:'last_attempted_at'] end if attributes.key?(:'last_http_response_status') self.last_http_response_status = attributes[:'last_http_response_status'] end if attributes.key?(:'response_data') if (value = attributes[:'response_data']).is_a?(Hash) self.response_data = value end end if attributes.key?(:'url') self.url = attributes[:'url'] end end |
Instance Attribute Details
#failed_attempts ⇒ Object
Returns the value of attribute failed_attempts.
19 20 21 |
# File 'lib/conekta/models/events_resend_response.rb', line 19 def failed_attempts @failed_attempts end |
#id ⇒ Object
Returns the value of attribute id.
21 22 23 |
# File 'lib/conekta/models/events_resend_response.rb', line 21 def id @id end |
#last_attempted_at ⇒ Object
Returns the value of attribute last_attempted_at.
23 24 25 |
# File 'lib/conekta/models/events_resend_response.rb', line 23 def last_attempted_at @last_attempted_at end |
#last_http_response_status ⇒ Object
Returns the value of attribute last_http_response_status.
25 26 27 |
# File 'lib/conekta/models/events_resend_response.rb', line 25 def last_http_response_status @last_http_response_status end |
#response_data ⇒ Object
Returns the value of attribute response_data.
27 28 29 |
# File 'lib/conekta/models/events_resend_response.rb', line 27 def response_data @response_data end |
#url ⇒ Object
Returns the value of attribute url.
29 30 31 |
# File 'lib/conekta/models/events_resend_response.rb', line 29 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/conekta/models/events_resend_response.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/conekta/models/events_resend_response.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/conekta/models/events_resend_response.rb', line 32 def self.attribute_map { :'failed_attempts' => :'failed_attempts', :'id' => :'id', :'last_attempted_at' => :'last_attempted_at', :'last_http_response_status' => :'last_http_response_status', :'response_data' => :'response_data', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/conekta/models/events_resend_response.rb', line 176 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/conekta/models/events_resend_response.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/conekta/models/events_resend_response.rb', line 54 def self.openapi_types { :'failed_attempts' => :'Integer', :'id' => :'String', :'last_attempted_at' => :'Integer', :'last_http_response_status' => :'Integer', :'response_data' => :'Hash<String, Object>', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/conekta/models/events_resend_response.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && failed_attempts == o.failed_attempts && id == o.id && last_attempted_at == o.last_attempted_at && last_http_response_status == o.last_http_response_status && response_data == o.response_data && url == o.url end |
#eql?(o) ⇒ Boolean
163 164 165 |
# File 'lib/conekta/models/events_resend_response.rb', line 163 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/conekta/models/events_resend_response.rb', line 169 def hash [failed_attempts, id, last_attempted_at, last_http_response_status, response_data, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 |
# File 'lib/conekta/models/events_resend_response.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@response_data.nil? && @response_data.length > 100 invalid_properties.push('invalid value for "response_data", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/conekta/models/events_resend_response.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 |
# File 'lib/conekta/models/events_resend_response.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@response_data.nil? && @response_data.length > 100 true end |