Class: Conekta::LogsResponseData

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/logs_response_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LogsResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/conekta/models/logs_response_data.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::LogsResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::LogsResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  end

  if attributes.key?(:'loggable_id')
    self.loggable_id = attributes[:'loggable_id']
  end

  if attributes.key?(:'loggable_type')
    self.loggable_type = attributes[:'loggable_type']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'oauth_token_id')
    self.oauth_token_id = attributes[:'oauth_token_id']
  end

  if attributes.key?(:'query_string')
    if (value = attributes[:'query_string']).is_a?(Hash)
      self.query_string = value
    end
  end

  if attributes.key?(:'related')
    self.related = attributes[:'related']
  end

  if attributes.key?(:'request_body')
    self.request_body = attributes[:'request_body']
  end

  if attributes.key?(:'request_headers')
  end

  if attributes.key?(:'response_body')
    self.response_body = attributes[:'response_body']
  end

  if attributes.key?(:'response_headers')
  end

  if attributes.key?(:'searchable_tags')
    if (value = attributes[:'searchable_tags']).is_a?(Array)
      self.searchable_tags = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'user_account_id')
    self. = attributes[:'user_account_id']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



18
19
20
# File 'lib/conekta/models/logs_response_data.rb', line 18

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



20
21
22
# File 'lib/conekta/models/logs_response_data.rb', line 20

def id
  @id
end

#ip_addressObject

Returns the value of attribute ip_address.



22
23
24
# File 'lib/conekta/models/logs_response_data.rb', line 22

def ip_address
  @ip_address
end

#livemodeObject

Returns the value of attribute livemode.



24
25
26
# File 'lib/conekta/models/logs_response_data.rb', line 24

def livemode
  @livemode
end

#loggable_idObject

Returns the value of attribute loggable_id.



26
27
28
# File 'lib/conekta/models/logs_response_data.rb', line 26

def loggable_id
  @loggable_id
end

#loggable_typeObject

Returns the value of attribute loggable_type.



28
29
30
# File 'lib/conekta/models/logs_response_data.rb', line 28

def loggable_type
  @loggable_type
end

#methodObject

Returns the value of attribute method.



30
31
32
# File 'lib/conekta/models/logs_response_data.rb', line 30

def method
  @method
end

#oauth_token_idObject

Returns the value of attribute oauth_token_id.



32
33
34
# File 'lib/conekta/models/logs_response_data.rb', line 32

def oauth_token_id
  @oauth_token_id
end

#query_stringObject

Returns the value of attribute query_string.



34
35
36
# File 'lib/conekta/models/logs_response_data.rb', line 34

def query_string
  @query_string
end

Returns the value of attribute related.



36
37
38
# File 'lib/conekta/models/logs_response_data.rb', line 36

def related
  @related
end

#request_bodyObject

Returns the value of attribute request_body.



38
39
40
# File 'lib/conekta/models/logs_response_data.rb', line 38

def request_body
  @request_body
end

#request_headersObject

Returns the value of attribute request_headers.



40
41
42
# File 'lib/conekta/models/logs_response_data.rb', line 40

def request_headers
  @request_headers
end

#response_bodyObject

Returns the value of attribute response_body.



42
43
44
# File 'lib/conekta/models/logs_response_data.rb', line 42

def response_body
  @response_body
end

#response_headersObject

Returns the value of attribute response_headers.



44
45
46
# File 'lib/conekta/models/logs_response_data.rb', line 44

def response_headers
  @response_headers
end

#searchable_tagsObject

Returns the value of attribute searchable_tags.



46
47
48
# File 'lib/conekta/models/logs_response_data.rb', line 46

def searchable_tags
  @searchable_tags
end

#statusObject

Returns the value of attribute status.



48
49
50
# File 'lib/conekta/models/logs_response_data.rb', line 48

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



50
51
52
# File 'lib/conekta/models/logs_response_data.rb', line 50

def updated_at
  @updated_at
end

#urlObject

Returns the value of attribute url.



52
53
54
# File 'lib/conekta/models/logs_response_data.rb', line 52

def url
  @url
end

#user_account_idObject

Returns the value of attribute user_account_id.



54
55
56
# File 'lib/conekta/models/logs_response_data.rb', line 54

def 
  @user_account_id
end

#versionObject

Returns the value of attribute version.



56
57
58
# File 'lib/conekta/models/logs_response_data.rb', line 56

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/conekta/models/logs_response_data.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/conekta/models/logs_response_data.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/conekta/models/logs_response_data.rb', line 59

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'id' => :'id',
    :'ip_address' => :'ip_address',
    :'livemode' => :'livemode',
    :'loggable_id' => :'loggable_id',
    :'loggable_type' => :'loggable_type',
    :'method' => :'method',
    :'oauth_token_id' => :'oauth_token_id',
    :'query_string' => :'query_string',
    :'related' => :'related',
    :'request_body' => :'request_body',
    :'request_headers' => :'request_headers',
    :'response_body' => :'response_body',
    :'response_headers' => :'response_headers',
    :'searchable_tags' => :'searchable_tags',
    :'status' => :'status',
    :'updated_at' => :'updated_at',
    :'url' => :'url',
    :'user_account_id' => :'user_account_id',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/conekta/models/logs_response_data.rb', line 284

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
# File 'lib/conekta/models/logs_response_data.rb', line 121

def self.openapi_nullable
  Set.new([
    :'request_headers',
    :'response_headers',
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/conekta/models/logs_response_data.rb', line 95

def self.openapi_types
  {
    :'created_at' => :'Integer',
    :'id' => :'String',
    :'ip_address' => :'String',
    :'livemode' => :'Boolean',
    :'loggable_id' => :'String',
    :'loggable_type' => :'String',
    :'method' => :'String',
    :'oauth_token_id' => :'String',
    :'query_string' => :'Hash<String, Object>',
    :'related' => :'String',
    :'request_body' => :'Object',
    :'request_headers' => :'Hash<String, String>',
    :'response_body' => :'Object',
    :'response_headers' => :'Hash<String, String>',
    :'searchable_tags' => :'Array<String>',
    :'status' => :'String',
    :'updated_at' => :'String',
    :'url' => :'String',
    :'user_account_id' => :'String',
    :'version' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/conekta/models/logs_response_data.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      id == o.id &&
      ip_address == o.ip_address &&
      livemode == o.livemode &&
      loggable_id == o.loggable_id &&
      loggable_type == o.loggable_type &&
      method == o.method &&
      oauth_token_id == o.oauth_token_id &&
      query_string == o.query_string &&
      related == o.related &&
      request_body == o.request_body &&
      request_headers == o.request_headers &&
      response_body == o.response_body &&
      response_headers == o.response_headers &&
      searchable_tags == o.searchable_tags &&
      status == o.status &&
      updated_at == o.updated_at &&
      url == o.url &&
       == o. &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


271
272
273
# File 'lib/conekta/models/logs_response_data.rb', line 271

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



277
278
279
# File 'lib/conekta/models/logs_response_data.rb', line 277

def hash
  [created_at, id, ip_address, livemode, loggable_id, loggable_type, method, oauth_token_id, query_string, related, request_body, request_headers, response_body, response_headers, searchable_tags, status, updated_at, url, , version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
# File 'lib/conekta/models/logs_response_data.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/conekta/models/logs_response_data.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



237
238
239
240
# File 'lib/conekta/models/logs_response_data.rb', line 237

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end