Class: Conekta::OrderCheckoutRequest

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/order_checkout_request.rb

Overview

Checkout details

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderCheckoutRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/conekta/models/order_checkout_request.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderCheckoutRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderCheckoutRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allowed_payment_methods')
    if (value = attributes[:'allowed_payment_methods']).is_a?(Array)
      self.allowed_payment_methods = value
    end
  end

  if attributes.key?(:'excluded_payment_methods')
    if (value = attributes[:'excluded_payment_methods']).is_a?(Array)
      self.excluded_payment_methods = value
    end
  end

  if attributes.key?(:'exclude_card_networks')
    if (value = attributes[:'exclude_card_networks']).is_a?(Array)
      self.exclude_card_networks = value
    end
  end

  if attributes.key?(:'plan_ids')
    if (value = attributes[:'plan_ids']).is_a?(Array)
      self.plan_ids = value
    end
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'failure_url')
    self.failure_url = attributes[:'failure_url']
  end

  if attributes.key?(:'force_save_card')
    self.force_save_card = attributes[:'force_save_card']
  end

  if attributes.key?(:'monthly_installments_enabled')
    self.monthly_installments_enabled = attributes[:'monthly_installments_enabled']
  end

  if attributes.key?(:'monthly_installments_options')
    if (value = attributes[:'monthly_installments_options']).is_a?(Array)
      self.monthly_installments_options = value
    end
  end

  if attributes.key?(:'max_failed_retries')
    self.max_failed_retries = attributes[:'max_failed_retries']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'on_demand_enabled')
    self.on_demand_enabled = attributes[:'on_demand_enabled']
  end

  if attributes.key?(:'redirection_time')
    self.redirection_time = attributes[:'redirection_time']
  end

  if attributes.key?(:'success_url')
    self.success_url = attributes[:'success_url']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#allowed_payment_methodsObject

Are the payment methods available for this link. For subscriptions, only 'card' is allowed due to the recurring nature of the payments. This field is mutually exclusive with excluded_payment_methods.



20
21
22
# File 'lib/conekta/models/order_checkout_request.rb', line 20

def allowed_payment_methods
  @allowed_payment_methods
end

#exclude_card_networksObject

List of card networks to exclude from the checkout. This field is only applicable for card payments.



26
27
28
# File 'lib/conekta/models/order_checkout_request.rb', line 26

def exclude_card_networks
  @exclude_card_networks
end

#excluded_payment_methodsObject

Payment methods to be excluded from the checkout. This field is mutually exclusive with allowed_payment_methods.



23
24
25
# File 'lib/conekta/models/order_checkout_request.rb', line 23

def excluded_payment_methods
  @excluded_payment_methods
end

#expires_atObject

It is the time when the link will expire. It is expressed in seconds since the Unix epoch. The valid range is from 5 minutes to 365 days from the creation date.



32
33
34
# File 'lib/conekta/models/order_checkout_request.rb', line 32

def expires_at
  @expires_at
end

#failure_urlObject

Redirection url back to the site in case of failed payment, applies only to HostedPayment.



35
36
37
# File 'lib/conekta/models/order_checkout_request.rb', line 35

def failure_url
  @failure_url
end

#force_save_cardObject

Indicates whether the card used for the payment should be saved for future purchases. This field is only applicable for card payments.



38
39
40
# File 'lib/conekta/models/order_checkout_request.rb', line 38

def force_save_card
  @force_save_card
end

#max_failed_retriesObject

Number of retries allowed before the checkout is marked as failed



45
46
47
# File 'lib/conekta/models/order_checkout_request.rb', line 45

def max_failed_retries
  @max_failed_retries
end

#monthly_installments_enabledObject

Returns the value of attribute monthly_installments_enabled.



40
41
42
# File 'lib/conekta/models/order_checkout_request.rb', line 40

def monthly_installments_enabled
  @monthly_installments_enabled
end

#monthly_installments_optionsObject

Returns the value of attribute monthly_installments_options.



42
43
44
# File 'lib/conekta/models/order_checkout_request.rb', line 42

def monthly_installments_options
  @monthly_installments_options
end

#nameObject

Reason for payment



48
49
50
# File 'lib/conekta/models/order_checkout_request.rb', line 48

def name
  @name
end

#on_demand_enabledObject

Returns the value of attribute on_demand_enabled.



50
51
52
# File 'lib/conekta/models/order_checkout_request.rb', line 50

def on_demand_enabled
  @on_demand_enabled
end

#plan_idsObject

List of plan IDs that will be available for subscription. This field is required for subscription payments.



29
30
31
# File 'lib/conekta/models/order_checkout_request.rb', line 29

def plan_ids
  @plan_ids
end

#redirection_timeObject

number of seconds to wait before redirecting to the success_url



53
54
55
# File 'lib/conekta/models/order_checkout_request.rb', line 53

def redirection_time
  @redirection_time
end

#success_urlObject

Redirection url back to the site in case of successful payment, applies only to HostedPayment



56
57
58
# File 'lib/conekta/models/order_checkout_request.rb', line 56

def success_url
  @success_url
end

#typeObject

Required. This field represents the type of checkout, which determines the user experience during the payment process. 'HostedPayment' will redirect the customer to a Conekta-hosted page to complete the payment, while 'Integration' allows the payment process to be handled entirely on your site using Conekta's APIs and SDKs.



59
60
61
# File 'lib/conekta/models/order_checkout_request.rb', line 59

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



105
106
107
# File 'lib/conekta/models/order_checkout_request.rb', line 105

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/conekta/models/order_checkout_request.rb', line 110

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/conekta/models/order_checkout_request.rb', line 84

def self.attribute_map
  {
    :'allowed_payment_methods' => :'allowed_payment_methods',
    :'excluded_payment_methods' => :'excluded_payment_methods',
    :'exclude_card_networks' => :'exclude_card_networks',
    :'plan_ids' => :'plan_ids',
    :'expires_at' => :'expires_at',
    :'failure_url' => :'failure_url',
    :'force_save_card' => :'force_save_card',
    :'monthly_installments_enabled' => :'monthly_installments_enabled',
    :'monthly_installments_options' => :'monthly_installments_options',
    :'max_failed_retries' => :'max_failed_retries',
    :'name' => :'name',
    :'on_demand_enabled' => :'on_demand_enabled',
    :'redirection_time' => :'redirection_time',
    :'success_url' => :'success_url',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/conekta/models/order_checkout_request.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



136
137
138
139
# File 'lib/conekta/models/order_checkout_request.rb', line 136

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/conekta/models/order_checkout_request.rb', line 115

def self.openapi_types
  {
    :'allowed_payment_methods' => :'Array<String>',
    :'excluded_payment_methods' => :'Array<String>',
    :'exclude_card_networks' => :'Array<String>',
    :'plan_ids' => :'Array<String>',
    :'expires_at' => :'Integer',
    :'failure_url' => :'String',
    :'force_save_card' => :'Boolean',
    :'monthly_installments_enabled' => :'Boolean',
    :'monthly_installments_options' => :'Array<Integer>',
    :'max_failed_retries' => :'Integer',
    :'name' => :'String',
    :'on_demand_enabled' => :'Boolean',
    :'redirection_time' => :'Integer',
    :'success_url' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/conekta/models/order_checkout_request.rb', line 276

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allowed_payment_methods == o.allowed_payment_methods &&
      excluded_payment_methods == o.excluded_payment_methods &&
      exclude_card_networks == o.exclude_card_networks &&
      plan_ids == o.plan_ids &&
      expires_at == o.expires_at &&
      failure_url == o.failure_url &&
      force_save_card == o.force_save_card &&
      monthly_installments_enabled == o.monthly_installments_enabled &&
      monthly_installments_options == o.monthly_installments_options &&
      max_failed_retries == o.max_failed_retries &&
      name == o.name &&
      on_demand_enabled == o.on_demand_enabled &&
      redirection_time == o.redirection_time &&
      success_url == o.success_url &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/conekta/models/order_checkout_request.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/conekta/models/order_checkout_request.rb', line 304

def hash
  [allowed_payment_methods, excluded_payment_methods, exclude_card_networks, plan_ids, expires_at, failure_url, force_save_card, monthly_installments_enabled, monthly_installments_options, max_failed_retries, name, on_demand_enabled, redirection_time, success_url, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



230
231
232
233
234
235
236
237
238
# File 'lib/conekta/models/order_checkout_request.rb', line 230

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@expires_at.nil? && @expires_at < 1
    invalid_properties.push('invalid value for "expires_at", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/conekta/models/order_checkout_request.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



242
243
244
245
246
247
248
# File 'lib/conekta/models/order_checkout_request.rb', line 242

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@expires_at.nil? && @expires_at < 1
  type_validator = EnumAttributeValidator.new('String', ["Integration", "HostedPayment"])
  return false unless type_validator.valid?(@type)
  true
end