Class: Conekta::OrderFiscalEntityAddressResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/conekta/models/order_fiscal_entity_address_response.rb

Overview

Address of the fiscal entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderFiscalEntityAddressResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderFiscalEntityAddressResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderFiscalEntityAddressResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'street1')
    self.street1 = attributes[:'street1']
  else
    self.street1 = nil
  end

  if attributes.key?(:'street2')
    self.street2 = attributes[:'street2']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  else
    self.postal_code = nil
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  else
    self.city = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'external_number')
    self.external_number = attributes[:'external_number']
  else
    self.external_number = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end
end

Instance Attribute Details

#cityObject

City



29
30
31
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 29

def city
  @city
end

#countryObject

this field follows the ISO 3166-1 alpha-2 standard



35
36
37
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 35

def country
  @country
end

#external_numberObject

External number



38
39
40
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 38

def external_number
  @external_number
end

#objectObject

Returns the value of attribute object.



40
41
42
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 40

def object
  @object
end

#postal_codeObject

Postal code



26
27
28
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 26

def postal_code
  @postal_code
end

#stateObject

State



32
33
34
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 32

def state
  @state
end

#street1Object

Street name and number



20
21
22
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 20

def street1
  @street1
end

#street2Object

Street name and number



23
24
25
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 23

def street2
  @street2
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 43

def self.attribute_map
  {
    :'street1' => :'street1',
    :'street2' => :'street2',
    :'postal_code' => :'postal_code',
    :'city' => :'city',
    :'state' => :'state',
    :'country' => :'country',
    :'external_number' => :'external_number',
    :'object' => :'object'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 265

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 67

def self.openapi_types
  {
    :'street1' => :'String',
    :'street2' => :'String',
    :'postal_code' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'country' => :'String',
    :'external_number' => :'String',
    :'object' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 237

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      street1 == o.street1 &&
      street2 == o.street2 &&
      postal_code == o.postal_code &&
      city == o.city &&
      state == o.state &&
      country == o.country &&
      external_number == o.external_number &&
      object == o.object
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 258

def hash
  [street1, street2, postal_code, city, state, country, external_number, object].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @street1.nil?
    invalid_properties.push('invalid value for "street1", street1 cannot be nil.')
  end

  if @postal_code.nil?
    invalid_properties.push('invalid value for "postal_code", postal_code cannot be nil.')
  end

  if @city.nil?
    invalid_properties.push('invalid value for "city", city cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @external_number.nil?
    invalid_properties.push('invalid value for "external_number", external_number cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



175
176
177
178
179
180
181
182
183
# File 'lib/conekta/models/order_fiscal_entity_address_response.rb', line 175

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @street1.nil?
  return false if @postal_code.nil?
  return false if @city.nil?
  return false if @country.nil?
  return false if @external_number.nil?
  true
end