Class: Conekta::OrderFiscalEntityResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::OrderFiscalEntityResponse
- Defined in:
- lib/conekta/models/order_fiscal_entity_response.rb
Overview
Fiscal entity of the order, Currently it is a purely informative field
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#created_at ⇒ Object
The time at which the object was created in seconds since the Unix epoch.
-
#email ⇒ Object
Email of the fiscal entity.
-
#id ⇒ Object
ID of the fiscal entity.
-
#metadata ⇒ Object
Metadata associated with the fiscal entity.
-
#name ⇒ Object
Name of the fiscal entity.
-
#object ⇒ Object
Returns the value of attribute object.
-
#phone ⇒ Object
Phone of the fiscal entity.
-
#tax_id ⇒ Object
Tax ID of the fiscal entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderFiscalEntityResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrderFiscalEntityResponse
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderFiscalEntityResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderFiscalEntityResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'address') self.address = attributes[:'address'] else self.address = nil end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'tax_id') self.tax_id = attributes[:'tax_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
19 20 21 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 19 def address @address end |
#created_at ⇒ Object
The time at which the object was created in seconds since the Unix epoch
37 38 39 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 37 def created_at @created_at end |
#email ⇒ Object
Email of the fiscal entity
22 23 24 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 22 def email @email end |
#id ⇒ Object
ID of the fiscal entity
34 35 36 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 34 def id @id end |
#metadata ⇒ Object
Metadata associated with the fiscal entity
25 26 27 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 25 def @metadata end |
#name ⇒ Object
Name of the fiscal entity
28 29 30 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 28 def name @name end |
#object ⇒ Object
Returns the value of attribute object.
39 40 41 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 39 def object @object end |
#phone ⇒ Object
Phone of the fiscal entity
42 43 44 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 42 def phone @phone end |
#tax_id ⇒ Object
Tax ID of the fiscal entity
31 32 33 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 31 def tax_id @tax_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 45 def self.attribute_map { :'address' => :'address', :'email' => :'email', :'metadata' => :'metadata', :'name' => :'name', :'tax_id' => :'tax_id', :'id' => :'id', :'created_at' => :'created_at', :'object' => :'object', :'phone' => :'phone' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 278 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 70 def self.openapi_types { :'address' => :'OrderFiscalEntityAddressResponse', :'email' => :'String', :'metadata' => :'Hash<String, Object>', :'name' => :'String', :'tax_id' => :'String', :'id' => :'String', :'created_at' => :'Integer', :'object' => :'String', :'phone' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && address == o.address && email == o.email && == o. && name == o.name && tax_id == o.tax_id && id == o.id && created_at == o.created_at && object == o.object && phone == o.phone end |
#eql?(o) ⇒ Boolean
265 266 267 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 265 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
271 272 273 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 271 def hash [address, email, , name, tax_id, id, created_at, object, phone].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @address.nil? invalid_properties.push('invalid value for "address", address cannot be nil.') end if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
183 184 185 186 187 188 189 190 191 |
# File 'lib/conekta/models/order_fiscal_entity_response.rb', line 183 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @address.nil? return false if !@metadata.nil? && @metadata.length > 100 return false if @id.nil? return false if @created_at.nil? return false if @object.nil? true end |