Class: Conekta::OrderRequest

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/order_request.rb

Overview

a order

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/conekta/models/order_request.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'charges')
    if (value = attributes[:'charges']).is_a?(Array)
      self.charges = value
    end
  end

  if attributes.key?(:'checkout')
    self.checkout = attributes[:'checkout']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'customer_info')
    self.customer_info = attributes[:'customer_info']
  else
    self.customer_info = nil
  end

  if attributes.key?(:'discount_lines')
    if (value = attributes[:'discount_lines']).is_a?(Array)
      self.discount_lines = value
    end
  end

  if attributes.key?(:'fiscal_entity')
    self.fiscal_entity = attributes[:'fiscal_entity']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  else
    self.line_items = nil
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'needs_shipping_contact')
    self.needs_shipping_contact = attributes[:'needs_shipping_contact']
  end

  if attributes.key?(:'pre_authorize')
    self.pre_authorize = attributes[:'pre_authorize']
  end

  if attributes.key?(:'processing_mode')
    self.processing_mode = attributes[:'processing_mode']
  end

  if attributes.key?(:'return_url')
    self.return_url = attributes[:'return_url']
  end

  if attributes.key?(:'shipping_contact')
    self.shipping_contact = attributes[:'shipping_contact']
  end

  if attributes.key?(:'shipping_lines')
    if (value = attributes[:'shipping_lines']).is_a?(Array)
      self.shipping_lines = value
    end
  end

  if attributes.key?(:'tax_lines')
    if (value = attributes[:'tax_lines']).is_a?(Array)
      self.tax_lines = value
    end
  end

  if attributes.key?(:'three_ds_mode')
    self.three_ds_mode = attributes[:'three_ds_mode']
  end
end

Instance Attribute Details

#chargesObject

List of charges that are applied to the order



20
21
22
# File 'lib/conekta/models/order_request.rb', line 20

def charges
  @charges
end

#checkoutObject

Returns the value of attribute checkout.



22
23
24
# File 'lib/conekta/models/order_request.rb', line 22

def checkout
  @checkout
end

#currencyObject

Currency with which the payment will be made. It uses the 3-letter code of the International Standard ISO 4217.



25
26
27
# File 'lib/conekta/models/order_request.rb', line 25

def currency
  @currency
end

#customer_infoObject

Returns the value of attribute customer_info.



27
28
29
# File 'lib/conekta/models/order_request.rb', line 27

def customer_info
  @customer_info
end

#discount_linesObject

List of discounts that are applied to the order.



30
31
32
# File 'lib/conekta/models/order_request.rb', line 30

def discount_lines
  @discount_lines
end

#fiscal_entityObject

Returns the value of attribute fiscal_entity.



32
33
34
# File 'lib/conekta/models/order_request.rb', line 32

def fiscal_entity
  @fiscal_entity
end

#line_itemsObject

List of products that are sold in the order. You must have at least one product.



35
36
37
# File 'lib/conekta/models/order_request.rb', line 35

def line_items
  @line_items
end

#metadataObject

Metadata associated with the order



38
39
40
# File 'lib/conekta/models/order_request.rb', line 38

def 
  @metadata
end

#needs_shipping_contactObject

Allows you to fill out the shipping information at checkout



41
42
43
# File 'lib/conekta/models/order_request.rb', line 41

def needs_shipping_contact
  @needs_shipping_contact
end

#pre_authorizeObject

Indicates whether the order charges must be preauthorized



44
45
46
# File 'lib/conekta/models/order_request.rb', line 44

def pre_authorize
  @pre_authorize
end

#processing_modeObject

Indicates the processing mode for the order, either ecommerce, recurrent or validation.



47
48
49
# File 'lib/conekta/models/order_request.rb', line 47

def processing_mode
  @processing_mode
end

#return_urlObject

Indicates the redirection callback upon completion of the 3DS2 flow. Do not use this parameter if your order has a checkout parameter



50
51
52
# File 'lib/conekta/models/order_request.rb', line 50

def return_url
  @return_url
end

#shipping_contactObject

Returns the value of attribute shipping_contact.



52
53
54
# File 'lib/conekta/models/order_request.rb', line 52

def shipping_contact
  @shipping_contact
end

#shipping_linesObject

List of shipping costs. If the online store offers digital products.



55
56
57
# File 'lib/conekta/models/order_request.rb', line 55

def shipping_lines
  @shipping_lines
end

#tax_linesObject

List of taxes that are applied to the order.



58
59
60
# File 'lib/conekta/models/order_request.rb', line 58

def tax_lines
  @tax_lines
end

#three_ds_modeObject

Indicates the 3DS2 mode for the order, either smart or strict. This property is only applicable when 3DS is enabled. When 3DS is disabled, this field should be null.



61
62
63
# File 'lib/conekta/models/order_request.rb', line 61

def three_ds_mode
  @three_ds_mode
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/conekta/models/order_request.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/conekta/models/order_request.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/conekta/models/order_request.rb', line 64

def self.attribute_map
  {
    :'charges' => :'charges',
    :'checkout' => :'checkout',
    :'currency' => :'currency',
    :'customer_info' => :'customer_info',
    :'discount_lines' => :'discount_lines',
    :'fiscal_entity' => :'fiscal_entity',
    :'line_items' => :'line_items',
    :'metadata' => :'metadata',
    :'needs_shipping_contact' => :'needs_shipping_contact',
    :'pre_authorize' => :'pre_authorize',
    :'processing_mode' => :'processing_mode',
    :'return_url' => :'return_url',
    :'shipping_contact' => :'shipping_contact',
    :'shipping_lines' => :'shipping_lines',
    :'tax_lines' => :'tax_lines',
    :'three_ds_mode' => :'three_ds_mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/conekta/models/order_request.rb', line 348

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
# File 'lib/conekta/models/order_request.rb', line 118

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/conekta/models/order_request.rb', line 96

def self.openapi_types
  {
    :'charges' => :'Array<ChargeRequest>',
    :'checkout' => :'OrderCheckoutRequest',
    :'currency' => :'String',
    :'customer_info' => :'OrderRequestCustomerInfo',
    :'discount_lines' => :'Array<OrderDiscountLinesRequest>',
    :'fiscal_entity' => :'OrderFiscalEntityRequest',
    :'line_items' => :'Array<Product>',
    :'metadata' => :'Hash<String, Object>',
    :'needs_shipping_contact' => :'Boolean',
    :'pre_authorize' => :'Boolean',
    :'processing_mode' => :'String',
    :'return_url' => :'String',
    :'shipping_contact' => :'CustomerShippingContactsRequest',
    :'shipping_lines' => :'Array<ShippingRequest>',
    :'tax_lines' => :'Array<OrderTaxRequest>',
    :'three_ds_mode' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/conekta/models/order_request.rb', line 312

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      charges == o.charges &&
      checkout == o.checkout &&
      currency == o.currency &&
      customer_info == o.customer_info &&
      discount_lines == o.discount_lines &&
      fiscal_entity == o.fiscal_entity &&
      line_items == o.line_items &&
       == o. &&
      needs_shipping_contact == o.needs_shipping_contact &&
      pre_authorize == o.pre_authorize &&
      processing_mode == o.processing_mode &&
      return_url == o.return_url &&
      shipping_contact == o.shipping_contact &&
      shipping_lines == o.shipping_lines &&
      tax_lines == o.tax_lines &&
      three_ds_mode == o.three_ds_mode
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


335
336
337
# File 'lib/conekta/models/order_request.rb', line 335

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



341
342
343
# File 'lib/conekta/models/order_request.rb', line 341

def hash
  [charges, checkout, currency, customer_info, discount_lines, fiscal_entity, line_items, , needs_shipping_contact, pre_authorize, processing_mode, return_url, shipping_contact, shipping_lines, tax_lines, three_ds_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/conekta/models/order_request.rb', line 224

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if @customer_info.nil?
    invalid_properties.push('invalid value for "customer_info", customer_info cannot be nil.')
  end

  if @line_items.nil?
    invalid_properties.push('invalid value for "line_items", line_items cannot be nil.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/conekta/models/order_request.rb', line 370

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



252
253
254
255
256
257
258
259
260
# File 'lib/conekta/models/order_request.rb', line 252

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @currency.nil?
  return false if @currency.to_s.length > 3
  return false if @customer_info.nil?
  return false if @line_items.nil?
  return false if !@metadata.nil? && @metadata.length > 100
  true
end