Class: Conekta::OrderResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/order_response.rb

Overview

order response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/conekta/models/order_response.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'amount_refunded')
    self.amount_refunded = attributes[:'amount_refunded']
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  end

  if attributes.key?(:'charges')
    self.charges = attributes[:'charges']
  end

  if attributes.key?(:'checkout')
    self.checkout = attributes[:'checkout']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'customer_info')
    self.customer_info = attributes[:'customer_info']
  end

  if attributes.key?(:'discount_lines')
    self.discount_lines = attributes[:'discount_lines']
  end

  if attributes.key?(:'tax_lines')
    self.tax_lines = attributes[:'tax_lines']
  end

  if attributes.key?(:'shipping_lines')
    self.shipping_lines = attributes[:'shipping_lines']
  end

  if attributes.key?(:'fiscal_entity')
    self.fiscal_entity = attributes[:'fiscal_entity']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'is_refundable')
    self.is_refundable = attributes[:'is_refundable']
  end

  if attributes.key?(:'line_items')
    self.line_items = attributes[:'line_items']
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'next_action')
    self.next_action = attributes[:'next_action']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'payment_status')
    self.payment_status = attributes[:'payment_status']
  end

  if attributes.key?(:'processing_mode')
    self.processing_mode = attributes[:'processing_mode']
  end

  if attributes.key?(:'shipping_contact')
    self.shipping_contact = attributes[:'shipping_contact']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#amountObject

The total amount to be collected in cents



20
21
22
# File 'lib/conekta/models/order_response.rb', line 20

def amount
  @amount
end

#amount_refundedObject

The total amount refunded in cents



23
24
25
# File 'lib/conekta/models/order_response.rb', line 23

def amount_refunded
  @amount_refunded
end

#channelObject

Returns the value of attribute channel.



25
26
27
# File 'lib/conekta/models/order_response.rb', line 25

def channel
  @channel
end

#chargesObject

Returns the value of attribute charges.



27
28
29
# File 'lib/conekta/models/order_response.rb', line 27

def charges
  @charges
end

#checkoutObject

Returns the value of attribute checkout.



29
30
31
# File 'lib/conekta/models/order_response.rb', line 29

def checkout
  @checkout
end

#created_atObject

The time at which the object was created in seconds since the Unix epoch



32
33
34
# File 'lib/conekta/models/order_response.rb', line 32

def created_at
  @created_at
end

#currencyObject

The three-letter ISO 4217 currency code. The currency of the order.



35
36
37
# File 'lib/conekta/models/order_response.rb', line 35

def currency
  @currency
end

#customer_infoObject

Returns the value of attribute customer_info.



37
38
39
# File 'lib/conekta/models/order_response.rb', line 37

def customer_info
  @customer_info
end

#discount_linesObject

Returns the value of attribute discount_lines.



39
40
41
# File 'lib/conekta/models/order_response.rb', line 39

def discount_lines
  @discount_lines
end

#fiscal_entityObject

Returns the value of attribute fiscal_entity.



45
46
47
# File 'lib/conekta/models/order_response.rb', line 45

def fiscal_entity
  @fiscal_entity
end

#idObject

Returns the value of attribute id.



47
48
49
# File 'lib/conekta/models/order_response.rb', line 47

def id
  @id
end

#is_refundableObject

Returns the value of attribute is_refundable.



49
50
51
# File 'lib/conekta/models/order_response.rb', line 49

def is_refundable
  @is_refundable
end

#line_itemsObject

Returns the value of attribute line_items.



51
52
53
# File 'lib/conekta/models/order_response.rb', line 51

def line_items
  @line_items
end

#livemodeObject

Whether the object exists in live mode or test mode



54
55
56
# File 'lib/conekta/models/order_response.rb', line 54

def livemode
  @livemode
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



57
58
59
# File 'lib/conekta/models/order_response.rb', line 57

def 
  @metadata
end

#next_actionObject

Returns the value of attribute next_action.



59
60
61
# File 'lib/conekta/models/order_response.rb', line 59

def next_action
  @next_action
end

#objectObject

String representing the object’s type. Objects of the same type share the same value.



62
63
64
# File 'lib/conekta/models/order_response.rb', line 62

def object
  @object
end

#payment_statusObject

The payment status of the order.



65
66
67
# File 'lib/conekta/models/order_response.rb', line 65

def payment_status
  @payment_status
end

#processing_modeObject

Indicates the processing mode for the order, either ecommerce, recurrent or validation.



68
69
70
# File 'lib/conekta/models/order_response.rb', line 68

def processing_mode
  @processing_mode
end

#shipping_contactObject

Returns the value of attribute shipping_contact.



70
71
72
# File 'lib/conekta/models/order_response.rb', line 70

def shipping_contact
  @shipping_contact
end

#shipping_linesObject

Returns the value of attribute shipping_lines.



43
44
45
# File 'lib/conekta/models/order_response.rb', line 43

def shipping_lines
  @shipping_lines
end

#tax_linesObject

Returns the value of attribute tax_lines.



41
42
43
# File 'lib/conekta/models/order_response.rb', line 41

def tax_lines
  @tax_lines
end

#updated_atObject

The time at which the object was last updated in seconds since the Unix epoch



73
74
75
# File 'lib/conekta/models/order_response.rb', line 73

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



105
106
107
# File 'lib/conekta/models/order_response.rb', line 105

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/conekta/models/order_response.rb', line 110

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/conekta/models/order_response.rb', line 76

def self.attribute_map
  {
    :'amount' => :'amount',
    :'amount_refunded' => :'amount_refunded',
    :'channel' => :'channel',
    :'charges' => :'charges',
    :'checkout' => :'checkout',
    :'created_at' => :'created_at',
    :'currency' => :'currency',
    :'customer_info' => :'customer_info',
    :'discount_lines' => :'discount_lines',
    :'tax_lines' => :'tax_lines',
    :'shipping_lines' => :'shipping_lines',
    :'fiscal_entity' => :'fiscal_entity',
    :'id' => :'id',
    :'is_refundable' => :'is_refundable',
    :'line_items' => :'line_items',
    :'livemode' => :'livemode',
    :'metadata' => :'metadata',
    :'next_action' => :'next_action',
    :'object' => :'object',
    :'payment_status' => :'payment_status',
    :'processing_mode' => :'processing_mode',
    :'shipping_contact' => :'shipping_contact',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/conekta/models/order_response.rb', line 339

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



144
145
146
147
# File 'lib/conekta/models/order_response.rb', line 144

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/conekta/models/order_response.rb', line 115

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'amount_refunded' => :'Integer',
    :'channel' => :'OrderChannelResponse',
    :'charges' => :'OrderChargesResponse',
    :'checkout' => :'OrderResponseCheckout',
    :'created_at' => :'Integer',
    :'currency' => :'String',
    :'customer_info' => :'OrderResponseCustomerInfo',
    :'discount_lines' => :'OrderResponseDiscountLines',
    :'tax_lines' => :'OrderResponseTaxLines',
    :'shipping_lines' => :'OrderResponseShippingLines',
    :'fiscal_entity' => :'OrderFiscalEntityResponse',
    :'id' => :'String',
    :'is_refundable' => :'Boolean',
    :'line_items' => :'OrderResponseProducts',
    :'livemode' => :'Boolean',
    :'metadata' => :'Hash<String, Object>',
    :'next_action' => :'OrderNextActionResponse',
    :'object' => :'String',
    :'payment_status' => :'String',
    :'processing_mode' => :'String',
    :'shipping_contact' => :'OrderResponseShippingContact',
    :'updated_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/conekta/models/order_response.rb', line 296

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      amount_refunded == o.amount_refunded &&
      channel == o.channel &&
      charges == o.charges &&
      checkout == o.checkout &&
      created_at == o.created_at &&
      currency == o.currency &&
      customer_info == o.customer_info &&
      discount_lines == o.discount_lines &&
      tax_lines == o.tax_lines &&
      shipping_lines == o.shipping_lines &&
      fiscal_entity == o.fiscal_entity &&
      id == o.id &&
      is_refundable == o.is_refundable &&
      line_items == o.line_items &&
      livemode == o.livemode &&
       == o. &&
      next_action == o.next_action &&
      object == o.object &&
      payment_status == o.payment_status &&
      processing_mode == o.processing_mode &&
      shipping_contact == o.shipping_contact &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


326
327
328
# File 'lib/conekta/models/order_response.rb', line 326

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



332
333
334
# File 'lib/conekta/models/order_response.rb', line 332

def hash
  [amount, amount_refunded, channel, charges, checkout, created_at, currency, customer_info, discount_lines, tax_lines, shipping_lines, fiscal_entity, id, is_refundable, line_items, livemode, , next_action, object, payment_status, processing_mode, shipping_contact, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



262
263
264
265
266
267
268
269
270
# File 'lib/conekta/models/order_response.rb', line 262

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/conekta/models/order_response.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



274
275
276
277
278
# File 'lib/conekta/models/order_response.rb', line 274

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@metadata.nil? && @metadata.length > 100
  true
end