Class: Conekta::OrderResponseProducts

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/order_response_products.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderResponseProducts

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/conekta/models/order_response_products.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderResponseProducts` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderResponseProducts`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'has_more')
    self.has_more = attributes[:'has_more']
  else
    self.has_more = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'next_page_url')
    self.next_page_url = attributes[:'next_page_url']
  end

  if attributes.key?(:'previous_page_url')
    self.previous_page_url = attributes[:'previous_page_url']
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Array)
      self.data = value
    end
  end
end

Instance Attribute Details

#dataObject

Returns the value of attribute data.



30
31
32
# File 'lib/conekta/models/order_response_products.rb', line 30

def data
  @data
end

#has_moreObject

Indicates if there are more pages to be requested



19
20
21
# File 'lib/conekta/models/order_response_products.rb', line 19

def has_more
  @has_more
end

#next_page_urlObject

URL of the next page.



25
26
27
# File 'lib/conekta/models/order_response_products.rb', line 25

def next_page_url
  @next_page_url
end

#objectObject

Object type, in this case is list



22
23
24
# File 'lib/conekta/models/order_response_products.rb', line 22

def object
  @object
end

#previous_page_urlObject

Url of the previous page.



28
29
30
# File 'lib/conekta/models/order_response_products.rb', line 28

def previous_page_url
  @previous_page_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/conekta/models/order_response_products.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/conekta/models/order_response_products.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/conekta/models/order_response_products.rb', line 33

def self.attribute_map
  {
    :'has_more' => :'has_more',
    :'object' => :'object',
    :'next_page_url' => :'next_page_url',
    :'previous_page_url' => :'previous_page_url',
    :'data' => :'data'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/conekta/models/order_response_products.rb', line 185

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/conekta/models/order_response_products.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/conekta/models/order_response_products.rb', line 54

def self.openapi_types
  {
    :'has_more' => :'Boolean',
    :'object' => :'String',
    :'next_page_url' => :'String',
    :'previous_page_url' => :'String',
    :'data' => :'Array<ProductDataResponse>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
166
167
168
# File 'lib/conekta/models/order_response_products.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      has_more == o.has_more &&
      object == o.object &&
      next_page_url == o.next_page_url &&
      previous_page_url == o.previous_page_url &&
      data == o.data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/conekta/models/order_response_products.rb', line 172

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



178
179
180
# File 'lib/conekta/models/order_response_products.rb', line 178

def hash
  [has_more, object, next_page_url, previous_page_url, data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/conekta/models/order_response_products.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @has_more.nil?
    invalid_properties.push('invalid value for "has_more", has_more cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/conekta/models/order_response_products.rb', line 207

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
# File 'lib/conekta/models/order_response_products.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @has_more.nil?
  return false if @object.nil?
  true
end