Class: Conekta::OrderResponseShippingLines
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::OrderResponseShippingLines
- Defined in:
- lib/conekta/models/order_response_shipping_lines.rb
Overview
List of shipping costs applied to the order
Instance Attribute Summary collapse
-
#data ⇒ Object
Returns the value of attribute data.
-
#has_more ⇒ Object
Indicates if there are more pages to be requested.
-
#next_page_url ⇒ Object
URL of the next page.
-
#object ⇒ Object
Object type, in this case is list.
-
#previous_page_url ⇒ Object
Url of the previous page.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderResponseShippingLines
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrderResponseShippingLines
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderResponseShippingLines` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderResponseShippingLines`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'has_more') self.has_more = attributes[:'has_more'] else self.has_more = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'next_page_url') self.next_page_url = attributes[:'next_page_url'] end if attributes.key?(:'previous_page_url') self.previous_page_url = attributes[:'previous_page_url'] end if attributes.key?(:'data') if (value = attributes[:'data']).is_a?(Array) self.data = value end end end |
Instance Attribute Details
#data ⇒ Object
Returns the value of attribute data.
31 32 33 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 31 def data @data end |
#has_more ⇒ Object
Indicates if there are more pages to be requested
20 21 22 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 20 def has_more @has_more end |
#next_page_url ⇒ Object
URL of the next page.
26 27 28 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 26 def next_page_url @next_page_url end |
#object ⇒ Object
Object type, in this case is list
23 24 25 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 23 def object @object end |
#previous_page_url ⇒ Object
Url of the previous page.
29 30 31 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 29 def previous_page_url @previous_page_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 34 def self.attribute_map { :'has_more' => :'has_more', :'object' => :'object', :'next_page_url' => :'next_page_url', :'previous_page_url' => :'previous_page_url', :'data' => :'data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 55 def self.openapi_types { :'has_more' => :'Boolean', :'object' => :'String', :'next_page_url' => :'String', :'previous_page_url' => :'String', :'data' => :'Array<ShippingLinesDataResponse>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && has_more == o.has_more && object == o.object && next_page_url == o.next_page_url && previous_page_url == o.previous_page_url && data == o.data end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 179 def hash [has_more, object, next_page_url, previous_page_url, data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @has_more.nil? invalid_properties.push('invalid value for "has_more", has_more cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 137 |
# File 'lib/conekta/models/order_response_shipping_lines.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @has_more.nil? return false if @object.nil? true end |