Class: Conekta::OrderUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/order_update.rb

Overview

a order

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/conekta/models/order_update.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'charges')
    if (value = attributes[:'charges']).is_a?(Array)
      self.charges = value
    end
  end

  if attributes.key?(:'checkout')
    self.checkout = attributes[:'checkout']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'customer_info')
    self.customer_info = attributes[:'customer_info']
  end

  if attributes.key?(:'discount_lines')
    if (value = attributes[:'discount_lines']).is_a?(Array)
      self.discount_lines = value
    end
  end

  if attributes.key?(:'fiscal_entity')
    self.fiscal_entity = attributes[:'fiscal_entity']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'metadata')
  end

  if attributes.key?(:'pre_authorize')
    self.pre_authorize = attributes[:'pre_authorize']
  end

  if attributes.key?(:'shipping_contact')
    self.shipping_contact = attributes[:'shipping_contact']
  end

  if attributes.key?(:'shipping_lines')
    if (value = attributes[:'shipping_lines']).is_a?(Array)
      self.shipping_lines = value
    end
  end

  if attributes.key?(:'tax_lines')
    if (value = attributes[:'tax_lines']).is_a?(Array)
      self.tax_lines = value
    end
  end
end

Instance Attribute Details

#chargesObject

Returns the value of attribute charges.



19
20
21
# File 'lib/conekta/models/order_update.rb', line 19

def charges
  @charges
end

#checkoutObject

Returns the value of attribute checkout.



21
22
23
# File 'lib/conekta/models/order_update.rb', line 21

def checkout
  @checkout
end

#currencyObject

Currency with which the payment will be made. It uses the 3-letter code of the International Standard ISO 4217.



24
25
26
# File 'lib/conekta/models/order_update.rb', line 24

def currency
  @currency
end

#customer_infoObject

Returns the value of attribute customer_info.



26
27
28
# File 'lib/conekta/models/order_update.rb', line 26

def customer_info
  @customer_info
end

#discount_linesObject

List of discounts that are applied to the order.



29
30
31
# File 'lib/conekta/models/order_update.rb', line 29

def discount_lines
  @discount_lines
end

#fiscal_entityObject

Returns the value of attribute fiscal_entity.



31
32
33
# File 'lib/conekta/models/order_update.rb', line 31

def fiscal_entity
  @fiscal_entity
end

#line_itemsObject

List of products that are sold in the order. You must have at least one product.



34
35
36
# File 'lib/conekta/models/order_update.rb', line 34

def line_items
  @line_items
end

#metadataObject

Returns the value of attribute metadata.



36
37
38
# File 'lib/conekta/models/order_update.rb', line 36

def 
  @metadata
end

#pre_authorizeObject

Indicates whether the order charges must be preauthorized



39
40
41
# File 'lib/conekta/models/order_update.rb', line 39

def pre_authorize
  @pre_authorize
end

#shipping_contactObject

Returns the value of attribute shipping_contact.



41
42
43
# File 'lib/conekta/models/order_update.rb', line 41

def shipping_contact
  @shipping_contact
end

#shipping_linesObject

List of shipping costs. If the online store offers digital products.



44
45
46
# File 'lib/conekta/models/order_update.rb', line 44

def shipping_lines
  @shipping_lines
end

#tax_linesObject

Returns the value of attribute tax_lines.



46
47
48
# File 'lib/conekta/models/order_update.rb', line 46

def tax_lines
  @tax_lines
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/conekta/models/order_update.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/conekta/models/order_update.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/conekta/models/order_update.rb', line 49

def self.attribute_map
  {
    :'charges' => :'charges',
    :'checkout' => :'checkout',
    :'currency' => :'currency',
    :'customer_info' => :'customer_info',
    :'discount_lines' => :'discount_lines',
    :'fiscal_entity' => :'fiscal_entity',
    :'line_items' => :'line_items',
    :'metadata' => :'metadata',
    :'pre_authorize' => :'pre_authorize',
    :'shipping_contact' => :'shipping_contact',
    :'shipping_lines' => :'shipping_lines',
    :'tax_lines' => :'tax_lines'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/conekta/models/order_update.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
99
# File 'lib/conekta/models/order_update.rb', line 95

def self.openapi_nullable
  Set.new([
    :'metadata',
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/conekta/models/order_update.rb', line 77

def self.openapi_types
  {
    :'charges' => :'Array<ChargeRequest>',
    :'checkout' => :'OrderCheckoutRequest',
    :'currency' => :'String',
    :'customer_info' => :'OrderUpdateCustomerInfo',
    :'discount_lines' => :'Array<OrderDiscountLinesRequest>',
    :'fiscal_entity' => :'OrderUpdateFiscalEntityRequest',
    :'line_items' => :'Array<Product>',
    :'metadata' => :'Hash<String, String>',
    :'pre_authorize' => :'Boolean',
    :'shipping_contact' => :'CustomerShippingContactsRequest',
    :'shipping_lines' => :'Array<ShippingRequest>',
    :'tax_lines' => :'Array<OrderTaxRequest>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/conekta/models/order_update.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      charges == o.charges &&
      checkout == o.checkout &&
      currency == o.currency &&
      customer_info == o.customer_info &&
      discount_lines == o.discount_lines &&
      fiscal_entity == o.fiscal_entity &&
      line_items == o.line_items &&
       == o. &&
      pre_authorize == o.pre_authorize &&
      shipping_contact == o.shipping_contact &&
      shipping_lines == o.shipping_lines &&
      tax_lines == o.tax_lines
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/conekta/models/order_update.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/conekta/models/order_update.rb', line 236

def hash
  [charges, checkout, currency, customer_info, discount_lines, fiscal_entity, line_items, , pre_authorize, shipping_contact, shipping_lines, tax_lines].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
# File 'lib/conekta/models/order_update.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@currency.nil? && @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/conekta/models/order_update.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
# File 'lib/conekta/models/order_update.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@currency.nil? && @currency.to_s.length > 3
  true
end