Class: Conekta::OrderUpdateFiscalEntityRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::OrderUpdateFiscalEntityRequest
- Defined in:
- lib/conekta/models/order_update_fiscal_entity_request.rb
Overview
Fiscal entity of the order, Currently it is a purely informative field
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#email ⇒ Object
Email of the fiscal entity.
-
#metadata ⇒ Object
Metadata associated with the fiscal entity.
-
#name ⇒ Object
Name of the fiscal entity.
-
#phone ⇒ Object
Phone of the fiscal entity.
-
#tax_id ⇒ Object
Tax ID of the fiscal entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderUpdateFiscalEntityRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrderUpdateFiscalEntityRequest
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderUpdateFiscalEntityRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderUpdateFiscalEntityRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'address') self.address = attributes[:'address'] else self.address = nil end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'tax_id') self.tax_id = attributes[:'tax_id'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
19 20 21 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 19 def address @address end |
#email ⇒ Object
Email of the fiscal entity
22 23 24 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 22 def email @email end |
#metadata ⇒ Object
Metadata associated with the fiscal entity
28 29 30 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 28 def @metadata end |
#name ⇒ Object
Name of the fiscal entity
25 26 27 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 25 def name @name end |
#phone ⇒ Object
Phone of the fiscal entity
31 32 33 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 31 def phone @phone end |
#tax_id ⇒ Object
Tax ID of the fiscal entity
34 35 36 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 34 def tax_id @tax_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 37 def self.attribute_map { :'address' => :'address', :'email' => :'email', :'name' => :'name', :'metadata' => :'metadata', :'phone' => :'phone', :'tax_id' => :'tax_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 198 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 59 def self.openapi_types { :'address' => :'FiscalEntityAddress', :'email' => :'String', :'name' => :'String', :'metadata' => :'Hash<String, Object>', :'phone' => :'String', :'tax_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && address == o.address && email == o.email && name == o.name && == o. && phone == o.phone && tax_id == o.tax_id end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 191 def hash [address, email, name, , phone, tax_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @address.nil? invalid_properties.push('invalid value for "address", address cannot be nil.') end if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 143 144 |
# File 'lib/conekta/models/order_update_fiscal_entity_request.rb', line 139 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @address.nil? return false if !@metadata.nil? && @metadata.length > 100 true end |