Class: Conekta::PaymentMethodBankTransfer

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payment_method_bank_transfer.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethodBankTransfer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodBankTransfer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodBankTransfer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'bank')
    self.bank = attributes[:'bank']
  end

  if attributes.key?(:'clabe')
    self.clabe = attributes[:'clabe']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'executed_at')
    self.executed_at = attributes[:'executed_at']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'issuing_account_bank')
    self. = attributes[:'issuing_account_bank']
  end

  if attributes.key?(:'issuing_account_number')
    self. = attributes[:'issuing_account_number']
  end

  if attributes.key?(:'issuing_account_holder_name')
    self. = attributes[:'issuing_account_holder_name']
  end

  if attributes.key?(:'issuing_account_tax_id')
    self. = attributes[:'issuing_account_tax_id']
  end

  if attributes.key?(:'payment_attempts')
    if (value = attributes[:'payment_attempts']).is_a?(Array)
      self.payment_attempts = value
    end
  end

  if attributes.key?(:'receiving_account_holder_name')
    self. = attributes[:'receiving_account_holder_name']
  end

  if attributes.key?(:'receiving_account_number')
    self. = attributes[:'receiving_account_number']
  end

  if attributes.key?(:'receiving_account_bank')
    self. = attributes[:'receiving_account_bank']
  end

  if attributes.key?(:'receiving_account_tax_id')
    self. = attributes[:'receiving_account_tax_id']
  end

  if attributes.key?(:'reference_number')
    self.reference_number = attributes[:'reference_number']
  end

  if attributes.key?(:'tracking_code')
    self.tracking_code = attributes[:'tracking_code']
  end

  if attributes.key?(:'customer_ip_address')
    self.customer_ip_address = attributes[:'customer_ip_address']
  end
end

Instance Attribute Details

#bankObject

Returns the value of attribute bank.



22
23
24
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 22

def bank
  @bank
end

#clabeObject

Returns the value of attribute clabe.



24
25
26
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 24

def clabe
  @clabe
end

#customer_ip_addressObject

Returns the value of attribute customer_ip_address.



54
55
56
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 54

def customer_ip_address
  @customer_ip_address
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 26

def description
  @description
end

#executed_atObject

Returns the value of attribute executed_at.



28
29
30
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 28

def executed_at
  @executed_at
end

#expires_atObject

Returns the value of attribute expires_at.



30
31
32
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 30

def expires_at
  @expires_at
end

#issuing_account_bankObject

Returns the value of attribute issuing_account_bank.



32
33
34
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 32

def 
  @issuing_account_bank
end

#issuing_account_holder_nameObject

Returns the value of attribute issuing_account_holder_name.



36
37
38
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 36

def 
  @issuing_account_holder_name
end

#issuing_account_numberObject

Returns the value of attribute issuing_account_number.



34
35
36
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 34

def 
  @issuing_account_number
end

#issuing_account_tax_idObject

Returns the value of attribute issuing_account_tax_id.



38
39
40
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 38

def 
  @issuing_account_tax_id
end

#objectObject

Returns the value of attribute object.



20
21
22
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 20

def object
  @object
end

#payment_attemptsObject

Returns the value of attribute payment_attempts.



40
41
42
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 40

def payment_attempts
  @payment_attempts
end

#receiving_account_bankObject

Returns the value of attribute receiving_account_bank.



46
47
48
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 46

def 
  @receiving_account_bank
end

#receiving_account_holder_nameObject

Returns the value of attribute receiving_account_holder_name.



42
43
44
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 42

def 
  @receiving_account_holder_name
end

#receiving_account_numberObject

Returns the value of attribute receiving_account_number.



44
45
46
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 44

def 
  @receiving_account_number
end

#receiving_account_tax_idObject

Returns the value of attribute receiving_account_tax_id.



48
49
50
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 48

def 
  @receiving_account_tax_id
end

#reference_numberObject

Returns the value of attribute reference_number.



50
51
52
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 50

def reference_number
  @reference_number
end

#tracking_codeObject

Returns the value of attribute tracking_code.



52
53
54
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 52

def tracking_code
  @tracking_code
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 57

def self.attribute_map
  {
    :'type' => :'type',
    :'object' => :'object',
    :'bank' => :'bank',
    :'clabe' => :'clabe',
    :'description' => :'description',
    :'executed_at' => :'executed_at',
    :'expires_at' => :'expires_at',
    :'issuing_account_bank' => :'issuing_account_bank',
    :'issuing_account_number' => :'issuing_account_number',
    :'issuing_account_holder_name' => :'issuing_account_holder_name',
    :'issuing_account_tax_id' => :'issuing_account_tax_id',
    :'payment_attempts' => :'payment_attempts',
    :'receiving_account_holder_name' => :'receiving_account_holder_name',
    :'receiving_account_number' => :'receiving_account_number',
    :'receiving_account_bank' => :'receiving_account_bank',
    :'receiving_account_tax_id' => :'receiving_account_tax_id',
    :'reference_number' => :'reference_number',
    :'tracking_code' => :'tracking_code',
    :'customer_ip_address' => :'customer_ip_address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 290

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 92

def self.openapi_types
  {
    :'type' => :'String',
    :'object' => :'String',
    :'bank' => :'String',
    :'clabe' => :'String',
    :'description' => :'String',
    :'executed_at' => :'String',
    :'expires_at' => :'Integer',
    :'issuing_account_bank' => :'String',
    :'issuing_account_number' => :'String',
    :'issuing_account_holder_name' => :'String',
    :'issuing_account_tax_id' => :'String',
    :'payment_attempts' => :'Array<Object>',
    :'receiving_account_holder_name' => :'String',
    :'receiving_account_number' => :'String',
    :'receiving_account_bank' => :'String',
    :'receiving_account_tax_id' => :'String',
    :'reference_number' => :'String',
    :'tracking_code' => :'String',
    :'customer_ip_address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 251

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      object == o.object &&
      bank == o.bank &&
      clabe == o.clabe &&
      description == o.description &&
      executed_at == o.executed_at &&
      expires_at == o.expires_at &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
      payment_attempts == o.payment_attempts &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
      reference_number == o.reference_number &&
      tracking_code == o.tracking_code &&
      customer_ip_address == o.customer_ip_address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


277
278
279
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 277

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



283
284
285
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 283

def hash
  [type, object, bank, clabe, description, executed_at, expires_at, , , , , payment_attempts, , , , , reference_number, tracking_code, customer_ip_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



221
222
223
224
225
226
227
228
229
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 221

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 312

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
# File 'lib/conekta/models/payment_method_bank_transfer.rb', line 233

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object.nil?
  true
end