Class: Conekta::PaymentMethodBnplPayment

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payment_method_bnpl_payment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethodBnplPayment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodBnplPayment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodBnplPayment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'cancel_url')
    self.cancel_url = attributes[:'cancel_url']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'failure_url')
    self.failure_url = attributes[:'failure_url']
  end

  if attributes.key?(:'product_type')
    self.product_type = attributes[:'product_type']
  else
    self.product_type = nil
  end

  if attributes.key?(:'redirect_url')
    self.redirect_url = attributes[:'redirect_url']
  end

  if attributes.key?(:'success_url')
    self.success_url = attributes[:'success_url']
  end
end

Instance Attribute Details

#cancel_urlObject

URL to redirect the customer after a canceled payment



23
24
25
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 23

def cancel_url
  @cancel_url
end

#expires_atObject

Expiration date of the charge



26
27
28
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 26

def expires_at
  @expires_at
end

#failure_urlObject

URL to redirect the customer after a failed payment



29
30
31
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 29

def failure_url
  @failure_url
end

#objectObject

Returns the value of attribute object.



20
21
22
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 20

def object
  @object
end

#product_typeObject

Product type of the charge



32
33
34
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 32

def product_type
  @product_type
end

#redirect_urlObject

URL to redirect the customer to complete the payment



35
36
37
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 35

def redirect_url
  @redirect_url
end

#success_urlObject

URL to redirect the customer after a successful payment



38
39
40
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 38

def success_url
  @success_url
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 63

def self.attribute_map
  {
    :'type' => :'type',
    :'object' => :'object',
    :'cancel_url' => :'cancel_url',
    :'expires_at' => :'expires_at',
    :'failure_url' => :'failure_url',
    :'product_type' => :'product_type',
    :'redirect_url' => :'redirect_url',
    :'success_url' => :'success_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 253

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 87

def self.openapi_types
  {
    :'type' => :'String',
    :'object' => :'String',
    :'cancel_url' => :'String',
    :'expires_at' => :'Integer',
    :'failure_url' => :'String',
    :'product_type' => :'String',
    :'redirect_url' => :'String',
    :'success_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 225

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      object == o.object &&
      cancel_url == o.cancel_url &&
      expires_at == o.expires_at &&
      failure_url == o.failure_url &&
      product_type == o.product_type &&
      redirect_url == o.redirect_url &&
      success_url == o.success_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 246

def hash
  [type, object, cancel_url, expires_at, failure_url, product_type, redirect_url, success_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @product_type.nil?
    invalid_properties.push('invalid value for "product_type", product_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
# File 'lib/conekta/models/payment_method_bnpl_payment.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["bnpl_payment"])
  return false unless object_validator.valid?(@object)
  return false if @expires_at.nil?
  return false if @product_type.nil?
  true
end