Class: Conekta::PaymentMethodCard

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payment_method_card.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethodCard

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/conekta/models/payment_method_card.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodCard` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'account_type')
    self. = attributes[:'account_type']
  end

  if attributes.key?(:'auth_code')
    self.auth_code = attributes[:'auth_code']
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'contract_id')
    self.contract_id = attributes[:'contract_id']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'exp_month')
    self.exp_month = attributes[:'exp_month']
  end

  if attributes.key?(:'exp_year')
    self.exp_year = attributes[:'exp_year']
  end

  if attributes.key?(:'fraud_indicators')
    if (value = attributes[:'fraud_indicators']).is_a?(Array)
      self.fraud_indicators = value
    end
  end

  if attributes.key?(:'issuer')
    self.issuer = attributes[:'issuer']
  end

  if attributes.key?(:'last4')
    self.last4 = attributes[:'last4']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'customer_ip_address')
    self.customer_ip_address = attributes[:'customer_ip_address']
  end
end

Instance Attribute Details

#account_typeObject

Account type of the card



23
24
25
# File 'lib/conekta/models/payment_method_card.rb', line 23

def 
  @account_type
end

#auth_codeObject

Returns the value of attribute auth_code.



25
26
27
# File 'lib/conekta/models/payment_method_card.rb', line 25

def auth_code
  @auth_code
end

#brandObject

Brand of the card



28
29
30
# File 'lib/conekta/models/payment_method_card.rb', line 28

def brand
  @brand
end

#contract_idObject

Id sent for recurrent charges.



31
32
33
# File 'lib/conekta/models/payment_method_card.rb', line 31

def contract_id
  @contract_id
end

#countryObject

Country of the card



34
35
36
# File 'lib/conekta/models/payment_method_card.rb', line 34

def country
  @country
end

#customer_ip_addressObject

Optional field used to capture the customer's IP address for fraud prevention and security monitoring purposes



54
55
56
# File 'lib/conekta/models/payment_method_card.rb', line 54

def customer_ip_address
  @customer_ip_address
end

#exp_monthObject

Expiration month of the card



37
38
39
# File 'lib/conekta/models/payment_method_card.rb', line 37

def exp_month
  @exp_month
end

#exp_yearObject

Expiration year of the card



40
41
42
# File 'lib/conekta/models/payment_method_card.rb', line 40

def exp_year
  @exp_year
end

#fraud_indicatorsObject

Returns the value of attribute fraud_indicators.



42
43
44
# File 'lib/conekta/models/payment_method_card.rb', line 42

def fraud_indicators
  @fraud_indicators
end

#issuerObject

Issuer of the card



45
46
47
# File 'lib/conekta/models/payment_method_card.rb', line 45

def issuer
  @issuer
end

#last4Object

Last 4 digits of the card



48
49
50
# File 'lib/conekta/models/payment_method_card.rb', line 48

def last4
  @last4
end

#nameObject

Name of the cardholder



51
52
53
# File 'lib/conekta/models/payment_method_card.rb', line 51

def name
  @name
end

#objectObject

Returns the value of attribute object.



20
21
22
# File 'lib/conekta/models/payment_method_card.rb', line 20

def object
  @object
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/conekta/models/payment_method_card.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/conekta/models/payment_method_card.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/conekta/models/payment_method_card.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/conekta/models/payment_method_card.rb', line 57

def self.attribute_map
  {
    :'type' => :'type',
    :'object' => :'object',
    :'account_type' => :'account_type',
    :'auth_code' => :'auth_code',
    :'brand' => :'brand',
    :'contract_id' => :'contract_id',
    :'country' => :'country',
    :'exp_month' => :'exp_month',
    :'exp_year' => :'exp_year',
    :'fraud_indicators' => :'fraud_indicators',
    :'issuer' => :'issuer',
    :'last4' => :'last4',
    :'name' => :'name',
    :'customer_ip_address' => :'customer_ip_address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/conekta/models/payment_method_card.rb', line 255

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/conekta/models/payment_method_card.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/conekta/models/payment_method_card.rb', line 87

def self.openapi_types
  {
    :'type' => :'String',
    :'object' => :'String',
    :'account_type' => :'String',
    :'auth_code' => :'String',
    :'brand' => :'String',
    :'contract_id' => :'String',
    :'country' => :'String',
    :'exp_month' => :'String',
    :'exp_year' => :'String',
    :'fraud_indicators' => :'Array<Object>',
    :'issuer' => :'String',
    :'last4' => :'String',
    :'name' => :'String',
    :'customer_ip_address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/conekta/models/payment_method_card.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      object == o.object &&
       == o. &&
      auth_code == o.auth_code &&
      brand == o.brand &&
      contract_id == o.contract_id &&
      country == o.country &&
      exp_month == o.exp_month &&
      exp_year == o.exp_year &&
      fraud_indicators == o.fraud_indicators &&
      issuer == o.issuer &&
      last4 == o.last4 &&
      name == o.name &&
      customer_ip_address == o.customer_ip_address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/conekta/models/payment_method_card.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/conekta/models/payment_method_card.rb', line 248

def hash
  [type, object, , auth_code, brand, contract_id, country, exp_month, exp_year, fraud_indicators, issuer, last4, name, customer_ip_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
# File 'lib/conekta/models/payment_method_card.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/conekta/models/payment_method_card.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
# File 'lib/conekta/models/payment_method_card.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object.nil?
  true
end