Class: Conekta::PaymentMethodCardRequest

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payment_method_card_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethodCardRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/conekta/models/payment_method_card_request.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodCardRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodCardRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'cvc')
    self.cvc = attributes[:'cvc']
  else
    self.cvc = nil
  end

  if attributes.key?(:'exp_month')
    self.exp_month = attributes[:'exp_month']
  else
    self.exp_month = nil
  end

  if attributes.key?(:'exp_year')
    self.exp_year = attributes[:'exp_year']
  else
    self.exp_year = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  else
    self.number = nil
  end

  if attributes.key?(:'customer_ip_address')
    self.customer_ip_address = attributes[:'customer_ip_address']
  end
end

Instance Attribute Details

#customer_ip_addressObject

Optional field used to capture the customer's IP address for fraud prevention and security monitoring purposes



37
38
39
# File 'lib/conekta/models/payment_method_card_request.rb', line 37

def customer_ip_address
  @customer_ip_address
end

#cvcObject

Card security code



22
23
24
# File 'lib/conekta/models/payment_method_card_request.rb', line 22

def cvc
  @cvc
end

#exp_monthObject

Card expiration month



25
26
27
# File 'lib/conekta/models/payment_method_card_request.rb', line 25

def exp_month
  @exp_month
end

#exp_yearObject

Card expiration year



28
29
30
# File 'lib/conekta/models/payment_method_card_request.rb', line 28

def exp_year
  @exp_year
end

#nameObject

Cardholder name



31
32
33
# File 'lib/conekta/models/payment_method_card_request.rb', line 31

def name
  @name
end

#numberObject

Card number



34
35
36
# File 'lib/conekta/models/payment_method_card_request.rb', line 34

def number
  @number
end

#typeObject

Type of payment method



19
20
21
# File 'lib/conekta/models/payment_method_card_request.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/conekta/models/payment_method_card_request.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/conekta/models/payment_method_card_request.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/conekta/models/payment_method_card_request.rb', line 40

def self.attribute_map
  {
    :'type' => :'type',
    :'cvc' => :'cvc',
    :'exp_month' => :'exp_month',
    :'exp_year' => :'exp_year',
    :'name' => :'name',
    :'number' => :'number',
    :'customer_ip_address' => :'customer_ip_address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/conekta/models/payment_method_card_request.rb', line 326

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/conekta/models/payment_method_card_request.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/conekta/models/payment_method_card_request.rb', line 63

def self.openapi_types
  {
    :'type' => :'String',
    :'cvc' => :'String',
    :'exp_month' => :'String',
    :'exp_year' => :'String',
    :'name' => :'String',
    :'number' => :'String',
    :'customer_ip_address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



299
300
301
302
303
304
305
306
307
308
309
# File 'lib/conekta/models/payment_method_card_request.rb', line 299

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      cvc == o.cvc &&
      exp_month == o.exp_month &&
      exp_year == o.exp_year &&
      name == o.name &&
      number == o.number &&
      customer_ip_address == o.customer_ip_address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


313
314
315
# File 'lib/conekta/models/payment_method_card_request.rb', line 313

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



319
320
321
# File 'lib/conekta/models/payment_method_card_request.rb', line 319

def hash
  [type, cvc, exp_month, exp_year, name, number, customer_ip_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/conekta/models/payment_method_card_request.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @cvc.nil?
    invalid_properties.push('invalid value for "cvc", cvc cannot be nil.')
  end

  if @cvc.to_s.length > 4
    invalid_properties.push('invalid value for "cvc", the character length must be smaller than or equal to 4.')
  end

  if @cvc.to_s.length < 3
    invalid_properties.push('invalid value for "cvc", the character length must be greater than or equal to 3.')
  end

  if @exp_month.nil?
    invalid_properties.push('invalid value for "exp_month", exp_month cannot be nil.')
  end

  if @exp_month.to_s.length > 2
    invalid_properties.push('invalid value for "exp_month", the character length must be smaller than or equal to 2.')
  end

  if @exp_month.to_s.length < 2
    invalid_properties.push('invalid value for "exp_month", the character length must be greater than or equal to 2.')
  end

  if @exp_year.nil?
    invalid_properties.push('invalid value for "exp_year", exp_year cannot be nil.')
  end

  if @exp_year.to_s.length > 4
    invalid_properties.push('invalid value for "exp_year", the character length must be smaller than or equal to 4.')
  end

  if @exp_year.to_s.length < 4
    invalid_properties.push('invalid value for "exp_year", the character length must be greater than or equal to 4.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @number.nil?
    invalid_properties.push('invalid value for "number", number cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/conekta/models/payment_method_card_request.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/conekta/models/payment_method_card_request.rb', line 196

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  return false if @cvc.nil?
  return false if @cvc.to_s.length > 4
  return false if @cvc.to_s.length < 3
  return false if @exp_month.nil?
  return false if @exp_month.to_s.length > 2
  return false if @exp_month.to_s.length < 2
  return false if @exp_year.nil?
  return false if @exp_year.to_s.length > 4
  return false if @exp_year.to_s.length < 4
  return false if @name.nil?
  return false if @number.nil?
  true
end