Class: Conekta::PaymentMethodCash

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payment_method_cash.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethodCash

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/conekta/models/payment_method_cash.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodCash` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodCash`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'agreement')
    self.agreement = attributes[:'agreement']
  end

  if attributes.key?(:'auth_code')
    self.auth_code = attributes[:'auth_code']
  end

  if attributes.key?(:'cashier_id')
    self.cashier_id = attributes[:'cashier_id']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'barcode_url')
    self.barcode_url = attributes[:'barcode_url']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'product_type')
    self.product_type = attributes[:'product_type']
  end

  if attributes.key?(:'service_name')
    self.service_name = attributes[:'service_name']
  end

  if attributes.key?(:'store')
    self.store = attributes[:'store']
  end

  if attributes.key?(:'store_name')
    self.store_name = attributes[:'store_name']
  end

  if attributes.key?(:'customer_ip_address')
    self.customer_ip_address = attributes[:'customer_ip_address']
  end
end

Instance Attribute Details

#agreementObject

Agreement ID



23
24
25
# File 'lib/conekta/models/payment_method_cash.rb', line 23

def agreement
  @agreement
end

#auth_codeObject

Returns the value of attribute auth_code.



25
26
27
# File 'lib/conekta/models/payment_method_cash.rb', line 25

def auth_code
  @auth_code
end

#barcode_urlObject

Returns the value of attribute barcode_url.



31
32
33
# File 'lib/conekta/models/payment_method_cash.rb', line 31

def barcode_url
  @barcode_url
end

#cashier_idObject

Returns the value of attribute cashier_id.



27
28
29
# File 'lib/conekta/models/payment_method_cash.rb', line 27

def cashier_id
  @cashier_id
end

#customer_ip_addressObject

Returns the value of attribute customer_ip_address.



44
45
46
# File 'lib/conekta/models/payment_method_cash.rb', line 44

def customer_ip_address
  @customer_ip_address
end

#expires_atObject

Returns the value of attribute expires_at.



33
34
35
# File 'lib/conekta/models/payment_method_cash.rb', line 33

def expires_at
  @expires_at
end

#objectObject

Returns the value of attribute object.



20
21
22
# File 'lib/conekta/models/payment_method_cash.rb', line 20

def object
  @object
end

#product_typeObject

Product type, e.g. bbva_cash_in, cash_in, pespay_cash_in, etc.



36
37
38
# File 'lib/conekta/models/payment_method_cash.rb', line 36

def product_type
  @product_type
end

#referenceObject

Returns the value of attribute reference.



29
30
31
# File 'lib/conekta/models/payment_method_cash.rb', line 29

def reference
  @reference
end

#service_nameObject

Returns the value of attribute service_name.



38
39
40
# File 'lib/conekta/models/payment_method_cash.rb', line 38

def service_name
  @service_name
end

#storeObject

Returns the value of attribute store.



40
41
42
# File 'lib/conekta/models/payment_method_cash.rb', line 40

def store
  @store
end

#store_nameObject

Returns the value of attribute store_name.



42
43
44
# File 'lib/conekta/models/payment_method_cash.rb', line 42

def store_name
  @store_name
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/conekta/models/payment_method_cash.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/conekta/models/payment_method_cash.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/conekta/models/payment_method_cash.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/conekta/models/payment_method_cash.rb', line 47

def self.attribute_map
  {
    :'type' => :'type',
    :'object' => :'object',
    :'agreement' => :'agreement',
    :'auth_code' => :'auth_code',
    :'cashier_id' => :'cashier_id',
    :'reference' => :'reference',
    :'barcode_url' => :'barcode_url',
    :'expires_at' => :'expires_at',
    :'product_type' => :'product_type',
    :'service_name' => :'service_name',
    :'store' => :'store',
    :'store_name' => :'store_name',
    :'customer_ip_address' => :'customer_ip_address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/conekta/models/payment_method_cash.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/conekta/models/payment_method_cash.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/conekta/models/payment_method_cash.rb', line 76

def self.openapi_types
  {
    :'type' => :'String',
    :'object' => :'String',
    :'agreement' => :'String',
    :'auth_code' => :'Integer',
    :'cashier_id' => :'String',
    :'reference' => :'String',
    :'barcode_url' => :'String',
    :'expires_at' => :'Integer',
    :'product_type' => :'String',
    :'service_name' => :'String',
    :'store' => :'String',
    :'store_name' => :'String',
    :'customer_ip_address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/conekta/models/payment_method_cash.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      object == o.object &&
      agreement == o.agreement &&
      auth_code == o.auth_code &&
      cashier_id == o.cashier_id &&
      reference == o.reference &&
      barcode_url == o.barcode_url &&
      expires_at == o.expires_at &&
      product_type == o.product_type &&
      service_name == o.service_name &&
      store == o.store &&
      store_name == o.store_name &&
      customer_ip_address == o.customer_ip_address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/conekta/models/payment_method_cash.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/conekta/models/payment_method_cash.rb', line 229

def hash
  [type, object, agreement, auth_code, cashier_id, reference, barcode_url, expires_at, product_type, service_name, store, store_name, customer_ip_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
# File 'lib/conekta/models/payment_method_cash.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/conekta/models/payment_method_cash.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
# File 'lib/conekta/models/payment_method_cash.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object.nil?
  true
end