Class: Conekta::PaymentMethodCashRecurrentResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::PaymentMethodCashRecurrentResponse
- Defined in:
- lib/conekta/models/payment_method_cash_recurrent_response.rb
Overview
Alias of cash response used when type=cash_recurrent
Instance Attribute Summary collapse
-
#agreements ⇒ Object
Returns the value of attribute agreements.
-
#barcode ⇒ Object
Returns the value of attribute barcode.
-
#barcode_url ⇒ Object
URL to the barcode image, reference is the same as barcode.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#object ⇒ Object
Returns the value of attribute object.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#reference ⇒ Object
Returns the value of attribute reference.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentMethodCashRecurrentResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PaymentMethodCashRecurrentResponse
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodCashRecurrentResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodCashRecurrentResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'agreements') if (value = attributes[:'agreements']).is_a?(Array) self.agreements = value end end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'barcode') self. = attributes[:'barcode'] end if attributes.key?(:'barcode_url') self. = attributes[:'barcode_url'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end end |
Instance Attribute Details
#agreements ⇒ Object
Returns the value of attribute agreements.
29 30 31 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 29 def agreements @agreements end |
#barcode ⇒ Object
Returns the value of attribute barcode.
33 34 35 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 33 def @barcode end |
#barcode_url ⇒ Object
URL to the barcode image, reference is the same as barcode
36 37 38 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 36 def @barcode_url end |
#created_at ⇒ Object
Returns the value of attribute created_at.
25 26 27 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 25 def created_at @created_at end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
38 39 40 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 38 def expires_at @expires_at end |
#id ⇒ Object
Returns the value of attribute id.
21 22 23 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 21 def id @id end |
#object ⇒ Object
Returns the value of attribute object.
23 24 25 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 23 def object @object end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
27 28 29 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 27 def parent_id @parent_id end |
#provider ⇒ Object
Returns the value of attribute provider.
40 41 42 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 40 def provider @provider end |
#reference ⇒ Object
Returns the value of attribute reference.
31 32 33 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 31 def reference @reference end |
#type ⇒ Object
Returns the value of attribute type.
19 20 21 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 19 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 43 def self.attribute_map { :'type' => :'type', :'id' => :'id', :'object' => :'object', :'created_at' => :'created_at', :'parent_id' => :'parent_id', :'agreements' => :'agreements', :'reference' => :'reference', :'barcode' => :'barcode', :'barcode_url' => :'barcode_url', :'expires_at' => :'expires_at', :'provider' => :'provider' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 70 def self.openapi_types { :'type' => :'String', :'id' => :'String', :'object' => :'String', :'created_at' => :'Integer', :'parent_id' => :'String', :'agreements' => :'Array<CashAgreementsResponse>', :'reference' => :'String', :'barcode' => :'String', :'barcode_url' => :'String', :'expires_at' => :'Integer', :'provider' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && id == o.id && object == o.object && created_at == o.created_at && parent_id == o.parent_id && agreements == o.agreements && reference == o.reference && == o. && == o. && expires_at == o.expires_at && provider == o.provider end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 264 def hash [type, id, object, created_at, parent_id, agreements, reference, , , expires_at, provider].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 |
# File 'lib/conekta/models/payment_method_cash_recurrent_response.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? return false if @id.nil? return false if @object.nil? return false if @created_at.nil? true end |