Class: Conekta::PaymentMethodGeneralRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::PaymentMethodGeneralRequest
- Defined in:
- lib/conekta/models/payment_method_general_request.rb
Overview
Payment method used in the charge. Go to the payment methods section for more details
Instance Attribute Summary collapse
-
#contract_id ⇒ Object
Optional id sent to indicate the bank contract for recurrent card charges.
-
#customer_ip_address ⇒ Object
Optional field used to capture the customer's IP address for fraud prevention and security monitoring purposes.
-
#cvc ⇒ Object
Optional, It is a value that allows identifying the security code of the card.
-
#expires_at ⇒ Object
Method expiration date as unix timestamp.
-
#monthly_installments ⇒ Object
How many months without interest to apply, it can be 3, 6, 9, 12 or 18.
-
#payment_source_id ⇒ Object
Returns the value of attribute payment_source_id.
-
#token_id ⇒ Object
Returns the value of attribute token_id.
-
#type ⇒ Object
Type of payment method.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentMethodGeneralRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PaymentMethodGeneralRequest
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodGeneralRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodGeneralRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'monthly_installments') self.monthly_installments = attributes[:'monthly_installments'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'token_id') self.token_id = attributes[:'token_id'] end if attributes.key?(:'payment_source_id') self.payment_source_id = attributes[:'payment_source_id'] end if attributes.key?(:'cvc') self.cvc = attributes[:'cvc'] end if attributes.key?(:'contract_id') self.contract_id = attributes[:'contract_id'] end if attributes.key?(:'customer_ip_address') self.customer_ip_address = attributes[:'customer_ip_address'] end end |
Instance Attribute Details
#contract_id ⇒ Object
Optional id sent to indicate the bank contract for recurrent card charges.
36 37 38 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 36 def contract_id @contract_id end |
#customer_ip_address ⇒ Object
Optional field used to capture the customer's IP address for fraud prevention and security monitoring purposes
39 40 41 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 39 def customer_ip_address @customer_ip_address end |
#cvc ⇒ Object
Optional, It is a value that allows identifying the security code of the card. Only for PCI merchants
33 34 35 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 33 def cvc @cvc end |
#expires_at ⇒ Object
Method expiration date as unix timestamp
20 21 22 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 20 def expires_at @expires_at end |
#monthly_installments ⇒ Object
How many months without interest to apply, it can be 3, 6, 9, 12 or 18
23 24 25 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 23 def monthly_installments @monthly_installments end |
#payment_source_id ⇒ Object
Returns the value of attribute payment_source_id.
30 31 32 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 30 def payment_source_id @payment_source_id end |
#token_id ⇒ Object
Returns the value of attribute token_id.
28 29 30 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 28 def token_id @token_id end |
#type ⇒ Object
Type of payment method
26 27 28 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 26 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 42 def self.attribute_map { :'expires_at' => :'expires_at', :'monthly_installments' => :'monthly_installments', :'type' => :'type', :'token_id' => :'token_id', :'payment_source_id' => :'payment_source_id', :'cvc' => :'cvc', :'contract_id' => :'contract_id', :'customer_ip_address' => :'customer_ip_address' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 196 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 66 def self.openapi_types { :'expires_at' => :'Integer', :'monthly_installments' => :'Integer', :'type' => :'String', :'token_id' => :'String', :'payment_source_id' => :'String', :'cvc' => :'String', :'contract_id' => :'String', :'customer_ip_address' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && expires_at == o.expires_at && monthly_installments == o.monthly_installments && type == o.type && token_id == o.token_id && payment_source_id == o.payment_source_id && cvc == o.cvc && contract_id == o.contract_id && customer_ip_address == o.customer_ip_address end |
#eql?(o) ⇒ Boolean
183 184 185 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 183 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 189 def hash [expires_at, monthly_installments, type, token_id, payment_source_id, cvc, contract_id, customer_ip_address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 |
# File 'lib/conekta/models/payment_method_general_request.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? true end |