Class: Conekta::PayoutOrderPayoutsItem

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payout_order_payouts_item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PayoutOrderPayoutsItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PayoutOrderPayoutsItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PayoutOrderPayoutsItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  else
    self.livemode = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'payout_order_id')
    self.payout_order_id = attributes[:'payout_order_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#amountObject

The amount of the payout.



19
20
21
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 19

def amount
  @amount
end

#currencyObject

The currency in which the payout is made.



22
23
24
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 22

def currency
  @currency
end

#expires_atObject

The expiration date of the payout.



25
26
27
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 25

def expires_at
  @expires_at
end

#idObject

The id of the payout.



28
29
30
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 28

def id
  @id
end

#livemodeObject

The live mode of the payout.



31
32
33
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 31

def livemode
  @livemode
end

#objectObject

The object of the payout.



34
35
36
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 34

def object
  @object
end

#payout_order_idObject

The id of the payout order.



37
38
39
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 37

def payout_order_id
  @payout_order_id
end

#statusObject

The status of the payout.



40
41
42
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 40

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 43

def self.attribute_map
  {
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'expires_at' => :'expires_at',
    :'id' => :'id',
    :'livemode' => :'livemode',
    :'object' => :'object',
    :'payout_order_id' => :'payout_order_id',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 265

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 67

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'currency' => :'String',
    :'expires_at' => :'Integer',
    :'id' => :'String',
    :'livemode' => :'Boolean',
    :'object' => :'String',
    :'payout_order_id' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 237

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      currency == o.currency &&
      expires_at == o.expires_at &&
      id == o.id &&
      livemode == o.livemode &&
      object == o.object &&
      payout_order_id == o.payout_order_id &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 258

def hash
  [amount, currency, expires_at, id, livemode, object, payout_order_id, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @livemode.nil?
    invalid_properties.push('invalid value for "livemode", livemode cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



175
176
177
178
179
180
181
182
183
# File 'lib/conekta/models/payout_order_payouts_item.rb', line 175

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @currency.nil?
  return false if @id.nil?
  return false if @livemode.nil?
  return false if @object.nil?
  true
end