Class: Conekta::PayoutOrderRequest

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payout_order_request.rb

Overview

a payout order

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PayoutOrderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/conekta/models/payout_order_request.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PayoutOrderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PayoutOrderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allowed_payout_methods')
    if (value = attributes[:'allowed_payout_methods']).is_a?(Array)
      self.allowed_payout_methods = value
    end
  else
    self.allowed_payout_methods = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = 'MXN'
  end

  if attributes.key?(:'customer_info')
    self.customer_info = attributes[:'customer_info']
  else
    self.customer_info = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'payout')
    self.payout = attributes[:'payout']
  else
    self.payout = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end
end

Instance Attribute Details

#allowed_payout_methodsObject

The payout methods that are allowed for the payout order.



20
21
22
# File 'lib/conekta/models/payout_order_request.rb', line 20

def allowed_payout_methods
  @allowed_payout_methods
end

#amountObject

The amount of the payout order.



23
24
25
# File 'lib/conekta/models/payout_order_request.rb', line 23

def amount
  @amount
end

#currencyObject

The currency in which the payout order is made.



26
27
28
# File 'lib/conekta/models/payout_order_request.rb', line 26

def currency
  @currency
end

#customer_infoObject

Returns the value of attribute customer_info.



28
29
30
# File 'lib/conekta/models/payout_order_request.rb', line 28

def customer_info
  @customer_info
end

#expires_atObject

The expiration time of the payout order in Unix timestamp.



31
32
33
# File 'lib/conekta/models/payout_order_request.rb', line 31

def expires_at
  @expires_at
end

#metadataObject

The metadata of the payout order.



34
35
36
# File 'lib/conekta/models/payout_order_request.rb', line 34

def 
  @metadata
end

#payoutObject

Returns the value of attribute payout.



36
37
38
# File 'lib/conekta/models/payout_order_request.rb', line 36

def payout
  @payout
end

#reasonObject

The reason for the payout order.



39
40
41
# File 'lib/conekta/models/payout_order_request.rb', line 39

def reason
  @reason
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/conekta/models/payout_order_request.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/conekta/models/payout_order_request.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/conekta/models/payout_order_request.rb', line 42

def self.attribute_map
  {
    :'allowed_payout_methods' => :'allowed_payout_methods',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'customer_info' => :'customer_info',
    :'expires_at' => :'expires_at',
    :'metadata' => :'metadata',
    :'payout' => :'payout',
    :'reason' => :'reason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/conekta/models/payout_order_request.rb', line 321

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/conekta/models/payout_order_request.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/conekta/models/payout_order_request.rb', line 66

def self.openapi_types
  {
    :'allowed_payout_methods' => :'Array<String>',
    :'amount' => :'Integer',
    :'currency' => :'String',
    :'customer_info' => :'PayoutOrderRequestCustomerInfo',
    :'expires_at' => :'Integer',
    :'metadata' => :'Hash<String, Object>',
    :'payout' => :'Payout',
    :'reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/conekta/models/payout_order_request.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allowed_payout_methods == o.allowed_payout_methods &&
      amount == o.amount &&
      currency == o.currency &&
      customer_info == o.customer_info &&
      expires_at == o.expires_at &&
       == o. &&
      payout == o.payout &&
      reason == o.reason
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/conekta/models/payout_order_request.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



314
315
316
# File 'lib/conekta/models/payout_order_request.rb', line 314

def hash
  [allowed_payout_methods, amount, currency, customer_info, expires_at, , payout, reason].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/conekta/models/payout_order_request.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @allowed_payout_methods.nil?
    invalid_properties.push('invalid value for "allowed_payout_methods", allowed_payout_methods cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @customer_info.nil?
    invalid_properties.push('invalid value for "customer_info", customer_info cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  if @payout.nil?
    invalid_properties.push('invalid value for "payout", payout cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/conekta/models/payout_order_request.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/conekta/models/payout_order_request.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @allowed_payout_methods.nil?
  return false if @amount.nil?
  return false if @currency.nil?
  return false if @customer_info.nil?
  return false if @expires_at.nil?
  return false if !@metadata.nil? && @metadata.length > 100
  return false if @payout.nil?
  return false if @reason.nil?
  true
end