Class: Conekta::PayoutOrderResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/payout_order_response.rb

Overview

payout order model response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PayoutOrderResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/conekta/models/payout_order_response.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PayoutOrderResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PayoutOrderResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allowed_payout_methods')
    if (value = attributes[:'allowed_payout_methods']).is_a?(Array)
      self.allowed_payout_methods = value
    end
  else
    self.allowed_payout_methods = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = 'MXN'
  end

  if attributes.key?(:'customer_info')
    self.customer_info = attributes[:'customer_info']
  else
    self.customer_info = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  else
    self.livemode = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'payouts')
    if (value = attributes[:'payouts']).is_a?(Array)
      self.payouts = value
    end
  else
    self.payouts = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#allowed_payout_methodsObject

The payout methods that are allowed for the payout order.



20
21
22
# File 'lib/conekta/models/payout_order_response.rb', line 20

def allowed_payout_methods
  @allowed_payout_methods
end

#amountObject

The amount of the payout order.



23
24
25
# File 'lib/conekta/models/payout_order_response.rb', line 23

def amount
  @amount
end

#created_atObject

The creation date of the payout order.



26
27
28
# File 'lib/conekta/models/payout_order_response.rb', line 26

def created_at
  @created_at
end

#currencyObject

The currency in which the payout order is made.



29
30
31
# File 'lib/conekta/models/payout_order_response.rb', line 29

def currency
  @currency
end

#customer_infoObject

Returns the value of attribute customer_info.



31
32
33
# File 'lib/conekta/models/payout_order_response.rb', line 31

def customer_info
  @customer_info
end

#expires_atObject

The expiration date of the payout order.



34
35
36
# File 'lib/conekta/models/payout_order_response.rb', line 34

def expires_at
  @expires_at
end

#idObject

The id of the payout order.



37
38
39
# File 'lib/conekta/models/payout_order_response.rb', line 37

def id
  @id
end

#livemodeObject

The live mode of the payout order.



40
41
42
# File 'lib/conekta/models/payout_order_response.rb', line 40

def livemode
  @livemode
end

#metadataObject

The metadata of the payout order.



46
47
48
# File 'lib/conekta/models/payout_order_response.rb', line 46

def 
  @metadata
end

#objectObject

The object of the payout order.



43
44
45
# File 'lib/conekta/models/payout_order_response.rb', line 43

def object
  @object
end

#payoutsObject

The payout information of the payout order.



49
50
51
# File 'lib/conekta/models/payout_order_response.rb', line 49

def payouts
  @payouts
end

#reasonObject

The reason for the payout order.



52
53
54
# File 'lib/conekta/models/payout_order_response.rb', line 52

def reason
  @reason
end

#statusObject

The status of the payout order.



55
56
57
# File 'lib/conekta/models/payout_order_response.rb', line 55

def status
  @status
end

#updated_atObject

The update date of the payout order.



58
59
60
# File 'lib/conekta/models/payout_order_response.rb', line 58

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/conekta/models/payout_order_response.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/conekta/models/payout_order_response.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/conekta/models/payout_order_response.rb', line 61

def self.attribute_map
  {
    :'allowed_payout_methods' => :'allowed_payout_methods',
    :'amount' => :'amount',
    :'created_at' => :'created_at',
    :'currency' => :'currency',
    :'customer_info' => :'customer_info',
    :'expires_at' => :'expires_at',
    :'id' => :'id',
    :'livemode' => :'livemode',
    :'object' => :'object',
    :'metadata' => :'metadata',
    :'payouts' => :'payouts',
    :'reason' => :'reason',
    :'status' => :'status',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/conekta/models/payout_order_response.rb', line 495

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/conekta/models/payout_order_response.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/conekta/models/payout_order_response.rb', line 91

def self.openapi_types
  {
    :'allowed_payout_methods' => :'Array<String>',
    :'amount' => :'Integer',
    :'created_at' => :'Integer',
    :'currency' => :'String',
    :'customer_info' => :'PayoutOrderResponseCustomerInfo',
    :'expires_at' => :'Integer',
    :'id' => :'String',
    :'livemode' => :'Boolean',
    :'object' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'payouts' => :'Array<PayoutOrderPayoutsItem>',
    :'reason' => :'String',
    :'status' => :'String',
    :'updated_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/conekta/models/payout_order_response.rb', line 461

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allowed_payout_methods == o.allowed_payout_methods &&
      amount == o.amount &&
      created_at == o.created_at &&
      currency == o.currency &&
      customer_info == o.customer_info &&
      expires_at == o.expires_at &&
      id == o.id &&
      livemode == o.livemode &&
      object == o.object &&
       == o. &&
      payouts == o.payouts &&
      reason == o.reason &&
      status == o.status &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


482
483
484
# File 'lib/conekta/models/payout_order_response.rb', line 482

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



488
489
490
# File 'lib/conekta/models/payout_order_response.rb', line 488

def hash
  [allowed_payout_methods, amount, created_at, currency, customer_info, expires_at, id, livemode, object, , payouts, reason, status, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/conekta/models/payout_order_response.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @allowed_payout_methods.nil?
    invalid_properties.push('invalid value for "allowed_payout_methods", allowed_payout_methods cannot be nil.')
  end

  if @allowed_payout_methods.length < 1
    invalid_properties.push('invalid value for "allowed_payout_methods", number of items must be greater than or equal to 1.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @customer_info.nil?
    invalid_properties.push('invalid value for "customer_info", customer_info cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @livemode.nil?
    invalid_properties.push('invalid value for "livemode", livemode cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  if @payouts.nil?
    invalid_properties.push('invalid value for "payouts", payouts cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



517
518
519
520
521
522
523
524
525
526
527
528
529
# File 'lib/conekta/models/payout_order_response.rb', line 517

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/conekta/models/payout_order_response.rb', line 291

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @allowed_payout_methods.nil?
  return false if @allowed_payout_methods.length < 1
  return false if @amount.nil?
  return false if @created_at.nil?
  return false if @currency.nil?
  return false if @customer_info.nil?
  return false if @expires_at.nil?
  return false if @id.nil?
  return false if @livemode.nil?
  return false if @object.nil?
  return false if !@metadata.nil? && @metadata.length > 100
  return false if @payouts.nil?
  return false if @reason.nil?
  return false if @status.nil?
  return false if @updated_at.nil?
  true
end