Class: Conekta::PlanRequest

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/plan_request.rb

Overview

a plan

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PlanRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/conekta/models/plan_request.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PlanRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PlanRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'expiry_count')
    self.expiry_count = attributes[:'expiry_count']
  end

  if attributes.key?(:'frequency')
    self.frequency = attributes[:'frequency']
  else
    self.frequency = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'interval')
    self.interval = attributes[:'interval']
  else
    self.interval = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'trial_period_days')
    self.trial_period_days = attributes[:'trial_period_days']
  end

  if attributes.key?(:'max_retries')
    self.max_retries = attributes[:'max_retries']
  end

  if attributes.key?(:'retry_delay_hours')
    self.retry_delay_hours = attributes[:'retry_delay_hours']
  end
end

Instance Attribute Details

#amountObject

The amount in cents that will be charged on the interval specified.



20
21
22
# File 'lib/conekta/models/plan_request.rb', line 20

def amount
  @amount
end

#currencyObject

ISO 4217 for currencies, for the Mexican peso it is MXN/USD



23
24
25
# File 'lib/conekta/models/plan_request.rb', line 23

def currency
  @currency
end

#expiry_countObject

Number of repetitions of the frequency NUMBER OF CHARGES TO BE MADE, considering the interval and frequency, this evolves over time, but is subject to the expiration count.



26
27
28
# File 'lib/conekta/models/plan_request.rb', line 26

def expiry_count
  @expiry_count
end

#frequencyObject

Frequency of the charge, which together with the interval, can be every 3 weeks, every 4 months, every 2 years, every 5 fortnights



29
30
31
# File 'lib/conekta/models/plan_request.rb', line 29

def frequency
  @frequency
end

#idObject

internal reference id



32
33
34
# File 'lib/conekta/models/plan_request.rb', line 32

def id
  @id
end

#intervalObject

The interval of time between each charge.



35
36
37
# File 'lib/conekta/models/plan_request.rb', line 35

def interval
  @interval
end

#max_retriesObject

(optional) Specifies the maximum number of retry attempts for a subscription payment before it is canceled.



44
45
46
# File 'lib/conekta/models/plan_request.rb', line 44

def max_retries
  @max_retries
end

#nameObject

The name of the plan.



38
39
40
# File 'lib/conekta/models/plan_request.rb', line 38

def name
  @name
end

#retry_delay_hoursObject

(optional) Defines the number of hours between subscription payment retry attempts.



47
48
49
# File 'lib/conekta/models/plan_request.rb', line 47

def retry_delay_hours
  @retry_delay_hours
end

#trial_period_daysObject

The number of days the customer will have a free trial.



41
42
43
# File 'lib/conekta/models/plan_request.rb', line 41

def trial_period_days
  @trial_period_days
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/conekta/models/plan_request.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/conekta/models/plan_request.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/conekta/models/plan_request.rb', line 72

def self.attribute_map
  {
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'expiry_count' => :'expiry_count',
    :'frequency' => :'frequency',
    :'id' => :'id',
    :'interval' => :'interval',
    :'name' => :'name',
    :'trial_period_days' => :'trial_period_days',
    :'max_retries' => :'max_retries',
    :'retry_delay_hours' => :'retry_delay_hours'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/conekta/models/plan_request.rb', line 368

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/conekta/models/plan_request.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/conekta/models/plan_request.rb', line 98

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'currency' => :'String',
    :'expiry_count' => :'Integer',
    :'frequency' => :'Integer',
    :'id' => :'String',
    :'interval' => :'String',
    :'name' => :'String',
    :'trial_period_days' => :'Integer',
    :'max_retries' => :'Integer',
    :'retry_delay_hours' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/conekta/models/plan_request.rb', line 338

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      currency == o.currency &&
      expiry_count == o.expiry_count &&
      frequency == o.frequency &&
      id == o.id &&
      interval == o.interval &&
      name == o.name &&
      trial_period_days == o.trial_period_days &&
      max_retries == o.max_retries &&
      retry_delay_hours == o.retry_delay_hours
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


355
356
357
# File 'lib/conekta/models/plan_request.rb', line 355

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



361
362
363
# File 'lib/conekta/models/plan_request.rb', line 361

def hash
  [amount, currency, expiry_count, frequency, id, interval, name, trial_period_days, max_retries, retry_delay_hours].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/conekta/models/plan_request.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 1
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 1.')
  end

  if !@currency.nil? && @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if @frequency.nil?
    invalid_properties.push('invalid value for "frequency", frequency cannot be nil.')
  end

  if @frequency < 1
    invalid_properties.push('invalid value for "frequency", must be greater than or equal to 1.')
  end

  if @interval.nil?
    invalid_properties.push('invalid value for "interval", interval cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@max_retries.nil? && @max_retries < 3
    invalid_properties.push('invalid value for "max_retries", must be greater than or equal to 3.')
  end

  if !@retry_delay_hours.nil? && @retry_delay_hours < 48
    invalid_properties.push('invalid value for "retry_delay_hours", must be greater than or equal to 48.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/conekta/models/plan_request.rb', line 390

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/conekta/models/plan_request.rb', line 230

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 1
  return false if !@currency.nil? && @currency.to_s.length > 3
  return false if @frequency.nil?
  return false if @frequency < 1
  return false if @interval.nil?
  interval_validator = EnumAttributeValidator.new('String', ["week", "half_month", "month", "year"])
  return false unless interval_validator.valid?(@interval)
  return false if @name.nil?
  return false if !@max_retries.nil? && @max_retries < 3
  return false if !@retry_delay_hours.nil? && @retry_delay_hours < 48
  true
end