Class: Conekta::PlanResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/plan_response.rb

Overview

plans model

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PlanResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/conekta/models/plan_response.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PlanResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PlanResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'expiry_count')
    self.expiry_count = attributes[:'expiry_count']
  end

  if attributes.key?(:'frequency')
    self.frequency = attributes[:'frequency']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'interval')
    self.interval = attributes[:'interval']
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'trial_period_days')
    self.trial_period_days = attributes[:'trial_period_days']
  end

  if attributes.key?(:'max_retries')
    self.max_retries = attributes[:'max_retries']
  end

  if attributes.key?(:'retry_delay_hours')
    self.retry_delay_hours = attributes[:'retry_delay_hours']
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



19
20
21
# File 'lib/conekta/models/plan_response.rb', line 19

def amount
  @amount
end

#created_atObject

Returns the value of attribute created_at.



21
22
23
# File 'lib/conekta/models/plan_response.rb', line 21

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



23
24
25
# File 'lib/conekta/models/plan_response.rb', line 23

def currency
  @currency
end

#expiry_countObject

Returns the value of attribute expiry_count.



25
26
27
# File 'lib/conekta/models/plan_response.rb', line 25

def expiry_count
  @expiry_count
end

#frequencyObject

Returns the value of attribute frequency.



27
28
29
# File 'lib/conekta/models/plan_response.rb', line 27

def frequency
  @frequency
end

#idObject

Returns the value of attribute id.



29
30
31
# File 'lib/conekta/models/plan_response.rb', line 29

def id
  @id
end

#intervalObject

Returns the value of attribute interval.



31
32
33
# File 'lib/conekta/models/plan_response.rb', line 31

def interval
  @interval
end

#livemodeObject

Returns the value of attribute livemode.



33
34
35
# File 'lib/conekta/models/plan_response.rb', line 33

def livemode
  @livemode
end

#max_retriesObject

Returns the value of attribute max_retries.



41
42
43
# File 'lib/conekta/models/plan_response.rb', line 41

def max_retries
  @max_retries
end

#nameObject

Returns the value of attribute name.



35
36
37
# File 'lib/conekta/models/plan_response.rb', line 35

def name
  @name
end

#objectObject

Returns the value of attribute object.



37
38
39
# File 'lib/conekta/models/plan_response.rb', line 37

def object
  @object
end

#retry_delay_hoursObject

Returns the value of attribute retry_delay_hours.



43
44
45
# File 'lib/conekta/models/plan_response.rb', line 43

def retry_delay_hours
  @retry_delay_hours
end

#trial_period_daysObject

Returns the value of attribute trial_period_days.



39
40
41
# File 'lib/conekta/models/plan_response.rb', line 39

def trial_period_days
  @trial_period_days
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/conekta/models/plan_response.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/conekta/models/plan_response.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/conekta/models/plan_response.rb', line 46

def self.attribute_map
  {
    :'amount' => :'amount',
    :'created_at' => :'created_at',
    :'currency' => :'currency',
    :'expiry_count' => :'expiry_count',
    :'frequency' => :'frequency',
    :'id' => :'id',
    :'interval' => :'interval',
    :'livemode' => :'livemode',
    :'name' => :'name',
    :'object' => :'object',
    :'trial_period_days' => :'trial_period_days',
    :'max_retries' => :'max_retries',
    :'retry_delay_hours' => :'retry_delay_hours'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/conekta/models/plan_response.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/conekta/models/plan_response.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/conekta/models/plan_response.rb', line 75

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'created_at' => :'Integer',
    :'currency' => :'String',
    :'expiry_count' => :'Integer',
    :'frequency' => :'Integer',
    :'id' => :'String',
    :'interval' => :'String',
    :'livemode' => :'Boolean',
    :'name' => :'String',
    :'object' => :'String',
    :'trial_period_days' => :'Integer',
    :'max_retries' => :'Integer',
    :'retry_delay_hours' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/conekta/models/plan_response.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      created_at == o.created_at &&
      currency == o.currency &&
      expiry_count == o.expiry_count &&
      frequency == o.frequency &&
      id == o.id &&
      interval == o.interval &&
      livemode == o.livemode &&
      name == o.name &&
      object == o.object &&
      trial_period_days == o.trial_period_days &&
      max_retries == o.max_retries &&
      retry_delay_hours == o.retry_delay_hours
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/conekta/models/plan_response.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/conekta/models/plan_response.rb', line 230

def hash
  [amount, created_at, currency, expiry_count, frequency, id, interval, livemode, name, object, trial_period_days, max_retries, retry_delay_hours].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
# File 'lib/conekta/models/plan_response.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@currency.nil? && @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/conekta/models/plan_response.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
# File 'lib/conekta/models/plan_response.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@currency.nil? && @currency.to_s.length > 3
  true
end