Class: Conekta::ProductOrderResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/product_order_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProductOrderResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/conekta/models/product_order_response.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ProductOrderResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ProductOrderResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'antifraud_info')
    if (value = attributes[:'antifraud_info']).is_a?(Hash)
      self.antifraud_info = value
    end
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  else
    self.quantity = nil
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'unit_price')
    self.unit_price = attributes[:'unit_price']
  else
    self.unit_price = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end
end

Instance Attribute Details

#antifraud_infoObject

Returns the value of attribute antifraud_info.



18
19
20
# File 'lib/conekta/models/product_order_response.rb', line 18

def antifraud_info
  @antifraud_info
end

#brandObject

The brand of the item.



21
22
23
# File 'lib/conekta/models/product_order_response.rb', line 21

def brand
  @brand
end

#descriptionObject

Short description of the item



24
25
26
# File 'lib/conekta/models/product_order_response.rb', line 24

def description
  @description
end

#idObject

Returns the value of attribute id.



44
45
46
# File 'lib/conekta/models/product_order_response.rb', line 44

def id
  @id
end

#metadataObject

It is a key/value hash that can hold custom fields. Maximum 100 elements and allows special characters.



27
28
29
# File 'lib/conekta/models/product_order_response.rb', line 27

def 
  @metadata
end

#nameObject

The name of the item. It will be displayed in the order.



30
31
32
# File 'lib/conekta/models/product_order_response.rb', line 30

def name
  @name
end

#objectObject

Returns the value of attribute object.



46
47
48
# File 'lib/conekta/models/product_order_response.rb', line 46

def object
  @object
end

#parent_idObject

Returns the value of attribute parent_id.



48
49
50
# File 'lib/conekta/models/product_order_response.rb', line 48

def parent_id
  @parent_id
end

#quantityObject

The quantity of the item in the order.



33
34
35
# File 'lib/conekta/models/product_order_response.rb', line 33

def quantity
  @quantity
end

#skuObject

The stock keeping unit for the item. It is used to identify the item in the order.



36
37
38
# File 'lib/conekta/models/product_order_response.rb', line 36

def sku
  @sku
end

#tagsObject

List of tags for the item. It is used to identify the item in the order.



39
40
41
# File 'lib/conekta/models/product_order_response.rb', line 39

def tags
  @tags
end

#unit_priceObject

The price of the item in cents.



42
43
44
# File 'lib/conekta/models/product_order_response.rb', line 42

def unit_price
  @unit_price
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/conekta/models/product_order_response.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/conekta/models/product_order_response.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/conekta/models/product_order_response.rb', line 51

def self.attribute_map
  {
    :'antifraud_info' => :'antifraud_info',
    :'brand' => :'brand',
    :'description' => :'description',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'quantity' => :'quantity',
    :'sku' => :'sku',
    :'tags' => :'tags',
    :'unit_price' => :'unit_price',
    :'id' => :'id',
    :'object' => :'object',
    :'parent_id' => :'parent_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/conekta/models/product_order_response.rb', line 329

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/conekta/models/product_order_response.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/conekta/models/product_order_response.rb', line 79

def self.openapi_types
  {
    :'antifraud_info' => :'Hash<String, Object>',
    :'brand' => :'String',
    :'description' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'name' => :'String',
    :'quantity' => :'Integer',
    :'sku' => :'String',
    :'tags' => :'Array<String>',
    :'unit_price' => :'Integer',
    :'id' => :'String',
    :'object' => :'String',
    :'parent_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/conekta/models/product_order_response.rb', line 297

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      antifraud_info == o.antifraud_info &&
      brand == o.brand &&
      description == o.description &&
       == o. &&
      name == o.name &&
      quantity == o.quantity &&
      sku == o.sku &&
      tags == o.tags &&
      unit_price == o.unit_price &&
      id == o.id &&
      object == o.object &&
      parent_id == o.parent_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


316
317
318
# File 'lib/conekta/models/product_order_response.rb', line 316

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



322
323
324
# File 'lib/conekta/models/product_order_response.rb', line 322

def hash
  [antifraud_info, brand, description, , name, quantity, sku, tags, unit_price, id, object, parent_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/conekta/models/product_order_response.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @quantity.nil?
    invalid_properties.push('invalid value for "quantity", quantity cannot be nil.')
  end

  if @quantity < 1
    invalid_properties.push('invalid value for "quantity", must be greater than or equal to 1.')
  end

  if @unit_price.nil?
    invalid_properties.push('invalid value for "unit_price", unit_price cannot be nil.')
  end

  if @unit_price < 0
    invalid_properties.push('invalid value for "unit_price", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/conekta/models/product_order_response.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
223
224
225
226
227
# File 'lib/conekta/models/product_order_response.rb', line 217

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@description.nil? && @description.to_s.length > 250
  return false if !@metadata.nil? && @metadata.length > 100
  return false if @name.nil?
  return false if @quantity.nil?
  return false if @quantity < 1
  return false if @unit_price.nil?
  return false if @unit_price < 0
  true
end