Class: Conekta::ShippingLinesDataResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/shipping_lines_data_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ShippingLinesDataResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ShippingLinesDataResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ShippingLinesDataResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'carrier')
    self.carrier = attributes[:'carrier']
  end

  if attributes.key?(:'tracking_number')
    self.tracking_number = attributes[:'tracking_number']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end
end

Instance Attribute Details

#amountObject

Shipping amount in cents



19
20
21
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 19

def amount
  @amount
end

#carrierObject

Carrier name for the shipment



22
23
24
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 22

def carrier
  @carrier
end

#idObject

Returns the value of attribute id.



33
34
35
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 33

def id
  @id
end

#metadataObject

Hash where the user can send additional information for each 'shipping'.



31
32
33
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 31

def 
  @metadata
end

#methodObject

Method of shipment



28
29
30
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 28

def method
  @method
end

#objectObject

Returns the value of attribute object.



35
36
37
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 35

def object
  @object
end

#parent_idObject

Returns the value of attribute parent_id.



37
38
39
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 37

def parent_id
  @parent_id
end

#tracking_numberObject

Tracking number can be used to track the shipment



25
26
27
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 25

def tracking_number
  @tracking_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 40

def self.attribute_map
  {
    :'amount' => :'amount',
    :'carrier' => :'carrier',
    :'tracking_number' => :'tracking_number',
    :'method' => :'method',
    :'metadata' => :'metadata',
    :'id' => :'id',
    :'object' => :'object',
    :'parent_id' => :'parent_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 64

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'carrier' => :'String',
    :'tracking_number' => :'String',
    :'method' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'id' => :'String',
    :'object' => :'String',
    :'parent_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      carrier == o.carrier &&
      tracking_number == o.tracking_number &&
      method == o.method &&
       == o. &&
      id == o.id &&
      object == o.object &&
      parent_id == o.parent_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 217

def hash
  [amount, carrier, tracking_number, method, , id, object, parent_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
# File 'lib/conekta/models/shipping_lines_data_response.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 0
  return false if !@metadata.nil? && @metadata.length > 100
  true
end