Class: Conekta::SubscriptionDetailsCard

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/subscription_details_card.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionDetailsCard

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/conekta/models/subscription_details_card.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::SubscriptionDetailsCard` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::SubscriptionDetailsCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'exp_month')
    self.exp_month = attributes[:'exp_month']
  end

  if attributes.key?(:'exp_year')
    self.exp_year = attributes[:'exp_year']
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'last4')
    self.last4 = attributes[:'last4']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'payment_source_status')
    self.payment_source_status = attributes[:'payment_source_status']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'customer_custom_reference')
    self.customer_custom_reference = attributes[:'customer_custom_reference']
  end
end

Instance Attribute Details

#activeObject

Returns the value of attribute active.



22
23
24
# File 'lib/conekta/models/subscription_details_card.rb', line 22

def active
  @active
end

#brandObject

Returns the value of attribute brand.



30
31
32
# File 'lib/conekta/models/subscription_details_card.rb', line 30

def brand
  @brand
end

#created_atObject

Returns the value of attribute created_at.



20
21
22
# File 'lib/conekta/models/subscription_details_card.rb', line 20

def created_at
  @created_at
end

#customer_custom_referenceObject

Returns the value of attribute customer_custom_reference.



40
41
42
# File 'lib/conekta/models/subscription_details_card.rb', line 40

def customer_custom_reference
  @customer_custom_reference
end

#customer_idObject

Returns the value of attribute customer_id.



38
39
40
# File 'lib/conekta/models/subscription_details_card.rb', line 38

def customer_id
  @customer_id
end

#exp_monthObject

Returns the value of attribute exp_month.



26
27
28
# File 'lib/conekta/models/subscription_details_card.rb', line 26

def exp_month
  @exp_month
end

#exp_yearObject

Returns the value of attribute exp_year.



28
29
30
# File 'lib/conekta/models/subscription_details_card.rb', line 28

def exp_year
  @exp_year
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/conekta/models/subscription_details_card.rb', line 18

def id
  @id
end

#last4Object

Returns the value of attribute last4.



32
33
34
# File 'lib/conekta/models/subscription_details_card.rb', line 32

def last4
  @last4
end

#nameObject

Returns the value of attribute name.



34
35
36
# File 'lib/conekta/models/subscription_details_card.rb', line 34

def name
  @name
end

#objectObject

Returns the value of attribute object.



24
25
26
# File 'lib/conekta/models/subscription_details_card.rb', line 24

def object
  @object
end

#payment_source_statusObject

Returns the value of attribute payment_source_status.



36
37
38
# File 'lib/conekta/models/subscription_details_card.rb', line 36

def payment_source_status
  @payment_source_status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/conekta/models/subscription_details_card.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/conekta/models/subscription_details_card.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/conekta/models/subscription_details_card.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'created_at' => :'created_at',
    :'active' => :'active',
    :'object' => :'object',
    :'exp_month' => :'exp_month',
    :'exp_year' => :'exp_year',
    :'brand' => :'brand',
    :'last4' => :'last4',
    :'name' => :'name',
    :'payment_source_status' => :'payment_source_status',
    :'customer_id' => :'customer_id',
    :'customer_custom_reference' => :'customer_custom_reference'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/conekta/models/subscription_details_card.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/conekta/models/subscription_details_card.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/conekta/models/subscription_details_card.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'created_at' => :'Integer',
    :'active' => :'Boolean',
    :'object' => :'String',
    :'exp_month' => :'String',
    :'exp_year' => :'String',
    :'brand' => :'String',
    :'last4' => :'String',
    :'name' => :'String',
    :'payment_source_status' => :'String',
    :'customer_id' => :'String',
    :'customer_custom_reference' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/conekta/models/subscription_details_card.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created_at == o.created_at &&
      active == o.active &&
      object == o.object &&
      exp_month == o.exp_month &&
      exp_year == o.exp_year &&
      brand == o.brand &&
      last4 == o.last4 &&
      name == o.name &&
      payment_source_status == o.payment_source_status &&
      customer_id == o.customer_id &&
      customer_custom_reference == o.customer_custom_reference
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/conekta/models/subscription_details_card.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/conekta/models/subscription_details_card.rb', line 201

def hash
  [id, created_at, active, object, exp_month, exp_year, brand, last4, name, payment_source_status, customer_id, customer_custom_reference].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
# File 'lib/conekta/models/subscription_details_card.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/conekta/models/subscription_details_card.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
# File 'lib/conekta/models/subscription_details_card.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end