Class: Conekta::SubscriptionsCustomerPortalApi
- Inherits:
-
Object
- Object
- Conekta::SubscriptionsCustomerPortalApi
- Defined in:
- lib/conekta/api/subscriptions_customer_portal_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_customer_portal(subscription_id, opts = {}) ⇒ CustomerPortalResponse
Create customer portal Creates a customer portal for a subscription.
-
#create_customer_portal_with_http_info(subscription_id, opts = {}) ⇒ Array<(CustomerPortalResponse, Integer, Hash)>
Create customer portal Creates a customer portal for a subscription.
-
#get_customer_portal(subscription_id, opts = {}) ⇒ CustomerPortalResponse
Get customer portal Retrieves the customer portal for a subscription.
-
#get_customer_portal_with_http_info(subscription_id, opts = {}) ⇒ Array<(CustomerPortalResponse, Integer, Hash)>
Get customer portal Retrieves the customer portal for a subscription.
-
#initialize(api_client = ApiClient.default) ⇒ SubscriptionsCustomerPortalApi
constructor
A new instance of SubscriptionsCustomerPortalApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SubscriptionsCustomerPortalApi
Returns a new instance of SubscriptionsCustomerPortalApi.
19 20 21 |
# File 'lib/conekta/api/subscriptions_customer_portal_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/conekta/api/subscriptions_customer_portal_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_customer_portal(subscription_id, opts = {}) ⇒ CustomerPortalResponse
Create customer portal Creates a customer portal for a subscription. If a portal already exists, returns the existing one.
29 30 31 32 |
# File 'lib/conekta/api/subscriptions_customer_portal_api.rb', line 29 def create_customer_portal(subscription_id, opts = {}) data, _status_code, _headers = create_customer_portal_with_http_info(subscription_id, opts) data end |
#create_customer_portal_with_http_info(subscription_id, opts = {}) ⇒ Array<(CustomerPortalResponse, Integer, Hash)>
Create customer portal Creates a customer portal for a subscription. If a portal already exists, returns the existing one.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/conekta/api/subscriptions_customer_portal_api.rb', line 41 def create_customer_portal_with_http_info(subscription_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SubscriptionsCustomerPortalApi.create_customer_portal ...' end # verify the required parameter 'subscription_id' is set if @api_client.config.client_side_validation && subscription_id.nil? fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscriptionsCustomerPortalApi.create_customer_portal" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/subscriptions/{subscription_id}/customer_portal'.sub('{subscription_id}', CGI.escape(subscription_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CustomerPortalResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SubscriptionsCustomerPortalApi.create_customer_portal", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SubscriptionsCustomerPortalApi#create_customer_portal\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_customer_portal(subscription_id, opts = {}) ⇒ CustomerPortalResponse
Get customer portal Retrieves the customer portal for a subscription
102 103 104 105 |
# File 'lib/conekta/api/subscriptions_customer_portal_api.rb', line 102 def get_customer_portal(subscription_id, opts = {}) data, _status_code, _headers = get_customer_portal_with_http_info(subscription_id, opts) data end |
#get_customer_portal_with_http_info(subscription_id, opts = {}) ⇒ Array<(CustomerPortalResponse, Integer, Hash)>
Get customer portal Retrieves the customer portal for a subscription
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/conekta/api/subscriptions_customer_portal_api.rb', line 114 def get_customer_portal_with_http_info(subscription_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SubscriptionsCustomerPortalApi.get_customer_portal ...' end # verify the required parameter 'subscription_id' is set if @api_client.config.client_side_validation && subscription_id.nil? fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscriptionsCustomerPortalApi.get_customer_portal" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/subscriptions/{subscription_id}/customer_portal'.sub('{subscription_id}', CGI.escape(subscription_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.conekta-v2.3.0+json']) unless header_params['Accept'] header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CustomerPortalResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SubscriptionsCustomerPortalApi.get_customer_portal", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SubscriptionsCustomerPortalApi#get_customer_portal\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |