Class: Conekta::TokenRequestCard

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/token_request_card.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TokenRequestCard

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/conekta/models/token_request_card.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::TokenRequestCard` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::TokenRequestCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cvc')
    self.cvc = attributes[:'cvc']
  else
    self.cvc = nil
  end

  if attributes.key?(:'device_fingerprint')
    self.device_fingerprint = attributes[:'device_fingerprint']
  end

  if attributes.key?(:'exp_month')
    self.exp_month = attributes[:'exp_month']
  else
    self.exp_month = nil
  end

  if attributes.key?(:'exp_year')
    self.exp_year = attributes[:'exp_year']
  else
    self.exp_year = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  else
    self.number = nil
  end
end

Instance Attribute Details

#cvcObject

It is a value that allows identifying the security code of the card.



19
20
21
# File 'lib/conekta/models/token_request_card.rb', line 19

def cvc
  @cvc
end

#device_fingerprintObject

It is a value that allows identifying the device fingerprint.



22
23
24
# File 'lib/conekta/models/token_request_card.rb', line 22

def device_fingerprint
  @device_fingerprint
end

#exp_monthObject

It is a value that allows identifying the expiration month of the card.



25
26
27
# File 'lib/conekta/models/token_request_card.rb', line 25

def exp_month
  @exp_month
end

#exp_yearObject

It is a value that allows identifying the expiration year of the card.



28
29
30
# File 'lib/conekta/models/token_request_card.rb', line 28

def exp_year
  @exp_year
end

#nameObject

It is a value that allows identifying the name of the cardholder.



31
32
33
# File 'lib/conekta/models/token_request_card.rb', line 31

def name
  @name
end

#numberObject

It is a value that allows identifying the number of the card.



34
35
36
# File 'lib/conekta/models/token_request_card.rb', line 34

def number
  @number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/conekta/models/token_request_card.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/conekta/models/token_request_card.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/conekta/models/token_request_card.rb', line 37

def self.attribute_map
  {
    :'cvc' => :'cvc',
    :'device_fingerprint' => :'device_fingerprint',
    :'exp_month' => :'exp_month',
    :'exp_year' => :'exp_year',
    :'name' => :'name',
    :'number' => :'number'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/conekta/models/token_request_card.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/conekta/models/token_request_card.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/conekta/models/token_request_card.rb', line 59

def self.openapi_types
  {
    :'cvc' => :'String',
    :'device_fingerprint' => :'String',
    :'exp_month' => :'String',
    :'exp_year' => :'String',
    :'name' => :'String',
    :'number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
# File 'lib/conekta/models/token_request_card.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cvc == o.cvc &&
      device_fingerprint == o.device_fingerprint &&
      exp_month == o.exp_month &&
      exp_year == o.exp_year &&
      name == o.name &&
      number == o.number
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/conekta/models/token_request_card.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/conekta/models/token_request_card.rb', line 265

def hash
  [cvc, device_fingerprint, exp_month, exp_year, name, number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/conekta/models/token_request_card.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cvc.nil?
    invalid_properties.push('invalid value for "cvc", cvc cannot be nil.')
  end

  if @cvc.to_s.length > 4
    invalid_properties.push('invalid value for "cvc", the character length must be smaller than or equal to 4.')
  end

  if @exp_month.nil?
    invalid_properties.push('invalid value for "exp_month", exp_month cannot be nil.')
  end

  if @exp_month.to_s.length > 2
    invalid_properties.push('invalid value for "exp_month", the character length must be smaller than or equal to 2.')
  end

  if @exp_year.nil?
    invalid_properties.push('invalid value for "exp_year", exp_year cannot be nil.')
  end

  if @exp_year.to_s.length > 2
    invalid_properties.push('invalid value for "exp_year", the character length must be smaller than or equal to 2.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @number.nil?
    invalid_properties.push('invalid value for "number", number cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/conekta/models/token_request_card.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/conekta/models/token_request_card.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cvc.nil?
  return false if @cvc.to_s.length > 4
  return false if @exp_month.nil?
  return false if @exp_month.to_s.length > 2
  return false if @exp_year.nil?
  return false if @exp_year.to_s.length > 2
  return false if @name.nil?
  return false if @number.nil?
  true
end