Class: Conekta::TransactionResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/transaction_response.rb

Overview

The Transaction object represents the actions or steps of an order. Statuses can be: unprocessed, pending, available, owen, paid_out, voided, capture, capture_reversal, liquidation, liquidation_reversal, payout, payout_reversal, refund, refund_reversal, chargeback, chargeback_reversal, rounding_adjustment, won_chargeback, transferred, and transferred.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TransactionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/conekta/models/transaction_response.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::TransactionResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::TransactionResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'charge')
    self.charge = attributes[:'charge']
  else
    self.charge = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'fee')
    self.fee = attributes[:'fee']
  else
    self.fee = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  else
    self.livemode = nil
  end

  if attributes.key?(:'net')
    self.net = attributes[:'net']
  else
    self.net = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end
end

Instance Attribute Details

#amountObject

The amount of the transaction.



20
21
22
# File 'lib/conekta/models/transaction_response.rb', line 20

def amount
  @amount
end

#chargeObject

Randomly assigned unique order identifier associated with the charge.



23
24
25
# File 'lib/conekta/models/transaction_response.rb', line 23

def charge
  @charge
end

#created_atObject

Date and time of creation of the transaction in Unix format.



26
27
28
# File 'lib/conekta/models/transaction_response.rb', line 26

def created_at
  @created_at
end

#currencyObject

The currency of the transaction. It uses the 3-letter code of the International Standard ISO 4217.



29
30
31
# File 'lib/conekta/models/transaction_response.rb', line 29

def currency
  @currency
end

#feeObject

The amount to be deducted for taxes and commissions.



32
33
34
# File 'lib/conekta/models/transaction_response.rb', line 32

def fee
  @fee
end

#idObject

Unique identifier of the transaction.



35
36
37
# File 'lib/conekta/models/transaction_response.rb', line 35

def id
  @id
end

#livemodeObject

Indicates whether the transaction was created in live mode or test mode.



38
39
40
# File 'lib/conekta/models/transaction_response.rb', line 38

def livemode
  @livemode
end

#netObject

The net amount after deducting commissions and taxes.



41
42
43
# File 'lib/conekta/models/transaction_response.rb', line 41

def net
  @net
end

#objectObject

Object name, which is transaction.



44
45
46
# File 'lib/conekta/models/transaction_response.rb', line 44

def object
  @object
end

#statusObject

Code indicating transaction status.



47
48
49
# File 'lib/conekta/models/transaction_response.rb', line 47

def status
  @status
end

#typeObject

Transaction Type



50
51
52
# File 'lib/conekta/models/transaction_response.rb', line 50

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/conekta/models/transaction_response.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/conekta/models/transaction_response.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/conekta/models/transaction_response.rb', line 53

def self.attribute_map
  {
    :'amount' => :'amount',
    :'charge' => :'charge',
    :'created_at' => :'created_at',
    :'currency' => :'currency',
    :'fee' => :'fee',
    :'id' => :'id',
    :'livemode' => :'livemode',
    :'net' => :'net',
    :'object' => :'object',
    :'status' => :'status',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/conekta/models/transaction_response.rb', line 407

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/conekta/models/transaction_response.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/conekta/models/transaction_response.rb', line 80

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'charge' => :'String',
    :'created_at' => :'Integer',
    :'currency' => :'String',
    :'fee' => :'Integer',
    :'id' => :'String',
    :'livemode' => :'Boolean',
    :'net' => :'Integer',
    :'object' => :'String',
    :'status' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/conekta/models/transaction_response.rb', line 376

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      charge == o.charge &&
      created_at == o.created_at &&
      currency == o.currency &&
      fee == o.fee &&
      id == o.id &&
      livemode == o.livemode &&
      net == o.net &&
      object == o.object &&
      status == o.status &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


394
395
396
# File 'lib/conekta/models/transaction_response.rb', line 394

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



400
401
402
# File 'lib/conekta/models/transaction_response.rb', line 400

def hash
  [amount, charge, created_at, currency, fee, id, livemode, net, object, status, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/conekta/models/transaction_response.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @charge.nil?
    invalid_properties.push('invalid value for "charge", charge cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if @fee.nil?
    invalid_properties.push('invalid value for "fee", fee cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @livemode.nil?
    invalid_properties.push('invalid value for "livemode", livemode cannot be nil.')
  end

  if @net.nil?
    invalid_properties.push('invalid value for "net", net cannot be nil.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/conekta/models/transaction_response.rb', line 429

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/conekta/models/transaction_response.rb', line 243

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @charge.nil?
  return false if @created_at.nil?
  return false if @currency.nil?
  return false if @currency.to_s.length > 3
  return false if @fee.nil?
  return false if @id.nil?
  return false if @livemode.nil?
  return false if @net.nil?
  return false if @object.nil?
  return false if @status.nil?
  return false if @type.nil?
  true
end