Class: Conekta::UpdateOrderDiscountLinesRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::UpdateOrderDiscountLinesRequest
- Defined in:
- lib/conekta/models/update_order_discount_lines_request.rb
Overview
List of discounts that apply to the order.
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#code ⇒ Object
Discount code.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOrderDiscountLinesRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOrderDiscountLinesRequest
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::UpdateOrderDiscountLinesRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::UpdateOrderDiscountLinesRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
19 20 21 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 19 def amount @amount end |
#code ⇒ Object
Discount code.
22 23 24 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 22 def code @code end |
#type ⇒ Object
Returns the value of attribute type.
24 25 26 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 24 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 27 def self.attribute_map { :'amount' => :'amount', :'code' => :'code', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 148 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 46 def self.openapi_types { :'amount' => :'Integer', :'code' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && code == o.code && type == o.type end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 141 def hash [amount, code, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
91 92 93 94 95 96 97 98 99 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 91 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@amount.nil? && @amount < 0 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
103 104 105 106 107 |
# File 'lib/conekta/models/update_order_discount_lines_request.rb', line 103 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@amount.nil? && @amount < 0 true end |