Class: Conekta::UpdateProduct

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/update_product.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateProduct

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/conekta/models/update_product.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::UpdateProduct` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::UpdateProduct`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'antifraud_info')
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'unit_price')
    self.unit_price = attributes[:'unit_price']
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'metadata')
  end
end

Instance Attribute Details

#antifraud_infoObject

Returns the value of attribute antifraud_info.



18
19
20
# File 'lib/conekta/models/update_product.rb', line 18

def antifraud_info
  @antifraud_info
end

#brandObject

Returns the value of attribute brand.



32
33
34
# File 'lib/conekta/models/update_product.rb', line 32

def brand
  @brand
end

#descriptionObject

Returns the value of attribute description.



20
21
22
# File 'lib/conekta/models/update_product.rb', line 20

def description
  @description
end

#metadataObject

Returns the value of attribute metadata.



34
35
36
# File 'lib/conekta/models/update_product.rb', line 34

def 
  @metadata
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/conekta/models/update_product.rb', line 24

def name
  @name
end

#quantityObject

Returns the value of attribute quantity.



28
29
30
# File 'lib/conekta/models/update_product.rb', line 28

def quantity
  @quantity
end

#skuObject

Returns the value of attribute sku.



22
23
24
# File 'lib/conekta/models/update_product.rb', line 22

def sku
  @sku
end

#tagsObject

Returns the value of attribute tags.



30
31
32
# File 'lib/conekta/models/update_product.rb', line 30

def tags
  @tags
end

#unit_priceObject

Returns the value of attribute unit_price.



26
27
28
# File 'lib/conekta/models/update_product.rb', line 26

def unit_price
  @unit_price
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/conekta/models/update_product.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/conekta/models/update_product.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/conekta/models/update_product.rb', line 37

def self.attribute_map
  {
    :'antifraud_info' => :'antifraud_info',
    :'description' => :'description',
    :'sku' => :'sku',
    :'name' => :'name',
    :'unit_price' => :'unit_price',
    :'quantity' => :'quantity',
    :'tags' => :'tags',
    :'brand' => :'brand',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/conekta/models/update_product.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
82
# File 'lib/conekta/models/update_product.rb', line 77

def self.openapi_nullable
  Set.new([
    :'antifraud_info',
    :'metadata'
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/conekta/models/update_product.rb', line 62

def self.openapi_types
  {
    :'antifraud_info' => :'Hash<String, Object>',
    :'description' => :'String',
    :'sku' => :'String',
    :'name' => :'String',
    :'unit_price' => :'Integer',
    :'quantity' => :'Integer',
    :'tags' => :'Array<String>',
    :'brand' => :'String',
    :'metadata' => :'Hash<String, String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/conekta/models/update_product.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      antifraud_info == o.antifraud_info &&
      description == o.description &&
      sku == o.sku &&
      name == o.name &&
      unit_price == o.unit_price &&
      quantity == o.quantity &&
      tags == o.tags &&
      brand == o.brand &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/conekta/models/update_product.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/conekta/models/update_product.rb', line 233

def hash
  [antifraud_info, description, sku, name, unit_price, quantity, tags, brand, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/conekta/models/update_product.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  if !@unit_price.nil? && @unit_price < 0
    invalid_properties.push('invalid value for "unit_price", must be greater than or equal to 0.')
  end

  if !@quantity.nil? && @quantity < 1
    invalid_properties.push('invalid value for "quantity", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/conekta/models/update_product.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
164
165
# File 'lib/conekta/models/update_product.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@description.nil? && @description.to_s.length > 250
  return false if !@unit_price.nil? && @unit_price < 0
  return false if !@quantity.nil? && @quantity < 1
  true
end