Class: Conekta::UpdateWebhook

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/update_webhook.rb

Overview

an updated webhook

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateWebhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/conekta/models/update_webhook.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::UpdateWebhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::UpdateWebhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'subscribed_events')
    if (value = attributes[:'subscribed_events']).is_a?(Array)
      self.subscribed_events = value
    end
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end
end

Instance Attribute Details

#activeObject

whether the webhook is active or not



26
27
28
# File 'lib/conekta/models/update_webhook.rb', line 26

def active
  @active
end

#subscribed_eventsObject

events that will be sent to the webhook



23
24
25
# File 'lib/conekta/models/update_webhook.rb', line 23

def subscribed_events
  @subscribed_events
end

#urlObject

Here you must place the URL of your Webhook remember that you must program what you will do with the events received. Also do not forget to handle the HTTPS protocol for greater security.



20
21
22
# File 'lib/conekta/models/update_webhook.rb', line 20

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/conekta/models/update_webhook.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/conekta/models/update_webhook.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/conekta/models/update_webhook.rb', line 29

def self.attribute_map
  {
    :'url' => :'url',
    :'subscribed_events' => :'subscribed_events',
    :'active' => :'active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/conekta/models/update_webhook.rb', line 154

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/conekta/models/update_webhook.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/conekta/models/update_webhook.rb', line 48

def self.openapi_types
  {
    :'url' => :'String',
    :'subscribed_events' => :'Array<String>',
    :'active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
# File 'lib/conekta/models/update_webhook.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      subscribed_events == o.subscribed_events &&
      active == o.active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


141
142
143
# File 'lib/conekta/models/update_webhook.rb', line 141

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



147
148
149
# File 'lib/conekta/models/update_webhook.rb', line 147

def hash
  [url, subscribed_events, active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



95
96
97
98
99
100
101
102
103
104
# File 'lib/conekta/models/update_webhook.rb', line 95

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^(?!.*(localhost|127\.0\.0\.1)).*$/)
  if !@url.nil? && @url !~ pattern
    invalid_properties.push("invalid value for \"url\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/conekta/models/update_webhook.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



108
109
110
111
112
# File 'lib/conekta/models/update_webhook.rb', line 108

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@url.nil? && @url !~ Regexp.new(/^(?!.*(localhost|127\.0\.0\.1)).*$/)
  true
end