Class: Conekta::WebhookKeyResponse

Inherits:
ApiModelBase show all
Defined in:
lib/conekta/models/webhook_key_response.rb

Overview

webhook keys model

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookKeyResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/conekta/models/webhook_key_response.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::WebhookKeyResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::WebhookKeyResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deactivated_at')
    self.deactivated_at = attributes[:'deactivated_at']
  end

  if attributes.key?(:'public_key')
    self.public_key = attributes[:'public_key']
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end
end

Instance Attribute Details

#activeObject

Indicates if the webhook key is active



23
24
25
# File 'lib/conekta/models/webhook_key_response.rb', line 23

def active
  @active
end

#created_atObject

Unix timestamp in seconds with the creation date of the webhook key



26
27
28
# File 'lib/conekta/models/webhook_key_response.rb', line 26

def created_at
  @created_at
end

#deactivated_atObject

Unix timestamp in seconds with the deactivation date of the webhook key



29
30
31
# File 'lib/conekta/models/webhook_key_response.rb', line 29

def deactivated_at
  @deactivated_at
end

#idObject

Unique identifier of the webhook key



20
21
22
# File 'lib/conekta/models/webhook_key_response.rb', line 20

def id
  @id
end

#livemodeObject

Indicates if the webhook key is in live mode



35
36
37
# File 'lib/conekta/models/webhook_key_response.rb', line 35

def livemode
  @livemode
end

#objectObject

Object name, value is webhook_key



38
39
40
# File 'lib/conekta/models/webhook_key_response.rb', line 38

def object
  @object
end

#public_keyObject

Public key to be used in the webhook



32
33
34
# File 'lib/conekta/models/webhook_key_response.rb', line 32

def public_key
  @public_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/conekta/models/webhook_key_response.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/conekta/models/webhook_key_response.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/conekta/models/webhook_key_response.rb', line 41

def self.attribute_map
  {
    :'id' => :'id',
    :'active' => :'active',
    :'created_at' => :'created_at',
    :'deactivated_at' => :'deactivated_at',
    :'public_key' => :'public_key',
    :'livemode' => :'livemode',
    :'object' => :'object'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/conekta/models/webhook_key_response.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/conekta/models/webhook_key_response.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/conekta/models/webhook_key_response.rb', line 64

def self.openapi_types
  {
    :'id' => :'String',
    :'active' => :'Boolean',
    :'created_at' => :'Integer',
    :'deactivated_at' => :'Integer',
    :'public_key' => :'String',
    :'livemode' => :'Boolean',
    :'object' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/conekta/models/webhook_key_response.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      active == o.active &&
      created_at == o.created_at &&
      deactivated_at == o.deactivated_at &&
      public_key == o.public_key &&
      livemode == o.livemode &&
      object == o.object
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/conekta/models/webhook_key_response.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/conekta/models/webhook_key_response.rb', line 164

def hash
  [id, active, created_at, deactivated_at, public_key, livemode, object].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
# File 'lib/conekta/models/webhook_key_response.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/conekta/models/webhook_key_response.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
# File 'lib/conekta/models/webhook_key_response.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end