Class: Conekta::ApiKeyResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::ApiKeyResponse
- Defined in:
- lib/conekta/models/api_key_response.rb
Overview
api keys model
Instance Attribute Summary collapse
-
#active ⇒ Object
Indicates if the api key is active.
-
#created_at ⇒ Object
Unix timestamp in seconds of when the api key was created.
-
#deactivated_at ⇒ Object
Unix timestamp in seconds of when the api key was deleted.
-
#description ⇒ Object
A name or brief explanation of what this api key is used for.
-
#id ⇒ Object
Unique identifier of the api key.
-
#last_used_at ⇒ Object
Unix timestamp in seconds with the api key was used.
-
#livemode ⇒ Object
Indicates if the api key is in production.
-
#object ⇒ Object
Object name, value is 'api_key'.
-
#prefix ⇒ Object
The first few characters of the authentication_token.
-
#role ⇒ Object
Indicates if the api key is private or public.
-
#updated_at ⇒ Object
Unix timestamp in seconds of when the api key was last updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiKeyResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiKeyResponse
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/conekta/models/api_key_response.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ApiKeyResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ApiKeyResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'deactivated_at') self.deactivated_at = attributes[:'deactivated_at'] end if attributes.key?(:'last_used_at') self.last_used_at = attributes[:'last_used_at'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'prefix') self.prefix = attributes[:'prefix'] end if attributes.key?(:'role') self.role = attributes[:'role'] end end |
Instance Attribute Details
#active ⇒ Object
Indicates if the api key is active
20 21 22 |
# File 'lib/conekta/models/api_key_response.rb', line 20 def active @active end |
#created_at ⇒ Object
Unix timestamp in seconds of when the api key was created
23 24 25 |
# File 'lib/conekta/models/api_key_response.rb', line 23 def created_at @created_at end |
#deactivated_at ⇒ Object
Unix timestamp in seconds of when the api key was deleted
29 30 31 |
# File 'lib/conekta/models/api_key_response.rb', line 29 def deactivated_at @deactivated_at end |
#description ⇒ Object
A name or brief explanation of what this api key is used for
35 36 37 |
# File 'lib/conekta/models/api_key_response.rb', line 35 def description @description end |
#id ⇒ Object
Unique identifier of the api key
38 39 40 |
# File 'lib/conekta/models/api_key_response.rb', line 38 def id @id end |
#last_used_at ⇒ Object
Unix timestamp in seconds with the api key was used
32 33 34 |
# File 'lib/conekta/models/api_key_response.rb', line 32 def last_used_at @last_used_at end |
#livemode ⇒ Object
Indicates if the api key is in production
41 42 43 |
# File 'lib/conekta/models/api_key_response.rb', line 41 def livemode @livemode end |
#object ⇒ Object
Object name, value is 'api_key'
44 45 46 |
# File 'lib/conekta/models/api_key_response.rb', line 44 def object @object end |
#prefix ⇒ Object
The first few characters of the authentication_token
47 48 49 |
# File 'lib/conekta/models/api_key_response.rb', line 47 def prefix @prefix end |
#role ⇒ Object
Indicates if the api key is private or public
50 51 52 |
# File 'lib/conekta/models/api_key_response.rb', line 50 def role @role end |
#updated_at ⇒ Object
Unix timestamp in seconds of when the api key was last updated
26 27 28 |
# File 'lib/conekta/models/api_key_response.rb', line 26 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/conekta/models/api_key_response.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/conekta/models/api_key_response.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/conekta/models/api_key_response.rb', line 53 def self.attribute_map { :'active' => :'active', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'deactivated_at' => :'deactivated_at', :'last_used_at' => :'last_used_at', :'description' => :'description', :'id' => :'id', :'livemode' => :'livemode', :'object' => :'object', :'prefix' => :'prefix', :'role' => :'role' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/conekta/models/api_key_response.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/conekta/models/api_key_response.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/conekta/models/api_key_response.rb', line 80 def self.openapi_types { :'active' => :'Boolean', :'created_at' => :'Integer', :'updated_at' => :'Integer', :'deactivated_at' => :'Integer', :'last_used_at' => :'Integer', :'description' => :'String', :'id' => :'String', :'livemode' => :'Boolean', :'object' => :'String', :'prefix' => :'String', :'role' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/conekta/models/api_key_response.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && created_at == o.created_at && updated_at == o.updated_at && deactivated_at == o.deactivated_at && last_used_at == o.last_used_at && description == o.description && id == o.id && livemode == o.livemode && object == o.object && prefix == o.prefix && role == o.role end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/conekta/models/api_key_response.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/conekta/models/api_key_response.rb', line 204 def hash [active, created_at, updated_at, deactivated_at, last_used_at, description, id, livemode, object, prefix, role].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 |
# File 'lib/conekta/models/api_key_response.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/conekta/models/api_key_response.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 |
# File 'lib/conekta/models/api_key_response.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |