Class: Conekta::ChargeOrderResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::ChargeOrderResponse
- Defined in:
- lib/conekta/models/charge_order_response.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#description ⇒ Object
Returns the value of attribute description.
-
#device_fingerprint ⇒ Object
Returns the value of attribute device_fingerprint.
-
#failure_code ⇒ Object
Returns the value of attribute failure_code.
-
#failure_message ⇒ Object
Returns the value of attribute failure_message.
-
#id ⇒ Object
Returns the value of attribute id.
-
#livemode ⇒ Object
Returns the value of attribute livemode.
-
#monthly_installments ⇒ Object
Returns the value of attribute monthly_installments.
-
#object ⇒ Object
Returns the value of attribute object.
-
#order_id ⇒ Object
Returns the value of attribute order_id.
-
#paid_at ⇒ Object
Returns the value of attribute paid_at.
-
#payment_method ⇒ Object
Returns the value of attribute payment_method.
-
#reference_id ⇒ Object
Reference ID of the charge.
-
#refunds ⇒ Object
Returns the value of attribute refunds.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChargeOrderResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ChargeOrderResponse
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/conekta/models/charge_order_response.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ChargeOrderResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ChargeOrderResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'channel') self.channel = attributes[:'channel'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'device_fingerprint') self.device_fingerprint = attributes[:'device_fingerprint'] end if attributes.key?(:'failure_code') self.failure_code = attributes[:'failure_code'] end if attributes.key?(:'failure_message') self. = attributes[:'failure_message'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] end if attributes.key?(:'monthly_installments') self.monthly_installments = attributes[:'monthly_installments'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'order_id') self.order_id = attributes[:'order_id'] end if attributes.key?(:'paid_at') self.paid_at = attributes[:'paid_at'] end if attributes.key?(:'payment_method') self.payment_method = attributes[:'payment_method'] end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end if attributes.key?(:'refunds') if (value = attributes[:'refunds']).is_a?(Array) self.refunds = value end end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
18 19 20 |
# File 'lib/conekta/models/charge_order_response.rb', line 18 def amount @amount end |
#channel ⇒ Object
Returns the value of attribute channel.
20 21 22 |
# File 'lib/conekta/models/charge_order_response.rb', line 20 def channel @channel end |
#created_at ⇒ Object
Returns the value of attribute created_at.
22 23 24 |
# File 'lib/conekta/models/charge_order_response.rb', line 22 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
24 25 26 |
# File 'lib/conekta/models/charge_order_response.rb', line 24 def currency @currency end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
26 27 28 |
# File 'lib/conekta/models/charge_order_response.rb', line 26 def customer_id @customer_id end |
#description ⇒ Object
Returns the value of attribute description.
28 29 30 |
# File 'lib/conekta/models/charge_order_response.rb', line 28 def description @description end |
#device_fingerprint ⇒ Object
Returns the value of attribute device_fingerprint.
30 31 32 |
# File 'lib/conekta/models/charge_order_response.rb', line 30 def device_fingerprint @device_fingerprint end |
#failure_code ⇒ Object
Returns the value of attribute failure_code.
32 33 34 |
# File 'lib/conekta/models/charge_order_response.rb', line 32 def failure_code @failure_code end |
#failure_message ⇒ Object
Returns the value of attribute failure_message.
34 35 36 |
# File 'lib/conekta/models/charge_order_response.rb', line 34 def @failure_message end |
#id ⇒ Object
Returns the value of attribute id.
36 37 38 |
# File 'lib/conekta/models/charge_order_response.rb', line 36 def id @id end |
#livemode ⇒ Object
Returns the value of attribute livemode.
38 39 40 |
# File 'lib/conekta/models/charge_order_response.rb', line 38 def livemode @livemode end |
#monthly_installments ⇒ Object
Returns the value of attribute monthly_installments.
40 41 42 |
# File 'lib/conekta/models/charge_order_response.rb', line 40 def monthly_installments @monthly_installments end |
#object ⇒ Object
Returns the value of attribute object.
42 43 44 |
# File 'lib/conekta/models/charge_order_response.rb', line 42 def object @object end |
#order_id ⇒ Object
Returns the value of attribute order_id.
44 45 46 |
# File 'lib/conekta/models/charge_order_response.rb', line 44 def order_id @order_id end |
#paid_at ⇒ Object
Returns the value of attribute paid_at.
46 47 48 |
# File 'lib/conekta/models/charge_order_response.rb', line 46 def paid_at @paid_at end |
#payment_method ⇒ Object
Returns the value of attribute payment_method.
48 49 50 |
# File 'lib/conekta/models/charge_order_response.rb', line 48 def payment_method @payment_method end |
#reference_id ⇒ Object
Reference ID of the charge
51 52 53 |
# File 'lib/conekta/models/charge_order_response.rb', line 51 def reference_id @reference_id end |
#refunds ⇒ Object
Returns the value of attribute refunds.
53 54 55 |
# File 'lib/conekta/models/charge_order_response.rb', line 53 def refunds @refunds end |
#status ⇒ Object
Returns the value of attribute status.
55 56 57 |
# File 'lib/conekta/models/charge_order_response.rb', line 55 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/conekta/models/charge_order_response.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/conekta/models/charge_order_response.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/conekta/models/charge_order_response.rb', line 58 def self.attribute_map { :'amount' => :'amount', :'channel' => :'channel', :'created_at' => :'created_at', :'currency' => :'currency', :'customer_id' => :'customer_id', :'description' => :'description', :'device_fingerprint' => :'device_fingerprint', :'failure_code' => :'failure_code', :'failure_message' => :'failure_message', :'id' => :'id', :'livemode' => :'livemode', :'monthly_installments' => :'monthly_installments', :'object' => :'object', :'order_id' => :'order_id', :'paid_at' => :'paid_at', :'payment_method' => :'payment_method', :'reference_id' => :'reference_id', :'refunds' => :'refunds', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/conekta/models/charge_order_response.rb', line 274 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/conekta/models/charge_order_response.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/conekta/models/charge_order_response.rb', line 93 def self.openapi_types { :'amount' => :'Integer', :'channel' => :'ChargeResponseChannel', :'created_at' => :'Integer', :'currency' => :'String', :'customer_id' => :'String', :'description' => :'String', :'device_fingerprint' => :'String', :'failure_code' => :'String', :'failure_message' => :'String', :'id' => :'String', :'livemode' => :'Boolean', :'monthly_installments' => :'Integer', :'object' => :'String', :'order_id' => :'String', :'paid_at' => :'Integer', :'payment_method' => :'ChargeOrderResponsePaymentMethod', :'reference_id' => :'String', :'refunds' => :'Array<Object>', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/conekta/models/charge_order_response.rb', line 235 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && channel == o.channel && created_at == o.created_at && currency == o.currency && customer_id == o.customer_id && description == o.description && device_fingerprint == o.device_fingerprint && failure_code == o.failure_code && == o. && id == o.id && livemode == o.livemode && monthly_installments == o.monthly_installments && object == o.object && order_id == o.order_id && paid_at == o.paid_at && payment_method == o.payment_method && reference_id == o.reference_id && refunds == o.refunds && status == o.status end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/conekta/models/charge_order_response.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/conekta/models/charge_order_response.rb', line 267 def hash [amount, channel, created_at, currency, customer_id, description, device_fingerprint, failure_code, , id, livemode, monthly_installments, object, order_id, paid_at, payment_method, reference_id, refunds, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
220 221 222 223 224 |
# File 'lib/conekta/models/charge_order_response.rb', line 220 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/conekta/models/charge_order_response.rb', line 296 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 231 |
# File 'lib/conekta/models/charge_order_response.rb', line 228 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |