Class: Conekta::ChargesDataResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::ChargesDataResponse
- Defined in:
- lib/conekta/models/charges_data_response.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#chargeback ⇒ Object
Returns the value of attribute chargeback.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#description ⇒ Object
Returns the value of attribute description.
-
#device_fingerprint ⇒ Object
Returns the value of attribute device_fingerprint.
-
#failure_code ⇒ Object
Returns the value of attribute failure_code.
-
#failure_message ⇒ Object
Returns the value of attribute failure_message.
-
#id ⇒ Object
Charge ID.
-
#livemode ⇒ Object
Whether the charge was made in live mode or not.
-
#object ⇒ Object
Returns the value of attribute object.
-
#order_id ⇒ Object
Order ID.
-
#paid_at ⇒ Object
charge Payment date.
-
#payment_method ⇒ Object
Returns the value of attribute payment_method.
-
#reference_id ⇒ Object
Reference ID of the charge.
-
#refunds ⇒ Object
Returns the value of attribute refunds.
-
#status ⇒ Object
Charge status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChargesDataResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ChargesDataResponse
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/conekta/models/charges_data_response.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::ChargesDataResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::ChargesDataResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'channel') self.channel = attributes[:'channel'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'device_fingerprint') self.device_fingerprint = attributes[:'device_fingerprint'] end if attributes.key?(:'failure_code') self.failure_code = attributes[:'failure_code'] end if attributes.key?(:'failure_message') self. = attributes[:'failure_message'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] else self.livemode = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'order_id') self.order_id = attributes[:'order_id'] else self.order_id = nil end if attributes.key?(:'paid_at') self.paid_at = attributes[:'paid_at'] end if attributes.key?(:'payment_method') self.payment_method = attributes[:'payment_method'] end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end if attributes.key?(:'refunds') self.refunds = attributes[:'refunds'] end if attributes.key?(:'chargeback') self.chargeback = attributes[:'chargeback'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
18 19 20 |
# File 'lib/conekta/models/charges_data_response.rb', line 18 def amount @amount end |
#channel ⇒ Object
Returns the value of attribute channel.
20 21 22 |
# File 'lib/conekta/models/charges_data_response.rb', line 20 def channel @channel end |
#chargeback ⇒ Object
Returns the value of attribute chargeback.
57 58 59 |
# File 'lib/conekta/models/charges_data_response.rb', line 57 def chargeback @chargeback end |
#created_at ⇒ Object
Returns the value of attribute created_at.
22 23 24 |
# File 'lib/conekta/models/charges_data_response.rb', line 22 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
24 25 26 |
# File 'lib/conekta/models/charges_data_response.rb', line 24 def currency @currency end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
26 27 28 |
# File 'lib/conekta/models/charges_data_response.rb', line 26 def customer_id @customer_id end |
#description ⇒ Object
Returns the value of attribute description.
28 29 30 |
# File 'lib/conekta/models/charges_data_response.rb', line 28 def description @description end |
#device_fingerprint ⇒ Object
Returns the value of attribute device_fingerprint.
30 31 32 |
# File 'lib/conekta/models/charges_data_response.rb', line 30 def device_fingerprint @device_fingerprint end |
#failure_code ⇒ Object
Returns the value of attribute failure_code.
32 33 34 |
# File 'lib/conekta/models/charges_data_response.rb', line 32 def failure_code @failure_code end |
#failure_message ⇒ Object
Returns the value of attribute failure_message.
34 35 36 |
# File 'lib/conekta/models/charges_data_response.rb', line 34 def @failure_message end |
#id ⇒ Object
Charge ID
37 38 39 |
# File 'lib/conekta/models/charges_data_response.rb', line 37 def id @id end |
#livemode ⇒ Object
Whether the charge was made in live mode or not
40 41 42 |
# File 'lib/conekta/models/charges_data_response.rb', line 40 def livemode @livemode end |
#object ⇒ Object
Returns the value of attribute object.
42 43 44 |
# File 'lib/conekta/models/charges_data_response.rb', line 42 def object @object end |
#order_id ⇒ Object
Order ID
45 46 47 |
# File 'lib/conekta/models/charges_data_response.rb', line 45 def order_id @order_id end |
#paid_at ⇒ Object
charge Payment date
48 49 50 |
# File 'lib/conekta/models/charges_data_response.rb', line 48 def paid_at @paid_at end |
#payment_method ⇒ Object
Returns the value of attribute payment_method.
50 51 52 |
# File 'lib/conekta/models/charges_data_response.rb', line 50 def payment_method @payment_method end |
#reference_id ⇒ Object
Reference ID of the charge
53 54 55 |
# File 'lib/conekta/models/charges_data_response.rb', line 53 def reference_id @reference_id end |
#refunds ⇒ Object
Returns the value of attribute refunds.
55 56 57 |
# File 'lib/conekta/models/charges_data_response.rb', line 55 def refunds @refunds end |
#status ⇒ Object
Charge status
60 61 62 |
# File 'lib/conekta/models/charges_data_response.rb', line 60 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/conekta/models/charges_data_response.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/conekta/models/charges_data_response.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/conekta/models/charges_data_response.rb', line 63 def self.attribute_map { :'amount' => :'amount', :'channel' => :'channel', :'created_at' => :'created_at', :'currency' => :'currency', :'customer_id' => :'customer_id', :'description' => :'description', :'device_fingerprint' => :'device_fingerprint', :'failure_code' => :'failure_code', :'failure_message' => :'failure_message', :'id' => :'id', :'livemode' => :'livemode', :'object' => :'object', :'order_id' => :'order_id', :'paid_at' => :'paid_at', :'payment_method' => :'payment_method', :'reference_id' => :'reference_id', :'refunds' => :'refunds', :'chargeback' => :'chargeback', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/conekta/models/charges_data_response.rb', line 413 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/conekta/models/charges_data_response.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/conekta/models/charges_data_response.rb', line 98 def self.openapi_types { :'amount' => :'Integer', :'channel' => :'ChargeResponseChannel', :'created_at' => :'Integer', :'currency' => :'String', :'customer_id' => :'String', :'description' => :'String', :'device_fingerprint' => :'String', :'failure_code' => :'String', :'failure_message' => :'String', :'id' => :'String', :'livemode' => :'Boolean', :'object' => :'String', :'order_id' => :'String', :'paid_at' => :'Integer', :'payment_method' => :'ChargeResponsePaymentMethod', :'reference_id' => :'String', :'refunds' => :'ChargeResponseRefunds', :'chargeback' => :'ChargebackResponse', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/conekta/models/charges_data_response.rb', line 374 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && channel == o.channel && created_at == o.created_at && currency == o.currency && customer_id == o.customer_id && description == o.description && device_fingerprint == o.device_fingerprint && failure_code == o.failure_code && == o. && id == o.id && livemode == o.livemode && object == o.object && order_id == o.order_id && paid_at == o.paid_at && payment_method == o.payment_method && reference_id == o.reference_id && refunds == o.refunds && chargeback == o.chargeback && status == o.status end |
#eql?(o) ⇒ Boolean
400 401 402 |
# File 'lib/conekta/models/charges_data_response.rb', line 400 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
406 407 408 |
# File 'lib/conekta/models/charges_data_response.rb', line 406 def hash [amount, channel, created_at, currency, customer_id, description, device_fingerprint, failure_code, , id, livemode, object, order_id, paid_at, payment_method, reference_id, refunds, chargeback, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/conekta/models/charges_data_response.rb', line 239 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @livemode.nil? invalid_properties.push('invalid value for "livemode", livemode cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end if @order_id.nil? invalid_properties.push('invalid value for "order_id", order_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/conekta/models/charges_data_response.rb', line 435 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/conekta/models/charges_data_response.rb', line 279 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @amount.nil? return false if @created_at.nil? return false if @currency.nil? return false if @id.nil? return false if @livemode.nil? return false if @object.nil? return false if @order_id.nil? return false if @status.nil? true end |