Class: Conekta::Checkout
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::Checkout
- Defined in:
- lib/conekta/models/checkout.rb
Overview
It is a sub-resource of the Order model that can be stipulated in order to configure its corresponding checkout
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allowed_payment_methods ⇒ Object
Those are the payment methods that will be available for the link.
-
#exclude_card_networks ⇒ Object
List of card networks to exclude from the checkout.
-
#excluded_payment_methods ⇒ Object
Payment methods to be excluded from the checkout.
-
#expires_at ⇒ Object
It is the time when the link will expire.
-
#monthly_installments_enabled ⇒ Object
This flag allows you to specify if months without interest will be active.
-
#monthly_installments_options ⇒ Object
This field allows you to specify the number of months without interest.
-
#name ⇒ Object
Reason for charge.
-
#needs_shipping_contact ⇒ Object
This flag allows you to fill in the shipping information at checkout.
-
#on_demand_enabled ⇒ Object
This flag allows you to specify if the link will be on demand.
-
#order_template ⇒ Object
Returns the value of attribute order_template.
-
#payments_limit_count ⇒ Object
It is the number of payments that can be made through the link.
-
#plan_ids ⇒ Object
It is a list of plan IDs that will be associated with the order.
-
#recurrent ⇒ Object
false: single use.
-
#success_url ⇒ Object
The URL to redirect to after a successful payment.
-
#three_ds_mode ⇒ Object
Indicates the 3DS2 mode for the order, either smart or strict.
-
#type ⇒ Object
It is the type of link that will be created.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Checkout
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Checkout
Initializes the object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/conekta/models/checkout.rb', line 150 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::Checkout` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::Checkout`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allowed_payment_methods') if (value = attributes[:'allowed_payment_methods']).is_a?(Array) self.allowed_payment_methods = value end end if attributes.key?(:'excluded_payment_methods') if (value = attributes[:'excluded_payment_methods']).is_a?(Array) self.excluded_payment_methods = value end end if attributes.key?(:'exclude_card_networks') if (value = attributes[:'exclude_card_networks']).is_a?(Array) self.exclude_card_networks = value end end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'monthly_installments_enabled') self.monthly_installments_enabled = attributes[:'monthly_installments_enabled'] end if attributes.key?(:'monthly_installments_options') if (value = attributes[:'monthly_installments_options']).is_a?(Array) self. = value end end if attributes.key?(:'three_ds_mode') self.three_ds_mode = attributes[:'three_ds_mode'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'needs_shipping_contact') self.needs_shipping_contact = attributes[:'needs_shipping_contact'] end if attributes.key?(:'on_demand_enabled') self.on_demand_enabled = attributes[:'on_demand_enabled'] end if attributes.key?(:'plan_ids') if (value = attributes[:'plan_ids']).is_a?(Array) self.plan_ids = value end end if attributes.key?(:'order_template') self.order_template = attributes[:'order_template'] else self.order_template = nil end if attributes.key?(:'payments_limit_count') self.payments_limit_count = attributes[:'payments_limit_count'] end if attributes.key?(:'success_url') self.success_url = attributes[:'success_url'] end if attributes.key?(:'recurrent') self.recurrent = attributes[:'recurrent'] else self.recurrent = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#allowed_payment_methods ⇒ Object
Those are the payment methods that will be available for the link. This field is mutually exclusive with excluded_payment_methods.
20 21 22 |
# File 'lib/conekta/models/checkout.rb', line 20 def allowed_payment_methods @allowed_payment_methods end |
#exclude_card_networks ⇒ Object
List of card networks to exclude from the checkout. This field is only applicable for card payments.
26 27 28 |
# File 'lib/conekta/models/checkout.rb', line 26 def exclude_card_networks @exclude_card_networks end |
#excluded_payment_methods ⇒ Object
Payment methods to be excluded from the checkout. This field is mutually exclusive with allowed_payment_methods.
23 24 25 |
# File 'lib/conekta/models/checkout.rb', line 23 def excluded_payment_methods @excluded_payment_methods end |
#expires_at ⇒ Object
It is the time when the link will expire. It is expressed in seconds since the Unix epoch. The valid range is from 5 minutes to 365 days from the creation date.
29 30 31 |
# File 'lib/conekta/models/checkout.rb', line 29 def expires_at @expires_at end |
#monthly_installments_enabled ⇒ Object
This flag allows you to specify if months without interest will be active.
32 33 34 |
# File 'lib/conekta/models/checkout.rb', line 32 def monthly_installments_enabled @monthly_installments_enabled end |
#monthly_installments_options ⇒ Object
This field allows you to specify the number of months without interest.
35 36 37 |
# File 'lib/conekta/models/checkout.rb', line 35 def @monthly_installments_options end |
#name ⇒ Object
Reason for charge
41 42 43 |
# File 'lib/conekta/models/checkout.rb', line 41 def name @name end |
#needs_shipping_contact ⇒ Object
This flag allows you to fill in the shipping information at checkout.
44 45 46 |
# File 'lib/conekta/models/checkout.rb', line 44 def needs_shipping_contact @needs_shipping_contact end |
#on_demand_enabled ⇒ Object
This flag allows you to specify if the link will be on demand.
47 48 49 |
# File 'lib/conekta/models/checkout.rb', line 47 def on_demand_enabled @on_demand_enabled end |
#order_template ⇒ Object
Returns the value of attribute order_template.
52 53 54 |
# File 'lib/conekta/models/checkout.rb', line 52 def order_template @order_template end |
#payments_limit_count ⇒ Object
It is the number of payments that can be made through the link.
55 56 57 |
# File 'lib/conekta/models/checkout.rb', line 55 def payments_limit_count @payments_limit_count end |
#plan_ids ⇒ Object
It is a list of plan IDs that will be associated with the order.
50 51 52 |
# File 'lib/conekta/models/checkout.rb', line 50 def plan_ids @plan_ids end |
#recurrent ⇒ Object
false: single use. true: multiple payments
61 62 63 |
# File 'lib/conekta/models/checkout.rb', line 61 def recurrent @recurrent end |
#success_url ⇒ Object
The URL to redirect to after a successful payment.
58 59 60 |
# File 'lib/conekta/models/checkout.rb', line 58 def success_url @success_url end |
#three_ds_mode ⇒ Object
Indicates the 3DS2 mode for the order, either smart or strict. This property is only applicable when 3DS is enabled. When 3DS is disabled, this field should be null.
38 39 40 |
# File 'lib/conekta/models/checkout.rb', line 38 def three_ds_mode @three_ds_mode end |
#type ⇒ Object
It is the type of link that will be created. It must be a valid type.
64 65 66 |
# File 'lib/conekta/models/checkout.rb', line 64 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
111 112 113 |
# File 'lib/conekta/models/checkout.rb', line 111 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
116 117 118 |
# File 'lib/conekta/models/checkout.rb', line 116 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/conekta/models/checkout.rb', line 89 def self.attribute_map { :'allowed_payment_methods' => :'allowed_payment_methods', :'excluded_payment_methods' => :'excluded_payment_methods', :'exclude_card_networks' => :'exclude_card_networks', :'expires_at' => :'expires_at', :'monthly_installments_enabled' => :'monthly_installments_enabled', :'monthly_installments_options' => :'monthly_installments_options', :'three_ds_mode' => :'three_ds_mode', :'name' => :'name', :'needs_shipping_contact' => :'needs_shipping_contact', :'on_demand_enabled' => :'on_demand_enabled', :'plan_ids' => :'plan_ids', :'order_template' => :'order_template', :'payments_limit_count' => :'payments_limit_count', :'success_url' => :'success_url', :'recurrent' => :'recurrent', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/conekta/models/checkout.rb', line 405 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
143 144 145 146 |
# File 'lib/conekta/models/checkout.rb', line 143 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/conekta/models/checkout.rb', line 121 def self.openapi_types { :'allowed_payment_methods' => :'Array<String>', :'excluded_payment_methods' => :'Array<String>', :'exclude_card_networks' => :'Array<String>', :'expires_at' => :'Integer', :'monthly_installments_enabled' => :'Boolean', :'monthly_installments_options' => :'Array<Integer>', :'three_ds_mode' => :'String', :'name' => :'String', :'needs_shipping_contact' => :'Boolean', :'on_demand_enabled' => :'Boolean', :'plan_ids' => :'Array<String>', :'order_template' => :'CheckoutOrderTemplate', :'payments_limit_count' => :'Integer', :'success_url' => :'String', :'recurrent' => :'Boolean', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/conekta/models/checkout.rb', line 369 def ==(o) return true if self.equal?(o) self.class == o.class && allowed_payment_methods == o.allowed_payment_methods && excluded_payment_methods == o.excluded_payment_methods && exclude_card_networks == o.exclude_card_networks && expires_at == o.expires_at && monthly_installments_enabled == o.monthly_installments_enabled && == o. && three_ds_mode == o.three_ds_mode && name == o.name && needs_shipping_contact == o.needs_shipping_contact && on_demand_enabled == o.on_demand_enabled && plan_ids == o.plan_ids && order_template == o.order_template && payments_limit_count == o.payments_limit_count && success_url == o.success_url && recurrent == o.recurrent && type == o.type end |
#eql?(o) ⇒ Boolean
392 393 394 |
# File 'lib/conekta/models/checkout.rb', line 392 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
398 399 400 |
# File 'lib/conekta/models/checkout.rb', line 398 def hash [allowed_payment_methods, excluded_payment_methods, exclude_card_networks, expires_at, monthly_installments_enabled, , three_ds_mode, name, needs_shipping_contact, on_demand_enabled, plan_ids, order_template, payments_limit_count, success_url, recurrent, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/conekta/models/checkout.rb', line 251 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end if @expires_at < 1 invalid_properties.push('invalid value for "expires_at", must be greater than or equal to 1.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @order_template.nil? invalid_properties.push('invalid value for "order_template", order_template cannot be nil.') end if !@payments_limit_count.nil? && @payments_limit_count < 1 invalid_properties.push('invalid value for "payments_limit_count", must be greater than or equal to 1.') end if @recurrent.nil? invalid_properties.push('invalid value for "recurrent", recurrent cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/conekta/models/checkout.rb', line 427 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/conekta/models/checkout.rb', line 287 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @expires_at.nil? return false if @expires_at < 1 return false if @name.nil? return false if @order_template.nil? return false if !@payments_limit_count.nil? && @payments_limit_count < 1 return false if @recurrent.nil? return false if @type.nil? true end |