Class: Conekta::CheckoutResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::CheckoutResponse
- Defined in:
- lib/conekta/models/checkout_response.rb
Overview
checkout response
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allowed_payment_methods ⇒ Object
Are the payment methods available for this link.
-
#can_not_expire ⇒ Object
Returns the value of attribute can_not_expire.
-
#emails_sent ⇒ Object
Returns the value of attribute emails_sent.
-
#exclude_card_networks ⇒ Object
Returns the value of attribute exclude_card_networks.
-
#excluded_payment_methods ⇒ Object
Payment methods excluded from the checkout.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#failure_url ⇒ Object
Returns the value of attribute failure_url.
-
#force_3ds_flow ⇒ Object
Returns the value of attribute force_3ds_flow.
-
#id ⇒ Object
Returns the value of attribute id.
-
#livemode ⇒ Object
Returns the value of attribute livemode.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#monthly_installments_enabled ⇒ Object
Returns the value of attribute monthly_installments_enabled.
-
#monthly_installments_options ⇒ Object
Returns the value of attribute monthly_installments_options.
-
#name ⇒ Object
Reason for charge.
-
#needs_shipping_contact ⇒ Object
Returns the value of attribute needs_shipping_contact.
-
#object ⇒ Object
Returns the value of attribute object.
-
#paid_payments_count ⇒ Object
Returns the value of attribute paid_payments_count.
-
#payments_limit_count ⇒ Object
Returns the value of attribute payments_limit_count.
-
#plan_ids ⇒ Object
List of plan IDs that are available for subscription.
-
#recurrent ⇒ Object
Returns the value of attribute recurrent.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#sms_sent ⇒ Object
Returns the value of attribute sms_sent.
-
#starts_at ⇒ Object
Returns the value of attribute starts_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#success_url ⇒ Object
The URL to redirect to after a successful payment.
-
#type ⇒ Object
Returns the value of attribute type.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckoutResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CheckoutResponse
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/conekta/models/checkout_response.rb', line 184 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::CheckoutResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::CheckoutResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allowed_payment_methods') if (value = attributes[:'allowed_payment_methods']).is_a?(Array) self.allowed_payment_methods = value end end if attributes.key?(:'excluded_payment_methods') if (value = attributes[:'excluded_payment_methods']).is_a?(Array) self.excluded_payment_methods = value end end if attributes.key?(:'plan_ids') if (value = attributes[:'plan_ids']).is_a?(Array) self.plan_ids = value end end if attributes.key?(:'can_not_expire') self.can_not_expire = attributes[:'can_not_expire'] end if attributes.key?(:'emails_sent') self.emails_sent = attributes[:'emails_sent'] end if attributes.key?(:'exclude_card_networks') if (value = attributes[:'exclude_card_networks']).is_a?(Array) self.exclude_card_networks = value end end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'failure_url') self.failure_url = attributes[:'failure_url'] end if attributes.key?(:'force_3ds_flow') self.force_3ds_flow = attributes[:'force_3ds_flow'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] else self.livemode = nil end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'monthly_installments_enabled') self.monthly_installments_enabled = attributes[:'monthly_installments_enabled'] end if attributes.key?(:'monthly_installments_options') if (value = attributes[:'monthly_installments_options']).is_a?(Array) self. = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'needs_shipping_contact') self.needs_shipping_contact = attributes[:'needs_shipping_contact'] end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'paid_payments_count') self.paid_payments_count = attributes[:'paid_payments_count'] end if attributes.key?(:'payments_limit_count') self.payments_limit_count = attributes[:'payments_limit_count'] end if attributes.key?(:'recurrent') self.recurrent = attributes[:'recurrent'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'sms_sent') self.sms_sent = attributes[:'sms_sent'] end if attributes.key?(:'starts_at') self.starts_at = attributes[:'starts_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'success_url') self.success_url = attributes[:'success_url'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'url') self.url = attributes[:'url'] end end |
Instance Attribute Details
#allowed_payment_methods ⇒ Object
Are the payment methods available for this link
20 21 22 |
# File 'lib/conekta/models/checkout_response.rb', line 20 def allowed_payment_methods @allowed_payment_methods end |
#can_not_expire ⇒ Object
Returns the value of attribute can_not_expire.
28 29 30 |
# File 'lib/conekta/models/checkout_response.rb', line 28 def can_not_expire @can_not_expire end |
#emails_sent ⇒ Object
Returns the value of attribute emails_sent.
30 31 32 |
# File 'lib/conekta/models/checkout_response.rb', line 30 def emails_sent @emails_sent end |
#exclude_card_networks ⇒ Object
Returns the value of attribute exclude_card_networks.
32 33 34 |
# File 'lib/conekta/models/checkout_response.rb', line 32 def exclude_card_networks @exclude_card_networks end |
#excluded_payment_methods ⇒ Object
Payment methods excluded from the checkout. This field is only returned when excluded_payment_methods is provided in the request.
23 24 25 |
# File 'lib/conekta/models/checkout_response.rb', line 23 def excluded_payment_methods @excluded_payment_methods end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
34 35 36 |
# File 'lib/conekta/models/checkout_response.rb', line 34 def expires_at @expires_at end |
#failure_url ⇒ Object
Returns the value of attribute failure_url.
36 37 38 |
# File 'lib/conekta/models/checkout_response.rb', line 36 def failure_url @failure_url end |
#force_3ds_flow ⇒ Object
Returns the value of attribute force_3ds_flow.
38 39 40 |
# File 'lib/conekta/models/checkout_response.rb', line 38 def force_3ds_flow @force_3ds_flow end |
#id ⇒ Object
Returns the value of attribute id.
40 41 42 |
# File 'lib/conekta/models/checkout_response.rb', line 40 def id @id end |
#livemode ⇒ Object
Returns the value of attribute livemode.
42 43 44 |
# File 'lib/conekta/models/checkout_response.rb', line 42 def livemode @livemode end |
#metadata ⇒ Object
Returns the value of attribute metadata.
44 45 46 |
# File 'lib/conekta/models/checkout_response.rb', line 44 def @metadata end |
#monthly_installments_enabled ⇒ Object
Returns the value of attribute monthly_installments_enabled.
46 47 48 |
# File 'lib/conekta/models/checkout_response.rb', line 46 def monthly_installments_enabled @monthly_installments_enabled end |
#monthly_installments_options ⇒ Object
Returns the value of attribute monthly_installments_options.
48 49 50 |
# File 'lib/conekta/models/checkout_response.rb', line 48 def @monthly_installments_options end |
#name ⇒ Object
Reason for charge
51 52 53 |
# File 'lib/conekta/models/checkout_response.rb', line 51 def name @name end |
#needs_shipping_contact ⇒ Object
Returns the value of attribute needs_shipping_contact.
53 54 55 |
# File 'lib/conekta/models/checkout_response.rb', line 53 def needs_shipping_contact @needs_shipping_contact end |
#object ⇒ Object
Returns the value of attribute object.
55 56 57 |
# File 'lib/conekta/models/checkout_response.rb', line 55 def object @object end |
#paid_payments_count ⇒ Object
Returns the value of attribute paid_payments_count.
57 58 59 |
# File 'lib/conekta/models/checkout_response.rb', line 57 def paid_payments_count @paid_payments_count end |
#payments_limit_count ⇒ Object
Returns the value of attribute payments_limit_count.
59 60 61 |
# File 'lib/conekta/models/checkout_response.rb', line 59 def payments_limit_count @payments_limit_count end |
#plan_ids ⇒ Object
List of plan IDs that are available for subscription
26 27 28 |
# File 'lib/conekta/models/checkout_response.rb', line 26 def plan_ids @plan_ids end |
#recurrent ⇒ Object
Returns the value of attribute recurrent.
61 62 63 |
# File 'lib/conekta/models/checkout_response.rb', line 61 def recurrent @recurrent end |
#slug ⇒ Object
Returns the value of attribute slug.
63 64 65 |
# File 'lib/conekta/models/checkout_response.rb', line 63 def slug @slug end |
#sms_sent ⇒ Object
Returns the value of attribute sms_sent.
65 66 67 |
# File 'lib/conekta/models/checkout_response.rb', line 65 def sms_sent @sms_sent end |
#starts_at ⇒ Object
Returns the value of attribute starts_at.
67 68 69 |
# File 'lib/conekta/models/checkout_response.rb', line 67 def starts_at @starts_at end |
#status ⇒ Object
Returns the value of attribute status.
69 70 71 |
# File 'lib/conekta/models/checkout_response.rb', line 69 def status @status end |
#success_url ⇒ Object
The URL to redirect to after a successful payment.
72 73 74 |
# File 'lib/conekta/models/checkout_response.rb', line 72 def success_url @success_url end |
#type ⇒ Object
Returns the value of attribute type.
74 75 76 |
# File 'lib/conekta/models/checkout_response.rb', line 74 def type @type end |
#url ⇒ Object
Returns the value of attribute url.
76 77 78 |
# File 'lib/conekta/models/checkout_response.rb', line 76 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
134 135 136 |
# File 'lib/conekta/models/checkout_response.rb', line 134 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
139 140 141 |
# File 'lib/conekta/models/checkout_response.rb', line 139 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/conekta/models/checkout_response.rb', line 101 def self.attribute_map { :'allowed_payment_methods' => :'allowed_payment_methods', :'excluded_payment_methods' => :'excluded_payment_methods', :'plan_ids' => :'plan_ids', :'can_not_expire' => :'can_not_expire', :'emails_sent' => :'emails_sent', :'exclude_card_networks' => :'exclude_card_networks', :'expires_at' => :'expires_at', :'failure_url' => :'failure_url', :'force_3ds_flow' => :'force_3ds_flow', :'id' => :'id', :'livemode' => :'livemode', :'metadata' => :'metadata', :'monthly_installments_enabled' => :'monthly_installments_enabled', :'monthly_installments_options' => :'monthly_installments_options', :'name' => :'name', :'needs_shipping_contact' => :'needs_shipping_contact', :'object' => :'object', :'paid_payments_count' => :'paid_payments_count', :'payments_limit_count' => :'payments_limit_count', :'recurrent' => :'recurrent', :'slug' => :'slug', :'sms_sent' => :'sms_sent', :'starts_at' => :'starts_at', :'status' => :'status', :'success_url' => :'success_url', :'type' => :'type', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/conekta/models/checkout_response.rb', line 451 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
177 178 179 180 |
# File 'lib/conekta/models/checkout_response.rb', line 177 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/conekta/models/checkout_response.rb', line 144 def self.openapi_types { :'allowed_payment_methods' => :'Array<String>', :'excluded_payment_methods' => :'Array<String>', :'plan_ids' => :'Array<String>', :'can_not_expire' => :'Boolean', :'emails_sent' => :'Integer', :'exclude_card_networks' => :'Array<String>', :'expires_at' => :'Integer', :'failure_url' => :'String', :'force_3ds_flow' => :'Boolean', :'id' => :'String', :'livemode' => :'Boolean', :'metadata' => :'Hash<String, Object>', :'monthly_installments_enabled' => :'Boolean', :'monthly_installments_options' => :'Array<Integer>', :'name' => :'String', :'needs_shipping_contact' => :'Boolean', :'object' => :'String', :'paid_payments_count' => :'Integer', :'payments_limit_count' => :'Integer', :'recurrent' => :'Boolean', :'slug' => :'String', :'sms_sent' => :'Integer', :'starts_at' => :'Integer', :'status' => :'String', :'success_url' => :'String', :'type' => :'String', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/conekta/models/checkout_response.rb', line 404 def ==(o) return true if self.equal?(o) self.class == o.class && allowed_payment_methods == o.allowed_payment_methods && excluded_payment_methods == o.excluded_payment_methods && plan_ids == o.plan_ids && can_not_expire == o.can_not_expire && emails_sent == o.emails_sent && exclude_card_networks == o.exclude_card_networks && expires_at == o.expires_at && failure_url == o.failure_url && force_3ds_flow == o.force_3ds_flow && id == o.id && livemode == o.livemode && == o. && monthly_installments_enabled == o.monthly_installments_enabled && == o. && name == o.name && needs_shipping_contact == o.needs_shipping_contact && object == o.object && paid_payments_count == o.paid_payments_count && payments_limit_count == o.payments_limit_count && recurrent == o.recurrent && slug == o.slug && sms_sent == o.sms_sent && starts_at == o.starts_at && status == o.status && success_url == o.success_url && type == o.type && url == o.url end |
#eql?(o) ⇒ Boolean
438 439 440 |
# File 'lib/conekta/models/checkout_response.rb', line 438 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
444 445 446 |
# File 'lib/conekta/models/checkout_response.rb', line 444 def hash [allowed_payment_methods, excluded_payment_methods, plan_ids, can_not_expire, emails_sent, exclude_card_networks, expires_at, failure_url, force_3ds_flow, id, livemode, , monthly_installments_enabled, , name, needs_shipping_contact, object, paid_payments_count, payments_limit_count, recurrent, slug, sms_sent, starts_at, status, success_url, type, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/conekta/models/checkout_response.rb', line 329 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @livemode.nil? invalid_properties.push('invalid value for "livemode", livemode cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
473 474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/conekta/models/checkout_response.rb', line 473 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
353 354 355 356 357 358 359 360 |
# File 'lib/conekta/models/checkout_response.rb', line 353 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @livemode.nil? return false if @name.nil? return false if @object.nil? true end |