Class: Conekta::FiscalEntityRequestAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::FiscalEntityRequestAddress
- Defined in:
- lib/conekta/models/fiscal_entity_request_address.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
this field follows the ISO 3166-1 alpha-2 standard.
-
#external_number ⇒ Object
Returns the value of attribute external_number.
-
#postal_code ⇒ Object
Returns the value of attribute postal_code.
-
#residential ⇒ Object
Returns the value of attribute residential.
-
#state ⇒ Object
Returns the value of attribute state.
-
#street1 ⇒ Object
Returns the value of attribute street1.
-
#street2 ⇒ Object
Returns the value of attribute street2.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FiscalEntityRequestAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FiscalEntityRequestAddress
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::FiscalEntityRequestAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::FiscalEntityRequestAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'street1') self.street1 = attributes[:'street1'] else self.street1 = nil end if attributes.key?(:'street2') self.street2 = attributes[:'street2'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] else self.postal_code = nil end if attributes.key?(:'city') self.city = attributes[:'city'] else self.city = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'residential') self.residential = attributes[:'residential'] else self.residential = false end if attributes.key?(:'external_number') self.external_number = attributes[:'external_number'] end end |
Instance Attribute Details
#city ⇒ Object
Returns the value of attribute city.
24 25 26 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 24 def city @city end |
#country ⇒ Object
this field follows the ISO 3166-1 alpha-2 standard
29 30 31 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 29 def country @country end |
#external_number ⇒ Object
Returns the value of attribute external_number.
33 34 35 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 33 def external_number @external_number end |
#postal_code ⇒ Object
Returns the value of attribute postal_code.
22 23 24 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 22 def postal_code @postal_code end |
#residential ⇒ Object
Returns the value of attribute residential.
31 32 33 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 31 def residential @residential end |
#state ⇒ Object
Returns the value of attribute state.
26 27 28 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 26 def state @state end |
#street1 ⇒ Object
Returns the value of attribute street1.
18 19 20 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 18 def street1 @street1 end |
#street2 ⇒ Object
Returns the value of attribute street2.
20 21 22 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 20 def street2 @street2 end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 36 def self.attribute_map { :'street1' => :'street1', :'street2' => :'street2', :'postal_code' => :'postal_code', :'city' => :'city', :'state' => :'state', :'country' => :'country', :'residential' => :'residential', :'external_number' => :'external_number' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 226 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 60 def self.openapi_types { :'street1' => :'String', :'street2' => :'String', :'postal_code' => :'String', :'city' => :'String', :'state' => :'String', :'country' => :'String', :'residential' => :'Boolean', :'external_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && street1 == o.street1 && street2 == o.street2 && postal_code == o.postal_code && city == o.city && state == o.state && country == o.country && residential == o.residential && external_number == o.external_number end |
#eql?(o) ⇒ Boolean
213 214 215 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 213 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 219 def hash [street1, street2, postal_code, city, state, country, residential, external_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @street1.nil? invalid_properties.push('invalid value for "street1", street1 cannot be nil.') end if @postal_code.nil? invalid_properties.push('invalid value for "postal_code", postal_code cannot be nil.') end if @city.nil? invalid_properties.push('invalid value for "city", city cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 248 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 164 |
# File 'lib/conekta/models/fiscal_entity_request_address.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @street1.nil? return false if @postal_code.nil? return false if @city.nil? true end |