Class: Conekta::OrderResponseCheckout
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::OrderResponseCheckout
- Defined in:
- lib/conekta/models/order_response_checkout.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allowed_payment_methods ⇒ Object
Are the payment methods available for this link.
-
#can_not_expire ⇒ Object
Returns the value of attribute can_not_expire.
-
#emails_sent ⇒ Object
Returns the value of attribute emails_sent.
-
#exclude_card_networks ⇒ Object
Returns the value of attribute exclude_card_networks.
-
#excluded_payment_methods ⇒ Object
Payment methods excluded from the checkout.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#failure_url ⇒ Object
Returns the value of attribute failure_url.
-
#force_3ds_flow ⇒ Object
Returns the value of attribute force_3ds_flow.
-
#force_save_card ⇒ Object
Indicates whether the card used for the payment should be saved for future purchases.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_redirect_on_failure ⇒ Object
Returns the value of attribute is_redirect_on_failure.
-
#livemode ⇒ Object
Returns the value of attribute livemode.
-
#max_failed_retries ⇒ Object
Number of retries allowed before the checkout is marked as failed.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#monthly_installments_enabled ⇒ Object
Returns the value of attribute monthly_installments_enabled.
-
#monthly_installments_options ⇒ Object
Returns the value of attribute monthly_installments_options.
-
#name ⇒ Object
Returns the value of attribute name.
-
#needs_shipping_contact ⇒ Object
Returns the value of attribute needs_shipping_contact.
-
#object ⇒ Object
Returns the value of attribute object.
-
#on_demand_enabled ⇒ Object
Returns the value of attribute on_demand_enabled.
-
#paid_payments_count ⇒ Object
Returns the value of attribute paid_payments_count.
-
#recurrent ⇒ Object
Returns the value of attribute recurrent.
-
#redirection_time ⇒ Object
number of seconds to wait before redirecting to the success_url.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#sms_sent ⇒ Object
Returns the value of attribute sms_sent.
-
#starts_at ⇒ Object
Returns the value of attribute starts_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#success_url ⇒ Object
Redirection url back to the site in case of successful payment, applies only to HostedPayment.
-
#type ⇒ Object
This field represents the type of checkout, which determines the user experience during the payment process.
-
#url ⇒ Object
Indicate the url of the Conekta component to complete the payment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderResponseCheckout
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrderResponseCheckout
Initializes the object
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/conekta/models/order_response_checkout.rb', line 198 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderResponseCheckout` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderResponseCheckout`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allowed_payment_methods') if (value = attributes[:'allowed_payment_methods']).is_a?(Array) self.allowed_payment_methods = value end end if attributes.key?(:'excluded_payment_methods') if (value = attributes[:'excluded_payment_methods']).is_a?(Array) self.excluded_payment_methods = value end end if attributes.key?(:'can_not_expire') self.can_not_expire = attributes[:'can_not_expire'] end if attributes.key?(:'emails_sent') self.emails_sent = attributes[:'emails_sent'] end if attributes.key?(:'exclude_card_networks') if (value = attributes[:'exclude_card_networks']).is_a?(Array) self.exclude_card_networks = value end end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'failure_url') self.failure_url = attributes[:'failure_url'] end if attributes.key?(:'force_3ds_flow') self.force_3ds_flow = attributes[:'force_3ds_flow'] end if attributes.key?(:'force_save_card') self.force_save_card = attributes[:'force_save_card'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'is_redirect_on_failure') self.is_redirect_on_failure = attributes[:'is_redirect_on_failure'] end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] else self.livemode = nil end if attributes.key?(:'max_failed_retries') self.max_failed_retries = attributes[:'max_failed_retries'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'monthly_installments_enabled') self.monthly_installments_enabled = attributes[:'monthly_installments_enabled'] end if attributes.key?(:'monthly_installments_options') if (value = attributes[:'monthly_installments_options']).is_a?(Array) self. = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'needs_shipping_contact') self.needs_shipping_contact = attributes[:'needs_shipping_contact'] end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'on_demand_enabled') self.on_demand_enabled = attributes[:'on_demand_enabled'] end if attributes.key?(:'paid_payments_count') self.paid_payments_count = attributes[:'paid_payments_count'] end if attributes.key?(:'recurrent') self.recurrent = attributes[:'recurrent'] end if attributes.key?(:'redirection_time') self.redirection_time = attributes[:'redirection_time'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'sms_sent') self.sms_sent = attributes[:'sms_sent'] end if attributes.key?(:'success_url') self.success_url = attributes[:'success_url'] end if attributes.key?(:'starts_at') self.starts_at = attributes[:'starts_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'url') self.url = attributes[:'url'] end end |
Instance Attribute Details
#allowed_payment_methods ⇒ Object
Are the payment methods available for this link
19 20 21 |
# File 'lib/conekta/models/order_response_checkout.rb', line 19 def allowed_payment_methods @allowed_payment_methods end |
#can_not_expire ⇒ Object
Returns the value of attribute can_not_expire.
24 25 26 |
# File 'lib/conekta/models/order_response_checkout.rb', line 24 def can_not_expire @can_not_expire end |
#emails_sent ⇒ Object
Returns the value of attribute emails_sent.
26 27 28 |
# File 'lib/conekta/models/order_response_checkout.rb', line 26 def emails_sent @emails_sent end |
#exclude_card_networks ⇒ Object
Returns the value of attribute exclude_card_networks.
28 29 30 |
# File 'lib/conekta/models/order_response_checkout.rb', line 28 def exclude_card_networks @exclude_card_networks end |
#excluded_payment_methods ⇒ Object
Payment methods excluded from the checkout. This field is only returned when excluded_payment_methods is provided in the request.
22 23 24 |
# File 'lib/conekta/models/order_response_checkout.rb', line 22 def excluded_payment_methods @excluded_payment_methods end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
30 31 32 |
# File 'lib/conekta/models/order_response_checkout.rb', line 30 def expires_at @expires_at end |
#failure_url ⇒ Object
Returns the value of attribute failure_url.
32 33 34 |
# File 'lib/conekta/models/order_response_checkout.rb', line 32 def failure_url @failure_url end |
#force_3ds_flow ⇒ Object
Returns the value of attribute force_3ds_flow.
34 35 36 |
# File 'lib/conekta/models/order_response_checkout.rb', line 34 def force_3ds_flow @force_3ds_flow end |
#force_save_card ⇒ Object
Indicates whether the card used for the payment should be saved for future purchases. This field is only applicable for card payments.
37 38 39 |
# File 'lib/conekta/models/order_response_checkout.rb', line 37 def force_save_card @force_save_card end |
#id ⇒ Object
Returns the value of attribute id.
39 40 41 |
# File 'lib/conekta/models/order_response_checkout.rb', line 39 def id @id end |
#is_redirect_on_failure ⇒ Object
Returns the value of attribute is_redirect_on_failure.
41 42 43 |
# File 'lib/conekta/models/order_response_checkout.rb', line 41 def is_redirect_on_failure @is_redirect_on_failure end |
#livemode ⇒ Object
Returns the value of attribute livemode.
43 44 45 |
# File 'lib/conekta/models/order_response_checkout.rb', line 43 def livemode @livemode end |
#max_failed_retries ⇒ Object
Number of retries allowed before the checkout is marked as failed
46 47 48 |
# File 'lib/conekta/models/order_response_checkout.rb', line 46 def max_failed_retries @max_failed_retries end |
#metadata ⇒ Object
Returns the value of attribute metadata.
48 49 50 |
# File 'lib/conekta/models/order_response_checkout.rb', line 48 def @metadata end |
#monthly_installments_enabled ⇒ Object
Returns the value of attribute monthly_installments_enabled.
50 51 52 |
# File 'lib/conekta/models/order_response_checkout.rb', line 50 def monthly_installments_enabled @monthly_installments_enabled end |
#monthly_installments_options ⇒ Object
Returns the value of attribute monthly_installments_options.
52 53 54 |
# File 'lib/conekta/models/order_response_checkout.rb', line 52 def @monthly_installments_options end |
#name ⇒ Object
Returns the value of attribute name.
54 55 56 |
# File 'lib/conekta/models/order_response_checkout.rb', line 54 def name @name end |
#needs_shipping_contact ⇒ Object
Returns the value of attribute needs_shipping_contact.
56 57 58 |
# File 'lib/conekta/models/order_response_checkout.rb', line 56 def needs_shipping_contact @needs_shipping_contact end |
#object ⇒ Object
Returns the value of attribute object.
58 59 60 |
# File 'lib/conekta/models/order_response_checkout.rb', line 58 def object @object end |
#on_demand_enabled ⇒ Object
Returns the value of attribute on_demand_enabled.
60 61 62 |
# File 'lib/conekta/models/order_response_checkout.rb', line 60 def on_demand_enabled @on_demand_enabled end |
#paid_payments_count ⇒ Object
Returns the value of attribute paid_payments_count.
62 63 64 |
# File 'lib/conekta/models/order_response_checkout.rb', line 62 def paid_payments_count @paid_payments_count end |
#recurrent ⇒ Object
Returns the value of attribute recurrent.
64 65 66 |
# File 'lib/conekta/models/order_response_checkout.rb', line 64 def recurrent @recurrent end |
#redirection_time ⇒ Object
number of seconds to wait before redirecting to the success_url
67 68 69 |
# File 'lib/conekta/models/order_response_checkout.rb', line 67 def redirection_time @redirection_time end |
#slug ⇒ Object
Returns the value of attribute slug.
69 70 71 |
# File 'lib/conekta/models/order_response_checkout.rb', line 69 def slug @slug end |
#sms_sent ⇒ Object
Returns the value of attribute sms_sent.
71 72 73 |
# File 'lib/conekta/models/order_response_checkout.rb', line 71 def sms_sent @sms_sent end |
#starts_at ⇒ Object
Returns the value of attribute starts_at.
76 77 78 |
# File 'lib/conekta/models/order_response_checkout.rb', line 76 def starts_at @starts_at end |
#status ⇒ Object
Returns the value of attribute status.
78 79 80 |
# File 'lib/conekta/models/order_response_checkout.rb', line 78 def status @status end |
#success_url ⇒ Object
Redirection url back to the site in case of successful payment, applies only to HostedPayment
74 75 76 |
# File 'lib/conekta/models/order_response_checkout.rb', line 74 def success_url @success_url end |
#type ⇒ Object
This field represents the type of checkout, which determines the user experience during the payment process. 'HostedPayment' will redirect the customer to a Conekta-hosted page to complete the payment, while 'Integration' allows the payment process to be handled entirely on your site using Conekta's APIs and SDKs.
81 82 83 |
# File 'lib/conekta/models/order_response_checkout.rb', line 81 def type @type end |
#url ⇒ Object
Indicate the url of the Conekta component to complete the payment. For HostedPayment, this will be a Conekta-hosted page
84 85 86 |
# File 'lib/conekta/models/order_response_checkout.rb', line 84 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
145 146 147 |
# File 'lib/conekta/models/order_response_checkout.rb', line 145 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
150 151 152 |
# File 'lib/conekta/models/order_response_checkout.rb', line 150 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/conekta/models/order_response_checkout.rb', line 109 def self.attribute_map { :'allowed_payment_methods' => :'allowed_payment_methods', :'excluded_payment_methods' => :'excluded_payment_methods', :'can_not_expire' => :'can_not_expire', :'emails_sent' => :'emails_sent', :'exclude_card_networks' => :'exclude_card_networks', :'expires_at' => :'expires_at', :'failure_url' => :'failure_url', :'force_3ds_flow' => :'force_3ds_flow', :'force_save_card' => :'force_save_card', :'id' => :'id', :'is_redirect_on_failure' => :'is_redirect_on_failure', :'livemode' => :'livemode', :'max_failed_retries' => :'max_failed_retries', :'metadata' => :'metadata', :'monthly_installments_enabled' => :'monthly_installments_enabled', :'monthly_installments_options' => :'monthly_installments_options', :'name' => :'name', :'needs_shipping_contact' => :'needs_shipping_contact', :'object' => :'object', :'on_demand_enabled' => :'on_demand_enabled', :'paid_payments_count' => :'paid_payments_count', :'recurrent' => :'recurrent', :'redirection_time' => :'redirection_time', :'slug' => :'slug', :'sms_sent' => :'sms_sent', :'success_url' => :'success_url', :'starts_at' => :'starts_at', :'status' => :'status', :'type' => :'type', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/conekta/models/order_response_checkout.rb', line 514 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
191 192 193 194 |
# File 'lib/conekta/models/order_response_checkout.rb', line 191 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/conekta/models/order_response_checkout.rb', line 155 def self.openapi_types { :'allowed_payment_methods' => :'Array<String>', :'excluded_payment_methods' => :'Array<String>', :'can_not_expire' => :'Boolean', :'emails_sent' => :'Integer', :'exclude_card_networks' => :'Array<String>', :'expires_at' => :'Integer', :'failure_url' => :'String', :'force_3ds_flow' => :'Boolean', :'force_save_card' => :'Boolean', :'id' => :'String', :'is_redirect_on_failure' => :'Boolean', :'livemode' => :'Boolean', :'max_failed_retries' => :'Integer', :'metadata' => :'Hash<String, Object>', :'monthly_installments_enabled' => :'Boolean', :'monthly_installments_options' => :'Array<Integer>', :'name' => :'String', :'needs_shipping_contact' => :'Boolean', :'object' => :'String', :'on_demand_enabled' => :'Boolean', :'paid_payments_count' => :'Integer', :'recurrent' => :'Boolean', :'redirection_time' => :'Integer', :'slug' => :'String', :'sms_sent' => :'Integer', :'success_url' => :'String', :'starts_at' => :'Integer', :'status' => :'String', :'type' => :'String', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/conekta/models/order_response_checkout.rb', line 464 def ==(o) return true if self.equal?(o) self.class == o.class && allowed_payment_methods == o.allowed_payment_methods && excluded_payment_methods == o.excluded_payment_methods && can_not_expire == o.can_not_expire && emails_sent == o.emails_sent && exclude_card_networks == o.exclude_card_networks && expires_at == o.expires_at && failure_url == o.failure_url && force_3ds_flow == o.force_3ds_flow && force_save_card == o.force_save_card && id == o.id && is_redirect_on_failure == o.is_redirect_on_failure && livemode == o.livemode && max_failed_retries == o.max_failed_retries && == o. && monthly_installments_enabled == o.monthly_installments_enabled && == o. && name == o.name && needs_shipping_contact == o.needs_shipping_contact && object == o.object && on_demand_enabled == o.on_demand_enabled && paid_payments_count == o.paid_payments_count && recurrent == o.recurrent && redirection_time == o.redirection_time && slug == o.slug && sms_sent == o.sms_sent && success_url == o.success_url && starts_at == o.starts_at && status == o.status && type == o.type && url == o.url end |
#eql?(o) ⇒ Boolean
501 502 503 |
# File 'lib/conekta/models/order_response_checkout.rb', line 501 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
507 508 509 |
# File 'lib/conekta/models/order_response_checkout.rb', line 507 def hash [allowed_payment_methods, excluded_payment_methods, can_not_expire, emails_sent, exclude_card_networks, expires_at, failure_url, force_3ds_flow, force_save_card, id, is_redirect_on_failure, livemode, max_failed_retries, , monthly_installments_enabled, , name, needs_shipping_contact, object, on_demand_enabled, paid_payments_count, recurrent, redirection_time, slug, sms_sent, success_url, starts_at, status, type, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/conekta/models/order_response_checkout.rb', line 355 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @livemode.nil? invalid_properties.push('invalid value for "livemode", livemode cannot be nil.') end if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
536 537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/conekta/models/order_response_checkout.rb', line 536 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
387 388 389 390 391 392 393 394 395 396 |
# File 'lib/conekta/models/order_response_checkout.rb', line 387 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @livemode.nil? return false if !@metadata.nil? && @metadata.length > 100 return false if @name.nil? return false if @object.nil? return false if @type.nil? true end |