Class: Conekta::OrderTaxResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::OrderTaxResponse
- Defined in:
- lib/conekta/models/order_tax_response.rb
Overview
create new taxes for an existing order response
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to be collected for tax in cents.
-
#description ⇒ Object
description or tax's name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#object ⇒ Object
Returns the value of attribute object.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderTaxResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrderTaxResponse
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/conekta/models/order_tax_response.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::OrderTaxResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::OrderTaxResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end end |
Instance Attribute Details
#amount ⇒ Object
The amount to be collected for tax in cents
20 21 22 |
# File 'lib/conekta/models/order_tax_response.rb', line 20 def amount @amount end |
#description ⇒ Object
description or tax's name
23 24 25 |
# File 'lib/conekta/models/order_tax_response.rb', line 23 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
27 28 29 |
# File 'lib/conekta/models/order_tax_response.rb', line 27 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
25 26 27 |
# File 'lib/conekta/models/order_tax_response.rb', line 25 def @metadata end |
#object ⇒ Object
Returns the value of attribute object.
29 30 31 |
# File 'lib/conekta/models/order_tax_response.rb', line 29 def object @object end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
31 32 33 |
# File 'lib/conekta/models/order_tax_response.rb', line 31 def parent_id @parent_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/conekta/models/order_tax_response.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/conekta/models/order_tax_response.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/conekta/models/order_tax_response.rb', line 34 def self.attribute_map { :'amount' => :'amount', :'description' => :'description', :'metadata' => :'metadata', :'id' => :'id', :'object' => :'object', :'parent_id' => :'parent_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/conekta/models/order_tax_response.rb', line 247 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/conekta/models/order_tax_response.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/conekta/models/order_tax_response.rb', line 56 def self.openapi_types { :'amount' => :'Integer', :'description' => :'String', :'metadata' => :'Hash<String, Object>', :'id' => :'String', :'object' => :'String', :'parent_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/conekta/models/order_tax_response.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && description == o.description && == o. && id == o.id && object == o.object && parent_id == o.parent_id end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/conekta/models/order_tax_response.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/conekta/models/order_tax_response.rb', line 240 def hash [amount, description, , id, object, parent_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/conekta/models/order_tax_response.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @amount < 0 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @description.to_s.length < 2 invalid_properties.push('invalid value for "description", the character length must be greater than or equal to 2.') end if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/conekta/models/order_tax_response.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/conekta/models/order_tax_response.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @amount.nil? return false if @amount < 0 return false if @description.nil? return false if @description.to_s.length < 2 return false if !@metadata.nil? && @metadata.length > 100 return false if @id.nil? true end |