Class: Conekta::PaymentMethodCardResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::PaymentMethodCardResponse
- Defined in:
- lib/conekta/models/payment_method_card_response.rb
Instance Attribute Summary collapse
-
#bin ⇒ Object
Returns the value of attribute bin.
-
#brand ⇒ Object
Returns the value of attribute brand.
-
#card_type ⇒ Object
Returns the value of attribute card_type.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#default ⇒ Object
Returns the value of attribute default.
-
#exp_month ⇒ Object
Returns the value of attribute exp_month.
-
#exp_year ⇒ Object
Returns the value of attribute exp_year.
-
#id ⇒ Object
Returns the value of attribute id.
-
#issuer ⇒ Object
Name of the institution that issued the card.
-
#last4 ⇒ Object
Returns the value of attribute last4.
-
#name ⇒ Object
Returns the value of attribute name.
-
#object ⇒ Object
Returns the value of attribute object.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
-
#payment_source_status ⇒ Object
Returns the value of attribute payment_source_status.
-
#type ⇒ Object
Returns the value of attribute type.
-
#visible_on_checkout ⇒ Object
Returns the value of attribute visible_on_checkout.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentMethodCardResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PaymentMethodCardResponse
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::PaymentMethodCardResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::PaymentMethodCardResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'last4') self.last4 = attributes[:'last4'] end if attributes.key?(:'bin') self.bin = attributes[:'bin'] end if attributes.key?(:'card_type') self.card_type = attributes[:'card_type'] end if attributes.key?(:'exp_month') self.exp_month = attributes[:'exp_month'] end if attributes.key?(:'exp_year') self.exp_year = attributes[:'exp_year'] end if attributes.key?(:'brand') self.brand = attributes[:'brand'] end if attributes.key?(:'issuer') self.issuer = attributes[:'issuer'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'default') self.default = attributes[:'default'] end if attributes.key?(:'visible_on_checkout') self.visible_on_checkout = attributes[:'visible_on_checkout'] end if attributes.key?(:'payment_source_status') self.payment_source_status = attributes[:'payment_source_status'] end end |
Instance Attribute Details
#bin ⇒ Object
Returns the value of attribute bin.
30 31 32 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 30 def bin @bin end |
#brand ⇒ Object
Returns the value of attribute brand.
38 39 40 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 38 def brand @brand end |
#card_type ⇒ Object
Returns the value of attribute card_type.
32 33 34 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 32 def card_type @card_type end |
#created_at ⇒ Object
Returns the value of attribute created_at.
24 25 26 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 24 def created_at @created_at end |
#default ⇒ Object
Returns the value of attribute default.
45 46 47 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 45 def default @default end |
#exp_month ⇒ Object
Returns the value of attribute exp_month.
34 35 36 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 34 def exp_month @exp_month end |
#exp_year ⇒ Object
Returns the value of attribute exp_year.
36 37 38 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 36 def exp_year @exp_year end |
#id ⇒ Object
Returns the value of attribute id.
20 21 22 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 20 def id @id end |
#issuer ⇒ Object
Name of the institution that issued the card
41 42 43 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 41 def issuer @issuer end |
#last4 ⇒ Object
Returns the value of attribute last4.
28 29 30 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 28 def last4 @last4 end |
#name ⇒ Object
Returns the value of attribute name.
43 44 45 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 43 def name @name end |
#object ⇒ Object
Returns the value of attribute object.
22 23 24 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 22 def object @object end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
26 27 28 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 26 def parent_id @parent_id end |
#payment_source_status ⇒ Object
Returns the value of attribute payment_source_status.
49 50 51 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 49 def payment_source_status @payment_source_status end |
#type ⇒ Object
Returns the value of attribute type.
18 19 20 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 18 def type @type end |
#visible_on_checkout ⇒ Object
Returns the value of attribute visible_on_checkout.
47 48 49 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 47 def visible_on_checkout @visible_on_checkout end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 52 def self.attribute_map { :'type' => :'type', :'id' => :'id', :'object' => :'object', :'created_at' => :'created_at', :'parent_id' => :'parent_id', :'last4' => :'last4', :'bin' => :'bin', :'card_type' => :'card_type', :'exp_month' => :'exp_month', :'exp_year' => :'exp_year', :'brand' => :'brand', :'issuer' => :'issuer', :'name' => :'name', :'default' => :'default', :'visible_on_checkout' => :'visible_on_checkout', :'payment_source_status' => :'payment_source_status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 313 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 84 def self.openapi_types { :'type' => :'String', :'id' => :'String', :'object' => :'String', :'created_at' => :'Integer', :'parent_id' => :'String', :'last4' => :'String', :'bin' => :'String', :'card_type' => :'String', :'exp_month' => :'String', :'exp_year' => :'String', :'brand' => :'String', :'issuer' => :'String', :'name' => :'String', :'default' => :'Boolean', :'visible_on_checkout' => :'Boolean', :'payment_source_status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 277 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && id == o.id && object == o.object && created_at == o.created_at && parent_id == o.parent_id && last4 == o.last4 && bin == o.bin && card_type == o.card_type && exp_month == o.exp_month && exp_year == o.exp_year && brand == o.brand && issuer == o.issuer && name == o.name && default == o.default && visible_on_checkout == o.visible_on_checkout && payment_source_status == o.payment_source_status end |
#eql?(o) ⇒ Boolean
300 301 302 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 300 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
306 307 308 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 306 def hash [type, id, object, created_at, parent_id, last4, bin, card_type, exp_month, exp_year, brand, issuer, name, default, visible_on_checkout, payment_source_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
226 227 228 229 230 231 232 233 |
# File 'lib/conekta/models/payment_method_card_response.rb', line 226 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? return false if @id.nil? return false if @object.nil? return false if @created_at.nil? true end |