Class: Conekta::Product
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::Product
- Defined in:
- lib/conekta/models/product.rb
Instance Attribute Summary collapse
-
#antifraud_info ⇒ Object
Returns the value of attribute antifraud_info.
-
#brand ⇒ Object
The brand of the item.
-
#description ⇒ Object
Short description of the item.
-
#metadata ⇒ Object
It is a key/value hash that can hold custom fields.
-
#name ⇒ Object
The name of the item.
-
#quantity ⇒ Object
The quantity of the item in the order.
-
#sku ⇒ Object
The stock keeping unit for the item.
-
#tags ⇒ Object
List of tags for the item.
-
#unit_price ⇒ Object
The price of the item in cents.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Product
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Product
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/conekta/models/product.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::Product` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::Product`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'antifraud_info') if (value = attributes[:'antifraud_info']).is_a?(Hash) self.antifraud_info = value end end if attributes.key?(:'brand') self.brand = attributes[:'brand'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] else self.quantity = nil end if attributes.key?(:'sku') self.sku = attributes[:'sku'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'unit_price') self.unit_price = attributes[:'unit_price'] else self.unit_price = nil end end |
Instance Attribute Details
#antifraud_info ⇒ Object
Returns the value of attribute antifraud_info.
18 19 20 |
# File 'lib/conekta/models/product.rb', line 18 def antifraud_info @antifraud_info end |
#brand ⇒ Object
The brand of the item.
21 22 23 |
# File 'lib/conekta/models/product.rb', line 21 def brand @brand end |
#description ⇒ Object
Short description of the item
24 25 26 |
# File 'lib/conekta/models/product.rb', line 24 def description @description end |
#metadata ⇒ Object
It is a key/value hash that can hold custom fields. Maximum 100 elements and allows special characters.
27 28 29 |
# File 'lib/conekta/models/product.rb', line 27 def @metadata end |
#name ⇒ Object
The name of the item. It will be displayed in the order.
30 31 32 |
# File 'lib/conekta/models/product.rb', line 30 def name @name end |
#quantity ⇒ Object
The quantity of the item in the order.
33 34 35 |
# File 'lib/conekta/models/product.rb', line 33 def quantity @quantity end |
#sku ⇒ Object
The stock keeping unit for the item. It is used to identify the item in the order.
36 37 38 |
# File 'lib/conekta/models/product.rb', line 36 def sku @sku end |
#tags ⇒ Object
List of tags for the item. It is used to identify the item in the order.
39 40 41 |
# File 'lib/conekta/models/product.rb', line 39 def @tags end |
#unit_price ⇒ Object
The price of the item in cents.
42 43 44 |
# File 'lib/conekta/models/product.rb', line 42 def unit_price @unit_price end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/conekta/models/product.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/conekta/models/product.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/conekta/models/product.rb', line 45 def self.attribute_map { :'antifraud_info' => :'antifraud_info', :'brand' => :'brand', :'description' => :'description', :'metadata' => :'metadata', :'name' => :'name', :'quantity' => :'quantity', :'sku' => :'sku', :'tags' => :'tags', :'unit_price' => :'unit_price' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/conekta/models/product.rb', line 302 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/conekta/models/product.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/conekta/models/product.rb', line 70 def self.openapi_types { :'antifraud_info' => :'Hash<String, Object>', :'brand' => :'String', :'description' => :'String', :'metadata' => :'Hash<String, Object>', :'name' => :'String', :'quantity' => :'Integer', :'sku' => :'String', :'tags' => :'Array<String>', :'unit_price' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/conekta/models/product.rb', line 273 def ==(o) return true if self.equal?(o) self.class == o.class && antifraud_info == o.antifraud_info && brand == o.brand && description == o.description && == o. && name == o.name && quantity == o.quantity && sku == o.sku && == o. && unit_price == o.unit_price end |
#eql?(o) ⇒ Boolean
289 290 291 |
# File 'lib/conekta/models/product.rb', line 289 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/conekta/models/product.rb', line 295 def hash [antifraud_info, brand, description, , name, quantity, sku, , unit_price].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/conekta/models/product.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@description.nil? && @description.to_s.length > 250 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.') end if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @quantity.nil? invalid_properties.push('invalid value for "quantity", quantity cannot be nil.') end if @quantity < 1 invalid_properties.push('invalid value for "quantity", must be greater than or equal to 1.') end if @unit_price.nil? invalid_properties.push('invalid value for "unit_price", unit_price cannot be nil.') end if @unit_price < 0 invalid_properties.push('invalid value for "unit_price", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/conekta/models/product.rb', line 324 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/conekta/models/product.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@description.nil? && @description.to_s.length > 250 return false if !@metadata.nil? && @metadata.length > 100 return false if @name.nil? return false if @quantity.nil? return false if @quantity < 1 return false if @unit_price.nil? return false if @unit_price < 0 true end |