Class: Conekta::SubscriptionResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::SubscriptionResponse
- Defined in:
- lib/conekta/models/subscription_response.rb
Overview
subscription model
Instance Attribute Summary collapse
-
#billing_cycle_end ⇒ Object
Returns the value of attribute billing_cycle_end.
-
#billing_cycle_start ⇒ Object
Returns the value of attribute billing_cycle_start.
-
#canceled_at ⇒ Object
Returns the value of attribute canceled_at.
-
#canceled_reason ⇒ Object
Reason for cancellation.
-
#card_id ⇒ Object
Returns the value of attribute card_id.
-
#charge_id ⇒ Object
Returns the value of attribute charge_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#customer_custom_reference ⇒ Object
Returns the value of attribute customer_custom_reference.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_billing_cycle_order_id ⇒ Object
Returns the value of attribute last_billing_cycle_order_id.
-
#object ⇒ Object
Returns the value of attribute object.
-
#paused_at ⇒ Object
Returns the value of attribute paused_at.
-
#plan_id ⇒ Object
Returns the value of attribute plan_id.
-
#status ⇒ Object
Returns the value of attribute status.
-
#subscription_start ⇒ Object
Returns the value of attribute subscription_start.
-
#trial_end ⇒ Object
Returns the value of attribute trial_end.
-
#trial_start ⇒ Object
Returns the value of attribute trial_start.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubscriptionResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SubscriptionResponse
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/conekta/models/subscription_response.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::SubscriptionResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::SubscriptionResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'billing_cycle_start') self.billing_cycle_start = attributes[:'billing_cycle_start'] end if attributes.key?(:'billing_cycle_end') self.billing_cycle_end = attributes[:'billing_cycle_end'] end if attributes.key?(:'canceled_at') self.canceled_at = attributes[:'canceled_at'] end if attributes.key?(:'canceled_reason') self.canceled_reason = attributes[:'canceled_reason'] end if attributes.key?(:'card_id') self.card_id = attributes[:'card_id'] end if attributes.key?(:'charge_id') self.charge_id = attributes[:'charge_id'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'customer_custom_reference') self.customer_custom_reference = attributes[:'customer_custom_reference'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'last_billing_cycle_order_id') self.last_billing_cycle_order_id = attributes[:'last_billing_cycle_order_id'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'paused_at') self.paused_at = attributes[:'paused_at'] end if attributes.key?(:'plan_id') self.plan_id = attributes[:'plan_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'subscription_start') self.subscription_start = attributes[:'subscription_start'] end if attributes.key?(:'trial_start') self.trial_start = attributes[:'trial_start'] end if attributes.key?(:'trial_end') self.trial_end = attributes[:'trial_end'] end end |
Instance Attribute Details
#billing_cycle_end ⇒ Object
Returns the value of attribute billing_cycle_end.
21 22 23 |
# File 'lib/conekta/models/subscription_response.rb', line 21 def billing_cycle_end @billing_cycle_end end |
#billing_cycle_start ⇒ Object
Returns the value of attribute billing_cycle_start.
19 20 21 |
# File 'lib/conekta/models/subscription_response.rb', line 19 def billing_cycle_start @billing_cycle_start end |
#canceled_at ⇒ Object
Returns the value of attribute canceled_at.
23 24 25 |
# File 'lib/conekta/models/subscription_response.rb', line 23 def canceled_at @canceled_at end |
#canceled_reason ⇒ Object
Reason for cancellation. This field appears when the subscription status is 'canceled'.
26 27 28 |
# File 'lib/conekta/models/subscription_response.rb', line 26 def canceled_reason @canceled_reason end |
#card_id ⇒ Object
Returns the value of attribute card_id.
28 29 30 |
# File 'lib/conekta/models/subscription_response.rb', line 28 def card_id @card_id end |
#charge_id ⇒ Object
Returns the value of attribute charge_id.
30 31 32 |
# File 'lib/conekta/models/subscription_response.rb', line 30 def charge_id @charge_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
32 33 34 |
# File 'lib/conekta/models/subscription_response.rb', line 32 def created_at @created_at end |
#customer_custom_reference ⇒ Object
Returns the value of attribute customer_custom_reference.
34 35 36 |
# File 'lib/conekta/models/subscription_response.rb', line 34 def customer_custom_reference @customer_custom_reference end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
36 37 38 |
# File 'lib/conekta/models/subscription_response.rb', line 36 def customer_id @customer_id end |
#id ⇒ Object
Returns the value of attribute id.
38 39 40 |
# File 'lib/conekta/models/subscription_response.rb', line 38 def id @id end |
#last_billing_cycle_order_id ⇒ Object
Returns the value of attribute last_billing_cycle_order_id.
40 41 42 |
# File 'lib/conekta/models/subscription_response.rb', line 40 def last_billing_cycle_order_id @last_billing_cycle_order_id end |
#object ⇒ Object
Returns the value of attribute object.
42 43 44 |
# File 'lib/conekta/models/subscription_response.rb', line 42 def object @object end |
#paused_at ⇒ Object
Returns the value of attribute paused_at.
44 45 46 |
# File 'lib/conekta/models/subscription_response.rb', line 44 def paused_at @paused_at end |
#plan_id ⇒ Object
Returns the value of attribute plan_id.
46 47 48 |
# File 'lib/conekta/models/subscription_response.rb', line 46 def plan_id @plan_id end |
#status ⇒ Object
Returns the value of attribute status.
48 49 50 |
# File 'lib/conekta/models/subscription_response.rb', line 48 def status @status end |
#subscription_start ⇒ Object
Returns the value of attribute subscription_start.
50 51 52 |
# File 'lib/conekta/models/subscription_response.rb', line 50 def subscription_start @subscription_start end |
#trial_end ⇒ Object
Returns the value of attribute trial_end.
54 55 56 |
# File 'lib/conekta/models/subscription_response.rb', line 54 def trial_end @trial_end end |
#trial_start ⇒ Object
Returns the value of attribute trial_start.
52 53 54 |
# File 'lib/conekta/models/subscription_response.rb', line 52 def trial_start @trial_start end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/conekta/models/subscription_response.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/conekta/models/subscription_response.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/conekta/models/subscription_response.rb', line 57 def self.attribute_map { :'billing_cycle_start' => :'billing_cycle_start', :'billing_cycle_end' => :'billing_cycle_end', :'canceled_at' => :'canceled_at', :'canceled_reason' => :'canceled_reason', :'card_id' => :'card_id', :'charge_id' => :'charge_id', :'created_at' => :'created_at', :'customer_custom_reference' => :'customer_custom_reference', :'customer_id' => :'customer_id', :'id' => :'id', :'last_billing_cycle_order_id' => :'last_billing_cycle_order_id', :'object' => :'object', :'paused_at' => :'paused_at', :'plan_id' => :'plan_id', :'status' => :'status', :'subscription_start' => :'subscription_start', :'trial_start' => :'trial_start', :'trial_end' => :'trial_end' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/conekta/models/subscription_response.rb', line 264 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/conekta/models/subscription_response.rb', line 115 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/conekta/models/subscription_response.rb', line 91 def self.openapi_types { :'billing_cycle_start' => :'Integer', :'billing_cycle_end' => :'Integer', :'canceled_at' => :'Integer', :'canceled_reason' => :'String', :'card_id' => :'String', :'charge_id' => :'String', :'created_at' => :'Integer', :'customer_custom_reference' => :'String', :'customer_id' => :'String', :'id' => :'String', :'last_billing_cycle_order_id' => :'String', :'object' => :'String', :'paused_at' => :'Integer', :'plan_id' => :'String', :'status' => :'String', :'subscription_start' => :'Integer', :'trial_start' => :'Integer', :'trial_end' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/conekta/models/subscription_response.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && billing_cycle_start == o.billing_cycle_start && billing_cycle_end == o.billing_cycle_end && canceled_at == o.canceled_at && canceled_reason == o.canceled_reason && card_id == o.card_id && charge_id == o.charge_id && created_at == o.created_at && customer_custom_reference == o.customer_custom_reference && customer_id == o.customer_id && id == o.id && last_billing_cycle_order_id == o.last_billing_cycle_order_id && object == o.object && paused_at == o.paused_at && plan_id == o.plan_id && status == o.status && subscription_start == o.subscription_start && trial_start == o.trial_start && trial_end == o.trial_end end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/conekta/models/subscription_response.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/conekta/models/subscription_response.rb', line 257 def hash [billing_cycle_start, billing_cycle_end, canceled_at, canceled_reason, card_id, charge_id, created_at, customer_custom_reference, customer_id, id, last_billing_cycle_order_id, object, paused_at, plan_id, status, subscription_start, trial_start, trial_end].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 215 |
# File 'lib/conekta/models/subscription_response.rb', line 211 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/conekta/models/subscription_response.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 |
# File 'lib/conekta/models/subscription_response.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |