Class: Conekta::TokenResponseCheckout
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::TokenResponseCheckout
- Defined in:
- lib/conekta/models/token_response_checkout.rb
Instance Attribute Summary collapse
-
#allowed_payment_methods ⇒ Object
Returns the value of attribute allowed_payment_methods.
-
#can_not_expire ⇒ Object
Indicates if the checkout can not expire.
-
#emails_sent ⇒ Object
Returns the value of attribute emails_sent.
-
#exclude_card_networks ⇒ Object
Returns the value of attribute exclude_card_networks.
-
#expires_at ⇒ Object
Date and time when the checkout expires.
-
#failure_url ⇒ Object
URL to redirect the customer to if the payment process fails.
-
#force_3ds_flow ⇒ Object
Indicates if the checkout forces the 3DS flow.
-
#id ⇒ Object
Returns the value of attribute id.
-
#livemode ⇒ Object
Returns the value of attribute livemode.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#monthly_installments_enabled ⇒ Object
Indicates if the checkout allows monthly installments.
-
#monthly_installments_options ⇒ Object
List of monthly installments options.
-
#name ⇒ Object
Returns the value of attribute name.
-
#needs_shipping_contact ⇒ Object
Returns the value of attribute needs_shipping_contact.
-
#object ⇒ Object
Indicates the type of object, in this case checkout.
-
#on_demand_enabled ⇒ Object
Indicates if the checkout allows on demand payments.
-
#paid_payments_count ⇒ Object
Number of payments that have been paid.
-
#recurrent ⇒ Object
Indicates if the checkout is recurrent.
-
#sms_sent ⇒ Object
Returns the value of attribute sms_sent.
-
#starts_at ⇒ Object
Date and time when the checkout starts.
-
#status ⇒ Object
Status of the checkout.
-
#success_url ⇒ Object
URL to redirect the customer to after the payment process is completed.
-
#type ⇒ Object
Type of checkout.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TokenResponseCheckout
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TokenResponseCheckout
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/conekta/models/token_response_checkout.rb', line 154 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::TokenResponseCheckout` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::TokenResponseCheckout`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allowed_payment_methods') if (value = attributes[:'allowed_payment_methods']).is_a?(Array) self.allowed_payment_methods = value end end if attributes.key?(:'can_not_expire') self.can_not_expire = attributes[:'can_not_expire'] end if attributes.key?(:'emails_sent') self.emails_sent = attributes[:'emails_sent'] end if attributes.key?(:'exclude_card_networks') if (value = attributes[:'exclude_card_networks']).is_a?(Array) self.exclude_card_networks = value end end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'failure_url') self.failure_url = attributes[:'failure_url'] end if attributes.key?(:'force_3ds_flow') self.force_3ds_flow = attributes[:'force_3ds_flow'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'monthly_installments_enabled') self.monthly_installments_enabled = attributes[:'monthly_installments_enabled'] end if attributes.key?(:'monthly_installments_options') if (value = attributes[:'monthly_installments_options']).is_a?(Array) self. = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'needs_shipping_contact') self.needs_shipping_contact = attributes[:'needs_shipping_contact'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'on_demand_enabled') self.on_demand_enabled = attributes[:'on_demand_enabled'] end if attributes.key?(:'paid_payments_count') self.paid_payments_count = attributes[:'paid_payments_count'] end if attributes.key?(:'recurrent') self.recurrent = attributes[:'recurrent'] end if attributes.key?(:'sms_sent') self.sms_sent = attributes[:'sms_sent'] end if attributes.key?(:'starts_at') self.starts_at = attributes[:'starts_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'success_url') self.success_url = attributes[:'success_url'] end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#allowed_payment_methods ⇒ Object
Returns the value of attribute allowed_payment_methods.
18 19 20 |
# File 'lib/conekta/models/token_response_checkout.rb', line 18 def allowed_payment_methods @allowed_payment_methods end |
#can_not_expire ⇒ Object
Indicates if the checkout can not expire.
21 22 23 |
# File 'lib/conekta/models/token_response_checkout.rb', line 21 def can_not_expire @can_not_expire end |
#emails_sent ⇒ Object
Returns the value of attribute emails_sent.
23 24 25 |
# File 'lib/conekta/models/token_response_checkout.rb', line 23 def emails_sent @emails_sent end |
#exclude_card_networks ⇒ Object
Returns the value of attribute exclude_card_networks.
25 26 27 |
# File 'lib/conekta/models/token_response_checkout.rb', line 25 def exclude_card_networks @exclude_card_networks end |
#expires_at ⇒ Object
Date and time when the checkout expires.
28 29 30 |
# File 'lib/conekta/models/token_response_checkout.rb', line 28 def expires_at @expires_at end |
#failure_url ⇒ Object
URL to redirect the customer to if the payment process fails.
31 32 33 |
# File 'lib/conekta/models/token_response_checkout.rb', line 31 def failure_url @failure_url end |
#force_3ds_flow ⇒ Object
Indicates if the checkout forces the 3DS flow.
34 35 36 |
# File 'lib/conekta/models/token_response_checkout.rb', line 34 def force_3ds_flow @force_3ds_flow end |
#id ⇒ Object
Returns the value of attribute id.
36 37 38 |
# File 'lib/conekta/models/token_response_checkout.rb', line 36 def id @id end |
#livemode ⇒ Object
Returns the value of attribute livemode.
38 39 40 |
# File 'lib/conekta/models/token_response_checkout.rb', line 38 def livemode @livemode end |
#metadata ⇒ Object
Returns the value of attribute metadata.
40 41 42 |
# File 'lib/conekta/models/token_response_checkout.rb', line 40 def @metadata end |
#monthly_installments_enabled ⇒ Object
Indicates if the checkout allows monthly installments.
43 44 45 |
# File 'lib/conekta/models/token_response_checkout.rb', line 43 def monthly_installments_enabled @monthly_installments_enabled end |
#monthly_installments_options ⇒ Object
List of monthly installments options.
46 47 48 |
# File 'lib/conekta/models/token_response_checkout.rb', line 46 def @monthly_installments_options end |
#name ⇒ Object
Returns the value of attribute name.
48 49 50 |
# File 'lib/conekta/models/token_response_checkout.rb', line 48 def name @name end |
#needs_shipping_contact ⇒ Object
Returns the value of attribute needs_shipping_contact.
50 51 52 |
# File 'lib/conekta/models/token_response_checkout.rb', line 50 def needs_shipping_contact @needs_shipping_contact end |
#object ⇒ Object
Indicates the type of object, in this case checkout.
53 54 55 |
# File 'lib/conekta/models/token_response_checkout.rb', line 53 def object @object end |
#on_demand_enabled ⇒ Object
Indicates if the checkout allows on demand payments.
56 57 58 |
# File 'lib/conekta/models/token_response_checkout.rb', line 56 def on_demand_enabled @on_demand_enabled end |
#paid_payments_count ⇒ Object
Number of payments that have been paid.
59 60 61 |
# File 'lib/conekta/models/token_response_checkout.rb', line 59 def paid_payments_count @paid_payments_count end |
#recurrent ⇒ Object
Indicates if the checkout is recurrent.
62 63 64 |
# File 'lib/conekta/models/token_response_checkout.rb', line 62 def recurrent @recurrent end |
#sms_sent ⇒ Object
Returns the value of attribute sms_sent.
64 65 66 |
# File 'lib/conekta/models/token_response_checkout.rb', line 64 def sms_sent @sms_sent end |
#starts_at ⇒ Object
Date and time when the checkout starts.
67 68 69 |
# File 'lib/conekta/models/token_response_checkout.rb', line 67 def starts_at @starts_at end |
#status ⇒ Object
Status of the checkout.
70 71 72 |
# File 'lib/conekta/models/token_response_checkout.rb', line 70 def status @status end |
#success_url ⇒ Object
URL to redirect the customer to after the payment process is completed.
73 74 75 |
# File 'lib/conekta/models/token_response_checkout.rb', line 73 def success_url @success_url end |
#type ⇒ Object
Type of checkout.
76 77 78 |
# File 'lib/conekta/models/token_response_checkout.rb', line 76 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
108 109 110 |
# File 'lib/conekta/models/token_response_checkout.rb', line 108 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/conekta/models/token_response_checkout.rb', line 113 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/conekta/models/token_response_checkout.rb', line 79 def self.attribute_map { :'allowed_payment_methods' => :'allowed_payment_methods', :'can_not_expire' => :'can_not_expire', :'emails_sent' => :'emails_sent', :'exclude_card_networks' => :'exclude_card_networks', :'expires_at' => :'expires_at', :'failure_url' => :'failure_url', :'force_3ds_flow' => :'force_3ds_flow', :'id' => :'id', :'livemode' => :'livemode', :'metadata' => :'metadata', :'monthly_installments_enabled' => :'monthly_installments_enabled', :'monthly_installments_options' => :'monthly_installments_options', :'name' => :'name', :'needs_shipping_contact' => :'needs_shipping_contact', :'object' => :'object', :'on_demand_enabled' => :'on_demand_enabled', :'paid_payments_count' => :'paid_payments_count', :'recurrent' => :'recurrent', :'sms_sent' => :'sms_sent', :'starts_at' => :'starts_at', :'status' => :'status', :'success_url' => :'success_url', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/conekta/models/token_response_checkout.rb', line 329 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
147 148 149 150 |
# File 'lib/conekta/models/token_response_checkout.rb', line 147 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/conekta/models/token_response_checkout.rb', line 118 def self.openapi_types { :'allowed_payment_methods' => :'Array<String>', :'can_not_expire' => :'Boolean', :'emails_sent' => :'Integer', :'exclude_card_networks' => :'Array<String>', :'expires_at' => :'Integer', :'failure_url' => :'String', :'force_3ds_flow' => :'Boolean', :'id' => :'String', :'livemode' => :'Boolean', :'metadata' => :'Hash<String, Object>', :'monthly_installments_enabled' => :'Boolean', :'monthly_installments_options' => :'Array<Integer>', :'name' => :'String', :'needs_shipping_contact' => :'Boolean', :'object' => :'String', :'on_demand_enabled' => :'Boolean', :'paid_payments_count' => :'Integer', :'recurrent' => :'Boolean', :'sms_sent' => :'Integer', :'starts_at' => :'Integer', :'status' => :'String', :'success_url' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/conekta/models/token_response_checkout.rb', line 286 def ==(o) return true if self.equal?(o) self.class == o.class && allowed_payment_methods == o.allowed_payment_methods && can_not_expire == o.can_not_expire && emails_sent == o.emails_sent && exclude_card_networks == o.exclude_card_networks && expires_at == o.expires_at && failure_url == o.failure_url && force_3ds_flow == o.force_3ds_flow && id == o.id && livemode == o.livemode && == o. && monthly_installments_enabled == o.monthly_installments_enabled && == o. && name == o.name && needs_shipping_contact == o.needs_shipping_contact && object == o.object && on_demand_enabled == o.on_demand_enabled && paid_payments_count == o.paid_payments_count && recurrent == o.recurrent && sms_sent == o.sms_sent && starts_at == o.starts_at && status == o.status && success_url == o.success_url && type == o.type end |
#eql?(o) ⇒ Boolean
316 317 318 |
# File 'lib/conekta/models/token_response_checkout.rb', line 316 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
322 323 324 |
# File 'lib/conekta/models/token_response_checkout.rb', line 322 def hash [allowed_payment_methods, can_not_expire, emails_sent, exclude_card_networks, expires_at, failure_url, force_3ds_flow, id, livemode, , monthly_installments_enabled, , name, needs_shipping_contact, object, on_demand_enabled, paid_payments_count, recurrent, sms_sent, starts_at, status, success_url, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
271 272 273 274 275 |
# File 'lib/conekta/models/token_response_checkout.rb', line 271 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/conekta/models/token_response_checkout.rb', line 351 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
279 280 281 282 |
# File 'lib/conekta/models/token_response_checkout.rb', line 279 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |