Class: Conekta::UpdateCustomer
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::UpdateCustomer
- Defined in:
- lib/conekta/models/update_customer.rb
Overview
update customer
Instance Attribute Summary collapse
-
#antifraud_info ⇒ Object
Returns the value of attribute antifraud_info.
-
#corporate ⇒ Object
It is a value that allows identifying if the email is corporate or not.
-
#custom_reference ⇒ Object
It is an undefined value.
-
#date_of_birth ⇒ Object
It is a parameter that allows to identify the date of birth of the client.
-
#default_payment_source_id ⇒ Object
It is a parameter that allows to identify in the response, the Conekta ID of a payment method (payment_id).
-
#default_shipping_contact_id ⇒ Object
It is a parameter that allows to identify in the response, the Conekta ID of the shipping address (shipping_contact).
-
#email ⇒ Object
An email address is a series of customizable characters followed by a universal Internet symbol, the at symbol (@), the name of a host server, and a web domain ending (.mx, .com, .org, . net, etc).
-
#fiscal_entities ⇒ Object
Returns the value of attribute fiscal_entities.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Client's name.
-
#national_id ⇒ Object
It is a parameter that allows to identify the national identification number of the client.
-
#payment_sources ⇒ Object
Contains details of the payment methods that the customer has active or has used in Conekta.
-
#phone ⇒ Object
Is the customer's phone number.
-
#plan_id ⇒ Object
Contains the ID of a plan, which could together with name, email and phone create a client directly to a subscription.
-
#shipping_contacts ⇒ Object
Contains the detail of the shipping addresses that the client has active or has used in Conekta.
-
#subscription ⇒ Object
Returns the value of attribute subscription.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCustomer
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCustomer
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/conekta/models/update_customer.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::UpdateCustomer` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::UpdateCustomer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'antifraud_info') self.antifraud_info = attributes[:'antifraud_info'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'default_payment_source_id') self.default_payment_source_id = attributes[:'default_payment_source_id'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'plan_id') self.plan_id = attributes[:'plan_id'] end if attributes.key?(:'default_shipping_contact_id') self.default_shipping_contact_id = attributes[:'default_shipping_contact_id'] end if attributes.key?(:'corporate') self.corporate = attributes[:'corporate'] else self.corporate = false end if attributes.key?(:'custom_reference') self.custom_reference = attributes[:'custom_reference'] end if attributes.key?(:'fiscal_entities') if (value = attributes[:'fiscal_entities']).is_a?(Array) self.fiscal_entities = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'national_id') self.national_id = attributes[:'national_id'] end if attributes.key?(:'payment_sources') if (value = attributes[:'payment_sources']).is_a?(Array) self.payment_sources = value end end if attributes.key?(:'shipping_contacts') if (value = attributes[:'shipping_contacts']).is_a?(Array) self.shipping_contacts = value end end if attributes.key?(:'subscription') self.subscription = attributes[:'subscription'] end end |
Instance Attribute Details
#antifraud_info ⇒ Object
Returns the value of attribute antifraud_info.
19 20 21 |
# File 'lib/conekta/models/update_customer.rb', line 19 def antifraud_info @antifraud_info end |
#corporate ⇒ Object
It is a value that allows identifying if the email is corporate or not.
43 44 45 |
# File 'lib/conekta/models/update_customer.rb', line 43 def corporate @corporate end |
#custom_reference ⇒ Object
It is an undefined value.
46 47 48 |
# File 'lib/conekta/models/update_customer.rb', line 46 def custom_reference @custom_reference end |
#date_of_birth ⇒ Object
It is a parameter that allows to identify the date of birth of the client.
22 23 24 |
# File 'lib/conekta/models/update_customer.rb', line 22 def date_of_birth @date_of_birth end |
#default_payment_source_id ⇒ Object
It is a parameter that allows to identify in the response, the Conekta ID of a payment method (payment_id)
25 26 27 |
# File 'lib/conekta/models/update_customer.rb', line 25 def default_payment_source_id @default_payment_source_id end |
#default_shipping_contact_id ⇒ Object
It is a parameter that allows to identify in the response, the Conekta ID of the shipping address (shipping_contact)
40 41 42 |
# File 'lib/conekta/models/update_customer.rb', line 40 def default_shipping_contact_id @default_shipping_contact_id end |
#email ⇒ Object
An email address is a series of customizable characters followed by a universal Internet symbol, the at symbol (@), the name of a host server, and a web domain ending (.mx, .com, .org, . net, etc).
28 29 30 |
# File 'lib/conekta/models/update_customer.rb', line 28 def email @email end |
#fiscal_entities ⇒ Object
Returns the value of attribute fiscal_entities.
48 49 50 |
# File 'lib/conekta/models/update_customer.rb', line 48 def fiscal_entities @fiscal_entities end |
#metadata ⇒ Object
Returns the value of attribute metadata.
50 51 52 |
# File 'lib/conekta/models/update_customer.rb', line 50 def @metadata end |
#name ⇒ Object
Client's name
31 32 33 |
# File 'lib/conekta/models/update_customer.rb', line 31 def name @name end |
#national_id ⇒ Object
It is a parameter that allows to identify the national identification number of the client.
53 54 55 |
# File 'lib/conekta/models/update_customer.rb', line 53 def national_id @national_id end |
#payment_sources ⇒ Object
Contains details of the payment methods that the customer has active or has used in Conekta
56 57 58 |
# File 'lib/conekta/models/update_customer.rb', line 56 def payment_sources @payment_sources end |
#phone ⇒ Object
Is the customer's phone number
34 35 36 |
# File 'lib/conekta/models/update_customer.rb', line 34 def phone @phone end |
#plan_id ⇒ Object
Contains the ID of a plan, which could together with name, email and phone create a client directly to a subscription
37 38 39 |
# File 'lib/conekta/models/update_customer.rb', line 37 def plan_id @plan_id end |
#shipping_contacts ⇒ Object
Contains the detail of the shipping addresses that the client has active or has used in Conekta
59 60 61 |
# File 'lib/conekta/models/update_customer.rb', line 59 def shipping_contacts @shipping_contacts end |
#subscription ⇒ Object
Returns the value of attribute subscription.
61 62 63 |
# File 'lib/conekta/models/update_customer.rb', line 61 def subscription @subscription end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/conekta/models/update_customer.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/conekta/models/update_customer.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/conekta/models/update_customer.rb', line 64 def self.attribute_map { :'antifraud_info' => :'antifraud_info', :'date_of_birth' => :'date_of_birth', :'default_payment_source_id' => :'default_payment_source_id', :'email' => :'email', :'name' => :'name', :'phone' => :'phone', :'plan_id' => :'plan_id', :'default_shipping_contact_id' => :'default_shipping_contact_id', :'corporate' => :'corporate', :'custom_reference' => :'custom_reference', :'fiscal_entities' => :'fiscal_entities', :'metadata' => :'metadata', :'national_id' => :'national_id', :'payment_sources' => :'payment_sources', :'shipping_contacts' => :'shipping_contacts', :'subscription' => :'subscription' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/conekta/models/update_customer.rb', line 286 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/conekta/models/update_customer.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/conekta/models/update_customer.rb', line 96 def self.openapi_types { :'antifraud_info' => :'UpdateCustomerAntifraudInfo', :'date_of_birth' => :'String', :'default_payment_source_id' => :'String', :'email' => :'String', :'name' => :'String', :'phone' => :'String', :'plan_id' => :'String', :'default_shipping_contact_id' => :'String', :'corporate' => :'Boolean', :'custom_reference' => :'String', :'fiscal_entities' => :'Array<FiscalEntityRequest>', :'metadata' => :'Hash<String, Object>', :'national_id' => :'String', :'payment_sources' => :'Array<CustomerPaymentMethodsRequest>', :'shipping_contacts' => :'Array<CustomerShippingContactsRequest>', :'subscription' => :'SubscriptionRequest' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/conekta/models/update_customer.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && antifraud_info == o.antifraud_info && date_of_birth == o.date_of_birth && default_payment_source_id == o.default_payment_source_id && email == o.email && name == o.name && phone == o.phone && plan_id == o.plan_id && default_shipping_contact_id == o.default_shipping_contact_id && corporate == o.corporate && custom_reference == o.custom_reference && fiscal_entities == o.fiscal_entities && == o. && national_id == o.national_id && payment_sources == o.payment_sources && shipping_contacts == o.shipping_contacts && subscription == o.subscription end |
#eql?(o) ⇒ Boolean
273 274 275 |
# File 'lib/conekta/models/update_customer.rb', line 273 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/conekta/models/update_customer.rb', line 279 def hash [antifraud_info, date_of_birth, default_payment_source_id, email, name, phone, plan_id, default_shipping_contact_id, corporate, custom_reference, fiscal_entities, , national_id, payment_sources, shipping_contacts, subscription].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
216 217 218 219 220 221 222 223 224 |
# File 'lib/conekta/models/update_customer.rb', line 216 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/conekta/models/update_customer.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 231 232 |
# File 'lib/conekta/models/update_customer.rb', line 228 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@metadata.nil? && @metadata.length > 100 true end |