Class: Conekta::WebhookResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Conekta::WebhookResponse
- Defined in:
- lib/conekta/models/webhook_response.rb
Overview
webhooks model
Instance Attribute Summary collapse
-
#active ⇒ Object
Indicates if the webhook is actived or not.
-
#description ⇒ Object
A name or brief explanation of what this webhook is used for.
-
#id ⇒ Object
id of the webhook.
-
#livemode ⇒ Object
Indicates if the webhook is in production.
-
#object ⇒ Object
Object name, value is 'webhook'.
-
#status ⇒ Object
Indicates if the webhook is ready to receive events or failing.
-
#subscribed_events ⇒ Object
lists the events that will be sent to the webhook.
-
#url ⇒ Object
url or endpoint of the webhook.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookResponse
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/conekta/models/webhook_response.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Conekta::WebhookResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Conekta::WebhookResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] end if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'subscribed_events') if (value = attributes[:'subscribed_events']).is_a?(Array) self.subscribed_events = value end end if attributes.key?(:'url') self.url = attributes[:'url'] end end |
Instance Attribute Details
#active ⇒ Object
Indicates if the webhook is actived or not
29 30 31 |
# File 'lib/conekta/models/webhook_response.rb', line 29 def active @active end |
#description ⇒ Object
A name or brief explanation of what this webhook is used for
23 24 25 |
# File 'lib/conekta/models/webhook_response.rb', line 23 def description @description end |
#id ⇒ Object
id of the webhook
20 21 22 |
# File 'lib/conekta/models/webhook_response.rb', line 20 def id @id end |
#livemode ⇒ Object
Indicates if the webhook is in production
26 27 28 |
# File 'lib/conekta/models/webhook_response.rb', line 26 def livemode @livemode end |
#object ⇒ Object
Object name, value is 'webhook'
32 33 34 |
# File 'lib/conekta/models/webhook_response.rb', line 32 def object @object end |
#status ⇒ Object
Indicates if the webhook is ready to receive events or failing
35 36 37 |
# File 'lib/conekta/models/webhook_response.rb', line 35 def status @status end |
#subscribed_events ⇒ Object
lists the events that will be sent to the webhook
38 39 40 |
# File 'lib/conekta/models/webhook_response.rb', line 38 def subscribed_events @subscribed_events end |
#url ⇒ Object
url or endpoint of the webhook
41 42 43 |
# File 'lib/conekta/models/webhook_response.rb', line 41 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/conekta/models/webhook_response.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/conekta/models/webhook_response.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/conekta/models/webhook_response.rb', line 44 def self.attribute_map { :'id' => :'id', :'description' => :'description', :'livemode' => :'livemode', :'active' => :'active', :'object' => :'object', :'status' => :'status', :'subscribed_events' => :'subscribed_events', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/conekta/models/webhook_response.rb', line 183 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/conekta/models/webhook_response.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/conekta/models/webhook_response.rb', line 68 def self.openapi_types { :'id' => :'String', :'description' => :'String', :'livemode' => :'Boolean', :'active' => :'Boolean', :'object' => :'String', :'status' => :'String', :'subscribed_events' => :'Array<String>', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/conekta/models/webhook_response.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && description == o.description && livemode == o.livemode && active == o.active && object == o.object && status == o.status && subscribed_events == o.subscribed_events && url == o.url end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/conekta/models/webhook_response.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/conekta/models/webhook_response.rb', line 176 def hash [id, description, livemode, active, object, status, subscribed_events, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 |
# File 'lib/conekta/models/webhook_response.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/conekta/models/webhook_response.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 |
# File 'lib/conekta/models/webhook_response.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |